@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -55,6 +55,8 @@ zbx_mutex_name_t;
 typedef enum
 {
 	ZBX_RWLOCK_CONFIG = 0,
+	ZBX_RWLOCK_CONFIG_HISTORY,
+	ZBX_RWLOCK_VALUECACHE,
 	ZBX_RWLOCK_COUNT,
 }
 zbx_rwlock_name_t;
