@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -157,10 +157,6 @@
 #	include <fcntl.h>
 #endif
 
-#ifdef HAVE_KNLIST_H
-#	include <knlist.h>
-#endif
-
 #ifdef HAVE_KSTAT_H
 #	include <kstat.h>
 #endif
@@ -184,10 +180,6 @@
 #	include <mach/mach_host.h>
 #endif
 
-#ifdef HAVE_MTENT_H
-#	include <mtent.h>
-#endif
-
 #ifdef HAVE_NETDB_H
 #	include <netdb.h>
 #endif
@@ -391,6 +383,11 @@
 #	if 0x071400 <= LIBCURL_VERSION_NUM	/* version 7.20.0 */
 #		define HAVE_SMTP_AUTHENTICATION	1
 #	endif
+#	if 0x071501 <= LIBCURL_VERSION_NUM	/* version 7.21.6 */
+#		define ZBX_CURLOPT_ACCEPT_ENCODING	CURLOPT_ACCEPT_ENCODING
+#	else
+#		define ZBX_CURLOPT_ACCEPT_ENCODING	CURLOPT_ENCODING
+#	endif
 #	define ZBX_CURLOPT_MAXREDIRS	10L
 #endif
 
