@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,16 +24,16 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"18 October 2021"
+#define ZABBIX_REVDATE		"19 November 2024"
 #define ZABBIX_VERSION_MAJOR	5
 #define ZABBIX_VERSION_MINOR	0
-#define ZABBIX_VERSION_PATCH	17
+#define ZABBIX_VERSION_PATCH	45
 #ifndef ZABBIX_VERSION_REVISION
-#	define ZABBIX_VERSION_REVISION	0a4ac3dabc
+#	define ZABBIX_VERSION_REVISION	0cce23f8c58
 #endif
 #ifdef _WINDOWS
 #	ifndef ZABBIX_VERSION_RC_NUM
-#		define ZABBIX_VERSION_RC_NUM	2400
+#		define ZABBIX_VERSION_RC_NUM	1400
 #	endif
 #endif
 #define ZABBIX_VERSION_RC	""
