@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ func checkMetrics(s scheduler.Scheduler) {
 	metrics := []string{
 		`agent.hostname`,
 		`agent.ping`,
+		`agent.variant`,
 		`agent.version`,
 		`system.localtime[utc]`,
 		`system.run[echo test]`,
@@ -57,6 +58,7 @@ func checkMetrics(s scheduler.Scheduler) {
 		`vfs.fs.size[/,free]`,
 		`vfs.fs.inode[/,free]`,
 		`vfs.fs.discovery`,
+		`vfs.fs.get`,
 		`vfs.dev.write[sda,operations]`,
 		`net.tcp.listen[80]`,
 		`net.udp.listen[68]`,
@@ -97,6 +99,6 @@ func checkMetrics(s scheduler.Scheduler) {
 	}
 
 	for _, metric := range metrics {
-		_ = checkMetric(s, metric)
+		checkMetric(s, metric)
 	}
 }
