@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,8 +23,14 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+
+	"zabbix.com/pkg/pdh"
 )
 
+func loadOSDependentItems() error {
+	return pdh.LocateObjectsAndDefaultCounters(true)
+}
+
 func init() {
 
 	if path, err := os.Executable(); err == nil {
