@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ import (
 	"database/sql"
 	"encoding/json"
 	"fmt"
+	"sync"
 	"sync/atomic"
 	"time"
 
@@ -41,6 +42,10 @@ const (
 	DataLimit        = 10000
 )
 
+var (
+	cacheLock sync.Mutex
+)
+
 type DiskCache struct {
 	*cacheData
 	storagePeriod int64
@@ -153,18 +158,48 @@ func (c *DiskCache) updateLogRange() (err error) {
 	return
 }
 
-func (c *DiskCache) upload(u Uploader) (err error) {
-	var results []*AgentData
+func (c *DiskCache) resultsGet() (results []*AgentData, maxDataId uint64, maxLogId uint64, err error) {
 	var result *AgentData
 	var rows *sql.Rows
-	var maxDataId, maxLogId uint64
+
+	cacheLock.Lock()
+	defer cacheLock.Unlock()
 
 	if rows, err = c.database.Query(fmt.Sprintf("SELECT "+
 		"id,itemid,lastlogsize,mtime,state,value,eventsource,eventid,eventseverity,eventtimestamp,clock,ns"+
-		" FROM data_%d ORDER BY id LIMIT ?", c.serverID), DataLimit); err != nil {
+		" FROM data_%d"+
+		" UNION ALL"+
+		" SELECT "+
+		"id,itemid,lastlogsize,mtime,state,value,eventsource,eventid,eventseverity,eventtimestamp,clock,ns"+
+		" FROM log_%d"+
+		" ORDER BY id LIMIT ?", c.serverID, c.serverID), DataLimit); err != nil {
 		c.Errf("cannot select from data table: %s", err.Error())
-		return
+		return nil, 0, 0, err
 	}
+	for rows.Next() {
+		if result, err = c.resultFetch(rows); err != nil {
+			rows.Close()
+			return nil, 0, 0, err
+		}
+		result.persistent = false
+		results = append(results, result)
+		if result.LastLogsize == nil {
+			maxDataId = result.Id
+		} else {
+			maxLogId = result.Id
+		}
+	}
+	if err = rows.Err(); err != nil {
+		return nil, 0, 0, err
+	}
+
+	return results, maxDataId, maxLogId, nil
+}
+
+func (c *DiskCache) upload(u Uploader) (err error) {
+	var results []*AgentData
+	var maxDataId, maxLogId uint64
+
 	defer func() {
 		if err != nil && (c.lastError == nil || err.Error() != c.lastError.Error()) {
 			c.Warningf("cannot upload history data: %s", err)
@@ -172,46 +207,9 @@ func (c *DiskCache) upload(u Uploader) (err error) {
 		}
 	}()
 
-	for rows.Next() {
-		if result, err = c.resultFetch(rows); err != nil {
-			rows.Close()
-			return
-		}
-		result.persistent = false
-		results = append(results, result)
-	}
-	if err = rows.Err(); err != nil {
+	if results, maxDataId, maxLogId, err = c.resultsGet(); err != nil {
 		return
 	}
-	dataLen := len(results)
-	if dataLen != 0 {
-		maxDataId = results[dataLen-1].Id
-	}
-
-	if dataLen != DataLimit {
-		if rows, err = c.database.Query(fmt.Sprintf("SELECT "+
-			"id,itemid,lastlogsize,mtime,state,value,eventsource,eventid,eventseverity,eventtimestamp,clock,ns"+
-			" FROM log_%d ORDER BY id LIMIT ?", c.serverID),
-			DataLimit-len(results)); err != nil {
-
-			c.Errf("cannot select from log table: %s", err.Error())
-			return
-		}
-		for rows.Next() {
-			if result, err = c.resultFetch(rows); err != nil {
-				rows.Close()
-				return
-			}
-			result.persistent = true
-			results = append(results, result)
-		}
-		if err = rows.Err(); err != nil {
-			return
-		}
-		if len(results) != dataLen {
-			maxLogId = results[len(results)-1].Id
-		}
-	}
 
 	if len(results) == 0 {
 		return
@@ -248,6 +246,8 @@ func (c *DiskCache) upload(u Uploader) (err error) {
 		c.Warningf("history upload to [%s] is working again", u.Addr())
 		c.lastError = nil
 	}
+	cacheLock.Lock()
+	defer cacheLock.Unlock()
 	if maxDataId != 0 {
 		if _, err = c.database.Exec(fmt.Sprintf("DELETE FROM data_%d WHERE id<=?", c.serverID), maxDataId); err != nil {
 			return fmt.Errorf("cannot delete from data_%d: %s", c.serverID, err)
@@ -332,7 +332,11 @@ func (c *DiskCache) write(r *plugin.Result) {
 	var stmt *sql.Stmt
 
 	now := time.Now().Unix()
+	cacheLock.Lock()
+	defer cacheLock.Unlock()
+
 	if r.Persistent {
+
 		if c.oldestLog == 0 {
 			c.oldestLog = clock
 		}
@@ -340,9 +344,13 @@ func (c *DiskCache) write(r *plugin.Result) {
 			atomic.StoreUint32(&c.persistFlag, 1)
 		}
 		stmt, err = c.database.Prepare(c.insertResultTable(fmt.Sprintf("log_%d", c.serverID)))
+
 		if err != nil {
 			c.Errf("cannot prepare SQL query to insert history in log_%d : %s", c.serverID, err)
+		} else {
+			defer stmt.Close()
 		}
+
 	} else {
 		if c.oldestData == 0 {
 			c.oldestData = clock
@@ -353,6 +361,7 @@ func (c *DiskCache) write(r *plugin.Result) {
 			if _, err = c.database.Exec(query, now-c.storagePeriod); err != nil {
 				c.Errf("cannot delete old data from data_%d : %s", c.serverID, err)
 			}
+
 			c.oldestData, err = c.getOldestWriteClock(tableName("data", c.serverID))
 			if err != nil {
 				c.Errf("cannot query minimum write clock from data_%d : %s", c.serverID, err)
@@ -361,6 +370,8 @@ func (c *DiskCache) write(r *plugin.Result) {
 		stmt, err = c.database.Prepare(c.insertResultTable(fmt.Sprintf("data_%d", c.serverID)))
 		if err != nil {
 			c.Errf("cannot prepare SQL query to insert history in data_%d : %s", c.serverID, err)
+		} else {
+			defer stmt.Close()
 		}
 	}
 	if stmt != nil {
@@ -402,6 +413,7 @@ func (c *DiskCache) run() {
 
 func (c *DiskCache) updateOptions(options *agent.AgentOptions) {
 	c.storagePeriod = int64(options.PersistentBufferPeriod)
+	c.timeout = options.Timeout
 }
 
 func (c *DiskCache) insertResultTable(table string) string {
@@ -417,13 +429,19 @@ func (c *DiskCache) init(options *agent.AgentOptions) {
 	c.updateOptions(options)
 
 	var err error
+	cacheLock.Lock()
+	defer cacheLock.Unlock()
+
 	c.database, err = sql.Open("sqlite3", agent.Options.PersistentBufferFile)
 	if err != nil {
 		return
 	}
 
 	rows, err := c.database.Query(fmt.Sprintf("SELECT id FROM registry WHERE address = '%s'", c.uploader.Addr()))
+
 	if err == nil {
+		defer rows.Close()
+
 		for rows.Next() {
 			if err = rows.Scan(&c.serverID); err != nil {
 				c.Errf("cannot retrieve diskcache server ID ")
