@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -282,9 +282,18 @@ static unsigned int tls_psk_server_cb(SSL *ssl, const char *identity, unsigned c
 
 static int	zbx_set_ecdhe_parameters(SSL_CTX *ctx)
 {
-	EC_KEY	*ecdh;
 	long	res;
 	int	ret = 0;
+#if defined(OPENSSL_VERSION_MAJOR) && OPENSSL_VERSION_NUMBER >= 3	// OpenSSL 3.0.0 or newer
+#define ARRSIZE(a)	(sizeof(a) / sizeof(*a))
+
+	int	grp_list[1] = { NID_X9_62_prime256v1 };	// use curve secp256r1/prime256v1/NIST P-256
+
+	if (1 != (res = SSL_CTX_set1_groups(ctx, grp_list, ARRSIZE(grp_list))))
+		ret = -1;
+#undef ARRSIZE
+#else
+	EC_KEY	*ecdh;
 
 	// use curve secp256r1/prime256v1/NIST P-256
 
@@ -297,7 +306,7 @@ static int	zbx_set_ecdhe_parameters(SSL_CTX *ctx)
 		ret = -1;
 
 	EC_KEY_free(ecdh);
-
+#endif
 	return ret;
 }
 
@@ -605,6 +614,8 @@ static int tls_close(tls_t *tls)
 
 static void tls_free(tls_t *tls)
 {
+	if (NULL == tls)
+		return;
 	if (NULL != tls->ssl)
 		SSL_free(tls->ssl);
 	if (NULL != tls->err)
@@ -692,12 +703,14 @@ out:
 static void tls_description(tls_t *tls, char **desc)
 {
 	X509	*cert;
-	char	*peer_issuer = NULL, *peer_subject = NULL, buf[TLS_MAX_BUF_LEN], *ptr = buf;
+	char	buf[TLS_MAX_BUF_LEN], *ptr = buf;
 
 	ptr += snprintf(ptr, sizeof(buf), "%s %s", SSL_get_version(tls->ssl), SSL_get_cipher(tls->ssl));
 
 	if ((sizeof(buf) - 1 > (size_t)(ptr - buf)) && NULL != (cert = SSL_get_peer_certificate(tls->ssl)))
 	{
+		char	*peer_issuer = NULL, *peer_subject = NULL;
+
 		if (0 == tls_get_x509_name(tls, X509_get_issuer_name(cert), &peer_issuer) &&
 			0 == tls_get_x509_name(tls, X509_get_subject_name(cert), &peer_subject))
 		{
@@ -709,10 +722,13 @@ static void tls_description(tls_t *tls, char **desc)
 						peer_issuer, peer_subject);
 			}
 		}
+
+		free(peer_issuer);
+		free(peer_subject);
+		X509_free(cert);
 	}
+
 	*desc = strdup(buf);
-	free(peer_issuer);
-	free(peer_subject);
 }
 
 //*****************************************************************************
@@ -945,6 +961,7 @@ func SupportedErrMsg() string {
 }
 
 func init() {
+	log.Tracef("Calling C function \"tls_init()\"")
 	supported = C.tls_init() != -1
 
 	if !supported {
@@ -954,8 +971,10 @@ func init() {
 
 func describeCiphersuites(context unsafe.Pointer) (desc string) {
 	var cDesc *C.char
+	log.Tracef("Calling C function \"tls_describe_ciphersuites()\"")
 	C.tls_describe_ciphersuites(C.SSL_CTX_LP(context), &cDesc)
 	desc = C.GoString(cDesc)
+	log.Tracef("Calling C function \"free()\"")
 	C.free(unsafe.Pointer(cDesc))
 	return
 }
@@ -971,8 +990,10 @@ type tlsConn struct {
 func (c *tlsConn) Error() (err error) {
 	var cBuf *C.char
 	var errmsg string
+	log.Tracef("Calling C function \"tls_error()\"")
 	if c.tls != nil && 0 != C.tls_error((*C.tls_t)(c.tls), &cBuf) {
 		errmsg = C.GoString(cBuf)
+		log.Tracef("Calling C function \"free()\"")
 		C.free(unsafe.Pointer(cBuf))
 	} else {
 		errmsg = "unknown openssl error"
@@ -981,12 +1002,14 @@ func (c *tlsConn) Error() (err error) {
 }
 
 func (c *tlsConn) ready() bool {
+	log.Tracef("Calling C function \"tls_ready()\"")
 	return C.tls_ready((*C.tls_t)(c.tls)) == 1
 }
 
 // Note, don't use flushTLS() and recvTLS() concurrently
 func (c *tlsConn) flushTLS() (err error) {
 	for {
+		log.Tracef("Calling C function \"tls_recv()\"")
 		if cn := C.tls_recv((*C.tls_t)(c.tls), (*C.char)(unsafe.Pointer(&c.buf[0])), C.int(len(c.buf))); cn > 0 {
 			if c.shiftDeadline {
 				if err = c.conn.SetWriteDeadline(time.Now().Add(c.timeout)); err != nil {
@@ -1014,6 +1037,7 @@ func (c *tlsConn) recvTLS() (err error) {
 	if n, err = c.conn.Read(c.buf); err != nil {
 		return
 	}
+	log.Tracef("Calling C function \"tls_send()\"")
 	C.tls_send((*C.tls_t)(c.tls), (*C.char)(unsafe.Pointer(&c.buf[0])), C.int(n))
 	return
 }
@@ -1039,8 +1063,14 @@ func (c *tlsConn) SetWriteDeadline(t time.Time) error {
 }
 
 func (c *tlsConn) Close() (err error) {
+	log.Tracef("Calling C function \"tls_close()\"")
 	cr := C.tls_close((*C.tls_t)(c.tls))
 	c.conn.Close()
+
+	log.Tracef("Calling C function \"tls_free()\"")
+	C.tls_free((*C.tls_t)(c.tls))
+	c.tls = nil
+
 	if cr < 0 {
 		return c.Error()
 	}
@@ -1052,12 +1082,15 @@ func (c *tlsConn) verifyIssuerSubject(cfg *Config) (err error) {
 		var cSubject, cIssuer *C.char
 		if cfg.ServerCertIssuer != "" {
 			cIssuer = C.CString(cfg.ServerCertIssuer)
+			log.Tracef("Calling C function \"free()\"")
 			defer C.free(unsafe.Pointer(cSubject))
 		}
 		if cfg.ServerCertSubject != "" {
 			cSubject = C.CString(cfg.ServerCertSubject)
+			log.Tracef("Calling C function \"free()\"")
 			defer C.free(unsafe.Pointer(cSubject))
 		}
+		log.Tracef("Calling C function \"tls_validate_issuer_and_subject()\"")
 		if 0 != C.tls_validate_issuer_and_subject((*C.tls_t)(c.tls), cIssuer, cSubject) {
 			return c.Error()
 		}
@@ -1067,8 +1100,10 @@ func (c *tlsConn) verifyIssuerSubject(cfg *Config) (err error) {
 
 func (c *tlsConn) String() (desc string) {
 	var cDesc *C.char
+	log.Tracef("Calling C function \"tls_description()\"")
 	C.tls_description((*C.tls_t)(c.tls), &cDesc)
 	desc = C.GoString(cDesc)
+	log.Tracef("Calling C function \"free()\"")
 	C.free(unsafe.Pointer(cDesc))
 	return
 }
@@ -1079,10 +1114,13 @@ type Client struct {
 }
 
 func (c *Client) checkConnection() (err error) {
+	log.Tracef("Calling C function \"tls_connected()\"")
 	if C.tls_connected((*C.tls_t)(c.tls)) == C.int(1) {
 		return
 	}
+	log.Tracef("Calling C function \"tls_connected()\"")
 	for C.tls_connected((*C.tls_t)(c.tls)) != C.int(1) {
+		log.Tracef("Calling C function \"tls_handshake()\"")
 		cRet := C.tls_handshake((*C.tls_t)(c.tls))
 		if cRet == 0 {
 			break
@@ -1105,6 +1143,7 @@ func (c *Client) Write(b []byte) (n int, err error) {
 	if err = c.checkConnection(); err != nil {
 		return
 	}
+	log.Tracef("Calling C function \"tls_write()\"")
 	cRet := C.tls_write((*C.tls_t)(c.tls), (*C.char)(unsafe.Pointer(&b[0])), C.int(len(b)))
 	if cRet <= 0 {
 		return 0, c.Error()
@@ -1120,6 +1159,7 @@ func (c *Client) Read(b []byte) (n int, err error) {
 		if err = c.checkConnection(); err != nil {
 			return
 		}
+		log.Tracef("Calling C function \"tls_read()\"")
 		cRet := C.tls_read((*C.tls_t)(c.tls), (*C.char)(unsafe.Pointer(&b[0])), C.int(len(b)))
 		if cRet > 0 {
 			return int(cRet), nil
@@ -1149,13 +1189,16 @@ func NewClient(nc net.Conn, cfg *Config, timeout time.Duration, shiftDeadline bo
 		cSecret = C.CString(cfg.PSKKey)
 
 		defer func() {
+			log.Tracef("Calling C function \"free()\"")
 			C.free(unsafe.Pointer(cUser))
+			log.Tracef("Calling C function \"free()\"")
 			C.free(unsafe.Pointer(cSecret))
 		}()
 		context = pskContext
 	}
 
 	// for TLS we overwrite the timeoutMode and force it to move on every read or write
+	log.Tracef("Calling C function \"tls_new_client()\"")
 	c := &Client{
 		tlsConn: tlsConn{
 			conn:          nc,
@@ -1165,6 +1208,7 @@ func NewClient(nc net.Conn, cfg *Config, timeout time.Duration, shiftDeadline bo
 			shiftDeadline: shiftDeadline,
 		},
 	}
+	log.Tracef("Calling C function \"tls_free()\"")
 	runtime.SetFinalizer(c, func(c *Client) { C.tls_free((*C.tls_t)(c.tls)) })
 
 	if !c.ready() {
@@ -1190,10 +1234,12 @@ type Server struct {
 }
 
 func (s *Server) checkConnection() (err error) {
+	log.Tracef("Calling C function \"tls_connected()\"")
 	if C.tls_connected((*C.tls_t)(s.tls)) == C.int(1) {
 		return
 	}
 	for {
+		log.Tracef("Calling C function \"tls_accept()\"")
 		cRet := C.tls_accept((*C.tls_t)(s.tls))
 		if cRet == 0 {
 			break
@@ -1216,6 +1262,7 @@ func (s *Server) Write(b []byte) (n int, err error) {
 	if err = s.checkConnection(); err != nil {
 		return
 	}
+	log.Tracef("Calling C function \"tls_write()\"")
 	cRet := C.tls_write((*C.tls_t)(s.tls), (*C.char)(unsafe.Pointer(&b[0])), C.int(len(b)))
 	if cRet <= 0 {
 		return 0, s.Error()
@@ -1229,6 +1276,7 @@ func (s *Server) Read(b []byte) (n int, err error) {
 		if err = s.checkConnection(); err != nil {
 			return
 		}
+		log.Tracef("Calling C function \"tls_read()\"")
 		cRet := C.tls_read((*C.tls_t)(s.tls), (*C.char)(unsafe.Pointer(&b[0])), C.int(len(b)))
 		if cRet > 0 {
 			return int(cRet), nil
@@ -1253,7 +1301,9 @@ func NewServer(nc net.Conn, cfg *Config, b []byte, timeout time.Duration, shiftD
 		cSecret = C.CString(cfg.PSKKey)
 
 		defer func() {
+			log.Tracef("Calling C function \"free()\"")
 			C.free(unsafe.Pointer(cUser))
+			log.Tracef("Calling C function \"free()\"")
 			C.free(unsafe.Pointer(cSecret))
 		}()
 	}
@@ -1264,6 +1314,7 @@ func NewServer(nc net.Conn, cfg *Config, b []byte, timeout time.Duration, shiftD
 	}
 
 	// for TLS we overwrite the timeoutMode and force it to move on every read or write
+	log.Tracef("Calling C function \"tls_new_server()\"")
 	s := &Server{
 		tlsConn: tlsConn{
 			conn:          nc,
@@ -1273,12 +1324,14 @@ func NewServer(nc net.Conn, cfg *Config, b []byte, timeout time.Duration, shiftD
 			shiftDeadline: shiftDeadline,
 		},
 	}
+	log.Tracef("Calling C function \"tls_free()\"")
 	runtime.SetFinalizer(s, func(s *Server) { C.tls_free((*C.tls_t)(s.tls)) })
 
 	if !s.ready() {
 		return nil, s.Error()
 	}
 
+	log.Tracef("Calling C function \"tls_send()\"")
 	C.tls_send((*C.tls_t)(s.tls), (*C.char)(unsafe.Pointer(&b[0])), C.int(len(b)))
 
 	if err = s.checkConnection(); err != nil {
@@ -1317,11 +1370,13 @@ type Config struct {
 }
 
 func CopyrightMessage() (message string) {
+	log.Tracef("Calling C function \"tls_version()\"")
 	version := C.tls_version()
 	if version == nil {
 		return ""
 	}
 
+	log.Tracef("Calling C function \"tls_version_static()\"")
 	return fmt.Sprintf("\n\nThis product includes software developed by the OpenSSL Project\n"+
 		"for use in the OpenSSL Toolkit (http://www.openssl.org/).\n\n"+
 		"Compiled with %s\nRunning with %s\n", C.GoString(C.tls_version_static()), C.GoString(version))
@@ -1332,9 +1387,11 @@ func Init(config *Config) (err error) {
 		return errors.New(SupportedErrMsg())
 	}
 	if pskContext != nil {
+		log.Tracef("Calling C function \"tls_free_context()\"")
 		C.tls_free_context(C.SSL_CTX_LP(pskContext))
 	}
 	if defaultContext != nil {
+		log.Tracef("Calling C function \"tls_free_context()\"")
 		C.tls_free_context(C.SSL_CTX_LP(defaultContext))
 	}
 
@@ -1343,28 +1400,36 @@ func Init(config *Config) (err error) {
 		cCaFile = C.CString(config.CAFile)
 		cCertFile = C.CString(config.CertFile)
 		cKeyFile = C.CString(config.KeyFile)
+		log.Tracef("Calling C function \"free()\"")
 		defer C.free(unsafe.Pointer(cCaFile))
+		log.Tracef("Calling C function \"free()\"")
 		defer C.free(unsafe.Pointer(cCertFile))
+		log.Tracef("Calling C function \"free()\"")
 		defer C.free(unsafe.Pointer(cKeyFile))
 
 		if config.CRLFile != "" {
 			cCrlFile = C.CString(config.CRLFile)
+			log.Tracef("Calling C function \"free()\"")
 			defer C.free(unsafe.Pointer(cCrlFile))
 		}
 	}
 
+	log.Tracef("Calling C function \"tls_new_context()\"")
 	if defaultContext = unsafe.Pointer(C.tls_new_context(cCaFile, cCrlFile, cCertFile, cKeyFile, &cErr)); defaultContext == nil {
 		err = fmt.Errorf("cannot initialize default TLS context: %s", C.GoString(cErr))
+		log.Tracef("Calling C function \"free()\"")
 		C.free(unsafe.Pointer(cErr))
 		return
 	}
 
+	log.Tracef("Calling C function \"tls_new_context()\"")
 	if pskContext = unsafe.Pointer(C.tls_new_context(cNULL, cNULL, cNULL, cNULL, &cErr)); pskContext == nil {
 		err = fmt.Errorf("cannot initialize PSK TLS context: %s", C.GoString(cErr))
+		log.Tracef("Calling C function \"free()\"")
 		C.free(unsafe.Pointer(cErr))
 		return
 	}
-
+	log.Tracef("Calling C function \"tls_version()\"")
 	log.Infof("OpenSSL library (%s) initialized", C.GoString(C.tls_version()))
 	log.Debugf("default context ciphersuites:%s", describeCiphersuites(defaultContext))
 	log.Debugf("psk context ciphersuites:%s", describeCiphersuites(pskContext))
