@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,15 +29,15 @@ import (
 
 const (
 	APPLICATION_NAME        = "Zabbix Agent"
-	ZABBIX_REVDATE          = "18 October 2021"
+	ZABBIX_REVDATE          = "19 November 2024"
 	ZABBIX_VERSION_MAJOR    = 5
 	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 17
+	ZABBIX_VERSION_PATCH    = 45
 	ZABBIX_VERSION_RC       = ""
-	ZABBIX_VERSION_RC_NUM   = "2400"
-	ZABBIX_VERSION_REVISION = "0a4ac3dabc"
-	copyrightMessage        = "Copyright (C) 2021 Zabbix SIA\n" +
-		"License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>.\n" +
+	ZABBIX_VERSION_RC_NUM   = "1400"
+	ZABBIX_VERSION_REVISION = "0cce23f8c58"
+	copyrightMessage        = "Copyright (C) 2024 Zabbix SIA\n" +
+		"License GPLv2+: GNU GPL version 2 or later <https://www.gnu.org/licenses/>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
 		"the license. There is NO WARRANTY, to the extent permitted by law."
 )
