@@ -1,8 +1,8 @@
-// +build !windows
+//go:build !windows
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -62,7 +62,9 @@ func execute(s string, timeout time.Duration, strict bool) (string, error) {
 
 	// we need to check error after t.Stop so we can inform the user if timeout was reached and Zabbix agent2 terminated the command
 	if strict && werr != nil {
-		return "", fmt.Errorf("Command execution failed: %s", werr)
+		log.Debugf("Command [%s] execution failed: %s\n%s", s, werr, b.String())
+
+		return "", fmt.Errorf("Command execution failed: %w", werr)
 	}
 
 	if maxExecuteOutputLenB <= len(b.String()) {
