@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -140,6 +140,8 @@ import (
 	"errors"
 	"time"
 	"unsafe"
+
+	"zabbix.com/pkg/log"
 )
 
 type EventLogItem struct {
@@ -161,16 +163,20 @@ type EventLogResult struct {
 }
 
 func ProcessEventLogCheck(data unsafe.Pointer, item *EventLogItem, refresh int, cblob unsafe.Pointer) {
+	log.Tracef("Calling C function \"metric_set_refresh()\"")
 	C.metric_set_refresh(C.ZBX_ACTIVE_METRIC_LP(data), C.int(refresh))
 
 	var clastLogsizeSent, clastLogsizeLast C.zbx_uint64_t
 	var cstate, cmtime C.int
+	log.Tracef("Calling C function \"metric_get_meta()\"")
 	C.metric_get_meta(C.ZBX_ACTIVE_METRIC_LP(data), &clastLogsizeSent, &cmtime)
 	clastLogsizeLast = clastLogsizeSent
 
+	log.Tracef("Calling C function \"new_eventlog_result()\"")
 	result := C.new_eventlog_result(C.int(item.Output.PersistSlotsAvailable()))
 
 	var cerrmsg *C.char
+	log.Tracef("Calling C function \"process_eventlog_check()\"")
 	ret := C.process_eventlog_check(C.char_lp_t(unsafe.Pointer(result)), 0, C.zbx_vector_ptr_lp_t(cblob),
 		C.ZBX_ACTIVE_METRIC_LP(data), C.zbx_process_value_func_t(C.process_eventlog_value_cb), &clastLogsizeSent,
 		&cerrmsg)
@@ -183,6 +189,7 @@ func ProcessEventLogCheck(data unsafe.Pointer, item *EventLogItem, refresh int,
 	if logTs.Before(item.LastTs) {
 		logTs = item.LastTs
 	}
+	log.Tracef("Calling C function \"get_eventlog_value()\"")
 	for i := 0; C.get_eventlog_value(result, C.int(i), &cvalue, &csource, &clogeventid, &cseverity, &ctimestamp, &cstate,
 		&clastlogsize) != C.FAIL; i++ {
 
@@ -218,16 +225,19 @@ func ProcessEventLogCheck(data unsafe.Pointer, item *EventLogItem, refresh int,
 		item.Results = append(item.Results, &r)
 		logTs = logTs.Add(time.Nanosecond)
 	}
+	log.Tracef("Calling C function \"free_eventlog_result()\"")
 	C.free_eventlog_result(result)
 
 	item.LastTs = logTs
 
 	if ret == C.FAIL {
+		log.Tracef("Calling C function \"metric_set_unsupported()\"")
 		C.metric_set_unsupported(C.ZBX_ACTIVE_METRIC_LP(data))
 
 		var err error
 		if cerrmsg != nil {
 			err = errors.New(C.GoString(cerrmsg))
+			log.Tracef("Calling C function \"free()\"")
 			C.free(unsafe.Pointer(cerrmsg))
 		} else {
 			err = errors.New("Unknown error.")
@@ -238,9 +248,11 @@ func ProcessEventLogCheck(data unsafe.Pointer, item *EventLogItem, refresh int,
 		}
 		item.Results = append(item.Results, result)
 	} else {
+		log.Tracef("Calling C function \"metric_set_supported()\"")
 		ret := C.metric_set_supported(C.ZBX_ACTIVE_METRIC_LP(data), clastLogsizeSent, 0, clastLogsizeLast, 0)
 
 		if ret == Succeed {
+			log.Tracef("Calling C function \"metric_get_meta()\"")
 			C.metric_get_meta(C.ZBX_ACTIVE_METRIC_LP(data), &clastLogsizeLast, &cmtime)
 			result := EventLogResult{
 				Ts:          time.Now(),
