@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 package ceph
 
 import (
-	"io/ioutil"
 	"log"
 	"os"
 	"strings"
@@ -32,15 +31,15 @@ var fixtures map[command][]byte
 const cmdBroken command = "broken"
 
 func TestMain(m *testing.M) {
-	var err error
-
 	fixtures = make(map[command][]byte)
 
 	for _, cmd := range []command{
 		cmdDf, cmdPgDump, cmdOSDCrushRuleDump, cmdOSDCrushTree, cmdOSDDump, cmdHealth, cmdStatus,
 	} {
-		fixtures[cmd], err = ioutil.ReadFile("testdata/" +
-			strings.ReplaceAll(string(cmd), " ", "_") + ".json")
+		var err error
+		fixtures[cmd], err = os.ReadFile(
+			"testdata/" + strings.ReplaceAll(string(cmd), " ", "_") + ".json",
+		)
 		if err != nil {
 			log.Fatal(err)
 		}
