@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@ type PluginOptions struct {
 
 	// Sessions stores pre-defined named sets of connections settings.
 	Sessions map[string]conf.Session `conf:"optional"`
+
+	// Default stores default connection parameter values from configuration file
+	Default conf.Session `conf:"optional"`
 }
 
 // Configure implements the Configurator interface.
