@@ -1,8 +1,9 @@
+//go:build oracle_tests
 // +build oracle_tests
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,9 +27,9 @@ import (
 	"testing"
 	"time"
 
-	"zabbix.com/pkg/uri"
-
+	"github.com/godror/godror"
 	"github.com/omeid/go-yarn"
+	"zabbix.com/pkg/uri"
 )
 
 func TestConnManager_closeUnused(t *testing.T) {
