@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,10 +21,13 @@ package oracle
 
 import (
 	"context"
+	"errors"
 	"net/http"
 	"net/url"
+	"strings"
 	"time"
 
+	"zabbix.com/pkg/metric"
 	"zabbix.com/pkg/uri"
 	"zabbix.com/pkg/zbxerr"
 
@@ -37,6 +40,14 @@ const (
 	pluginName = "Oracle"
 	hkInterval = 10
 	sqlExt     = ".sql"
+
+	sysdbaExtension  = " as sysdba"
+	sysasmExtension  = " as sysoper"
+	sysoperExtension = " as sysasm"
+
+	sysdbaPrivelage  = "sysdba"
+	sysasmPrivelage  = "sysoper"
+	sysoperPrivelage = "sysasm"
 )
 
 // Plugin inherits plugin.Base and store plugin-specific data.
@@ -51,22 +62,26 @@ var impl Plugin
 
 // Export implements the Exporter interface.
 func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result interface{}, err error) {
-	var extraParams []string
+	params, extraParams, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
+	if err != nil {
+		return nil, err
+	}
 
-	params, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
+	err = metric.SetDefaults(params, hc, p.options.Default)
 	if err != nil {
 		return nil, err
 	}
 
 	service := url.QueryEscape(params["Service"])
 
-	uri, err := uri.NewWithCreds(params["URI"]+"?service="+service, params["User"], params["Password"], uriDefaults)
+	user, privilege, err := splitUserPrivilege(params)
 	if err != nil {
-		return nil, err
+		return nil, zbxerr.ErrorInvalidParams.Wrap(err)
 	}
 
-	if len(rawParams) > len(params) {
-		extraParams = rawParams[len(params):]
+	uri, err := uri.NewWithCreds(params["URI"]+"?service="+service, user, params["Password"], uriDefaults)
+	if err != nil {
+		return nil, err
 	}
 
 	handleMetric := getHandlerFunc(key)
@@ -74,7 +89,7 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri)
+	conn, err := p.connMgr.GetConnection(connDetails{*uri, privilege})
 	if err != nil {
 		// Special logic of processing connection errors should be used if oracle.ping is requested
 		// because it must return pingFailed if any error occurred.
@@ -122,3 +137,27 @@ func (p *Plugin) Stop() {
 	p.connMgr.Destroy()
 	p.connMgr = nil
 }
+
+func splitUserPrivilege(params map[string]string) (user, privilege string, err error) {
+	var ok bool
+	user, ok = params["User"]
+	if !ok {
+		return "", "", errors.New("missing parameter 'User'")
+	}
+
+	var extension string
+
+	switch true {
+	case strings.HasSuffix(strings.ToLower(user), sysdbaExtension):
+		privilege = sysdbaPrivelage
+		extension = sysdbaExtension
+	case strings.HasSuffix(strings.ToLower(user), sysoperExtension):
+		privilege = sysoperPrivelage
+		extension = sysoperExtension
+	case strings.HasSuffix(strings.ToLower(user), sysasmExtension):
+		privilege = sysasmPrivelage
+		extension = sysasmExtension
+	}
+
+	return user[:len(user)-len(extension)], privilege, nil
+}
