@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,9 @@ import (
 	_ "zabbix.com/plugins/kernel"
 	_ "zabbix.com/plugins/log"
 	_ "zabbix.com/plugins/memcached"
+	_ "zabbix.com/plugins/mongodb"
 	_ "zabbix.com/plugins/mysql"
+	_ "zabbix.com/plugins/net/dns"
 	_ "zabbix.com/plugins/net/netif"
 	_ "zabbix.com/plugins/net/tcp"
 	_ "zabbix.com/plugins/net/udp"
@@ -33,17 +35,23 @@ import (
 	_ "zabbix.com/plugins/postgres"
 	_ "zabbix.com/plugins/proc"
 	_ "zabbix.com/plugins/redis"
+	_ "zabbix.com/plugins/smart"
 	_ "zabbix.com/plugins/system/cpu"
+	_ "zabbix.com/plugins/system/hw"
+	_ "zabbix.com/plugins/system/sw"
 	_ "zabbix.com/plugins/system/swap"
 	_ "zabbix.com/plugins/system/uname"
 	_ "zabbix.com/plugins/system/uptime"
+	_ "zabbix.com/plugins/system/users"
 	_ "zabbix.com/plugins/systemd"
 	_ "zabbix.com/plugins/systemrun"
 	_ "zabbix.com/plugins/vfs/dev"
+	_ "zabbix.com/plugins/vfs/dir"
 	_ "zabbix.com/plugins/vfs/file"
 	_ "zabbix.com/plugins/vfs/fs"
-	_ "zabbix.com/plugins/web"
+	_ "zabbix.com/plugins/vm/memory"
+	_ "zabbix.com/plugins/web/certificate"
+	_ "zabbix.com/plugins/web/page"
 	_ "zabbix.com/plugins/zabbix/async"
 	_ "zabbix.com/plugins/zabbix/stats"
-	_ "zabbix.com/plugins/zabbix/sync"
 )
