@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@ import (
 	"net/url"
 	"time"
 
+	"zabbix.com/pkg/metric"
+	"zabbix.com/pkg/tlsconfig"
 	"zabbix.com/pkg/uri"
 	"zabbix.com/pkg/zbxerr"
 
@@ -51,13 +53,22 @@ var impl Plugin
 
 // Export implements the Exporter interface.
 func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result interface{}, err error) {
-	var extraParams []string
-
-	params, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
+	params, extraParams, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
 	}
 
+	err = metric.SetDefaults(params, hc, p.options.Default)
+	if err != nil {
+		return nil, err
+	}
+
+	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
+		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
+	if err != nil {
+		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
+	}
+
 	dbname := url.QueryEscape(params["Database"])
 
 	uri, err := uri.NewWithCreds(params["URI"]+"?dbname="+dbname, params["User"], params["Password"], uriDefaults)
@@ -65,16 +76,12 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 		return nil, err
 	}
 
-	if len(rawParams) > len(params) {
-		extraParams = rawParams[len(params):]
-	}
-
 	handleMetric := getHandlerFunc(key)
 	if handleMetric == nil {
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri)
+	conn, err := p.connMgr.GetConnection(*uri, details)
 	if err != nil {
 		// Special logic of processing connection errors should be used if pgsql.ping is requested
 		// because it must return pingFailed if any error occurred.
