@@ -1,8 +1,9 @@
+//go:build linux
 // +build linux
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -401,6 +402,7 @@ func (p *Plugin) Export(key string, params []string, ctx plugin.ContextProvider)
 		ticks *= 1e12
 		ticks /= uint64(tail.timestamp.Sub(head.timestamp))
 
+		log.Tracef("Calling C function \"sysconf()\"")
 		return math.Round(float64(ticks)/float64(C.sysconf(C._SC_CLK_TCK))) / 10, nil
 	}
 	stats := &cpuUtilStats{accessed: now, history: make([]cpuUtilData, maxHistory)}
