@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ package redis
 
 import (
 	"context"
+	"errors"
 	"sync"
 	"time"
 
@@ -32,6 +33,8 @@ import (
 
 const hkInterval = 10
 
+var errMasterDown = errors.New("MASTERDOWN Link with MASTER is down and slave-serve-stale-data is set to 'no'.")
+
 type redisClient interface {
 	Query(cmd radix.CmdAction) error
 }
@@ -149,6 +152,12 @@ func (c *ConnManager) create(uri uri.URI) (*RedisConn, error) {
 			err = conn.Do(radix.Cmd(nil, "CLIENT", "SETNAME", clientName))
 		}
 
+		// Older redis servers return this as an error and the connection is present,
+		// and redis-cli does not return this error but continues
+		if err != nil && err.Error() == errMasterDown.Error() && conn != nil {
+			return conn, nil
+		}
+
 		return conn, err
 	}
 
