@@ -1,8 +1,9 @@
+//go:build !windows
 // +build !windows
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,6 +24,7 @@ package smart
 
 import (
 	"fmt"
+	"os/exec"
 	"time"
 
 	"zabbix.com/pkg/zbxcmd"
@@ -36,15 +38,25 @@ func (p *Plugin) executeSmartctl(args string, strict bool) ([]byte, error) {
 	}
 
 	var out string
-
 	var err error
 
-	if strict {
-		out, err = zbxcmd.ExecuteStrict(fmt.Sprintf("sudo %s %s", path, args), time.Second*time.Duration(p.options.Timeout))
-	} else {
-		out, err = zbxcmd.Execute(fmt.Sprintf("sudo %s %s", path, args), time.Second*time.Duration(p.options.Timeout))
+	_, err = exec.LookPath(path)
+	if err != nil {
+		return nil, err
 	}
 
+	executable := fmt.Sprintf("sudo -n %s %s", path, args)
+
+	p.Tracef("executing smartctl command: %s", executable)
+
+	if strict {
+		out, err = zbxcmd.ExecuteStrict(executable, time.Second*time.Duration(p.options.Timeout))
+	} else {
+		out, err = zbxcmd.Execute(executable, time.Second*time.Duration(p.options.Timeout))
+	}
+
+	p.Tracef("command %s smartctl raw response: %s", executable, out)
+
 	if err != nil {
 		return nil, err
 	}
