@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,16 +31,18 @@ import "C"
 import (
 	"syscall"
 	"unsafe"
+
+	"zabbix.com/pkg/log"
 )
 
 func decode(encoder string, inbuf []byte) (outbuf []byte) {
 
 	if "" == encoder {
-		if len(inbuf)>3 && 0xef == inbuf[0] && 0xbb == inbuf[1] && 0xbf == inbuf[2] {
+		if len(inbuf) > 3 && 0xef == inbuf[0] && 0xbb == inbuf[1] && 0xbf == inbuf[2] {
 			encoder = "UTF-8"
-		} else if len(inbuf)>2 && 0xff == inbuf[0] && 0xfe == inbuf[1] {
+		} else if len(inbuf) > 2 && 0xff == inbuf[0] && 0xfe == inbuf[1] {
 			encoder = "UTF-16LE"
-		} else if len(inbuf)>2 && 0xfe == inbuf[0] && 0xff == inbuf[1] {
+		} else if len(inbuf) > 2 && 0xfe == inbuf[0] && 0xff == inbuf[1] {
 			encoder = "UTF-16BE"
 		} else {
 			return inbuf
@@ -48,10 +50,13 @@ func decode(encoder string, inbuf []byte) (outbuf []byte) {
 	}
 
 	tocode := C.CString("UTF-8")
+	log.Tracef("Calling C function \"free()\"")
 	defer C.free(unsafe.Pointer(tocode))
 	fromcode := C.CString(encoder)
+	log.Tracef("Calling C function \"free()\"")
 	defer C.free(unsafe.Pointer(fromcode))
 
+	log.Tracef("Calling C function \"iconv_open()\"")
 	cd, err := C.iconv_open(tocode, fromcode)
 
 	if err != nil {
@@ -65,6 +70,7 @@ func decode(encoder string, inbuf []byte) (outbuf []byte) {
 	for {
 		inptr := (*C.char)(unsafe.Pointer(&inbuf[len(inbuf)-int(inbytes)]))
 		outptr := (*C.char)(unsafe.Pointer(&outbuf[len(outbuf)-int(outbytes)]))
+		log.Tracef("Calling C function \"call_iconv()\"")
 		_, err := C.call_iconv(cd, inptr, &inbytes, outptr, &outbytes)
 		if err == nil || err.(syscall.Errno) != syscall.E2BIG {
 			break
@@ -75,8 +81,9 @@ func decode(encoder string, inbuf []byte) (outbuf []byte) {
 		outbuf = tmp
 	}
 	outbuf = outbuf[:len(outbuf)-int(outbytes)]
+	log.Tracef("Calling C function \"iconv_close()\"")
 	C.iconv_close(cd)
-	if len(outbuf)>3 && 0xef == outbuf[0] && 0xbb == outbuf[1] && 0xbf == outbuf[2] {
+	if len(outbuf) > 3 && 0xef == outbuf[0] && 0xbb == outbuf[1] && 0xbf == outbuf[2] {
 		outbuf = outbuf[3:]
 	}
 	return
