@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -121,8 +121,11 @@ func (p *Plugin) export(params []string, getStats func(string) (*FsStats, error)
 			return nil, errors.New("Invalid second parameter.")
 		}
 	}
+
+	fsCaller := p.newFSCaller(getStats, 1)
+
 	var stats *FsStats
-	if stats, err = getStats(params[0]); err != nil {
+	if stats, err = fsCaller.run(params[0]); err != nil {
 		return
 	}
 
