@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,10 +20,12 @@
 package vfsfs
 
 import (
+	"fmt"
 	"syscall"
 
 	"golang.org/x/sys/windows"
 	"zabbix.com/pkg/plugin"
+	"zabbix.com/pkg/zbxerr"
 )
 
 func getMountPaths() (paths []string, err error) {
@@ -33,7 +35,7 @@ func getMountPaths() (paths []string, err error) {
 	if h, err = windows.FindFirstVolume(&volume[0], uint32(len(volume))); err != nil {
 		return
 	}
-	defer windows.FindClose(h)
+	defer windows.FindVolumeClose(h)
 
 	var result []string
 	var size uint32
@@ -41,6 +43,8 @@ func getMountPaths() (paths []string, err error) {
 		for {
 			if err = windows.GetVolumePathNamesForVolumeName(&volume[0], &buffer[0], uint32(len(buffer)), &size); err != nil {
 				if err.(syscall.Errno) != syscall.ERROR_MORE_DATA {
+					err = zbxerr.New(fmt.Sprintf("Cannot obtain a list of filesystems. Volume: %s Error",
+						windows.UTF16ToString(volume))).Wrap(err)
 					return
 				}
 				buffer = make([]uint16, size)
