@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -365,3 +365,34 @@ void	zbx_list_iterator_update(zbx_list_iterator_t *iterator)
 	if (NULL != iterator->current)
 		iterator->next = iterator->current->next;
 }
+
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: removes next iterator value from list                             *
+ *                                                                            *
+ * Parameters: iterator - [IN] list iterator                                  *
+ *                                                                            *
+ * Return value: The data held by the removed item.                           *
+ *                                                                            *
+ ******************************************************************************/
+void	*zbx_list_iterator_remove_next(zbx_list_iterator_t *iterator)
+{
+	zbx_list_item_t	*next;
+	void		*data;
+
+	if (NULL == iterator->current || NULL == iterator->next)
+		return NULL;
+
+	next = iterator->next;
+	data = next->data;
+
+	if (iterator->list->tail == next)
+		iterator->list->tail = iterator->current;
+
+	iterator->current->next = next->next;
+	iterator->next = next->next;
+	iterator->list->mem_free_func(next);
+
+	return data;
+}
