@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -444,6 +444,12 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 
 	if (ZBX_PROTO_ERROR == rc)
 	{
+		if (EINTR == zbx_socket_last_error() && SUCCEED == zbx_alarm_timed_out())
+		{
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot find prompt after command execution: "
+					"execution timed out"));
+			goto fail;
+		}
 		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot find prompt after command execution: %s",
 				strerror_from_system(zbx_socket_last_error())));
 		goto fail;
