@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -941,17 +941,19 @@ static int	DBpatch_2010101(void)
 		{
 			char	*param = NULL;
 			size_t	param_alloc = 0, param_offset = 0;
-			int	nparam;
 
 			zbx_strncpy_alloc(&param, &param_alloc, &param_offset, row[1] + 15, key_len - 16);
 
-			if (1 != (nparam = num_param(param)))
+			if (1 != num_param(param))
 			{
 				if (FAIL == (ret = quote_key_param(&param, 0)))
+				{
 					error_message = zbx_dsprintf(error_message, "unique description"
 							" \"%s\" contains invalid symbols and cannot be quoted", param);
+				}
 			}
-			if (FAIL == (ret = quote_key_param(&dsn, 0)))
+
+			if (SUCCEED == ret && FAIL == (ret = quote_key_param(&dsn, 0)))
 			{
 				error_message = zbx_dsprintf(error_message, "data source name"
 						" \"%s\" contains invalid symbols and cannot be quoted", dsn);
