@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the envied warranty of
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
@@ -29,8 +29,6 @@
 #include "duktape.h"
 
 #define ZBX_ES_MEMORY_LIMIT	(1024 * 1024 * 64)
-#define ZBX_ES_TIMEOUT		10
-
 #define ZBX_ES_STACK_LIMIT	1000
 
 /* maximum number of consequent runtime errors after which it's treated as fatal error */
@@ -122,6 +120,127 @@ static void	es_free(void *udata, void *ptr)
 	}
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Purpose: decodes 3-byte utf-8 sequence                                     *
+ *                                                                            *
+ * Parameters: ptr - [IN] pointer to the 3 byte sequence                      *
+ *             out - [OUT] decoded value                                      *
+ *                                                                            *
+ * Return value: SUCCEED                                                      *
+ *               FAIL                                                         *
+ *                                                                            *
+ ******************************************************************************/
+static int	utf8_decode_3byte_sequence(const char *ptr, zbx_uint32_t *out)
+{
+	*out = ((unsigned char)*ptr++ & 0xFu) << 12;
+	if (0x80 != (*ptr & 0xC0))
+		return FAIL;
+
+	*out |= ((unsigned char)*ptr++ & 0x3Fu) << 6;
+	if (0x80 != (*ptr & 0xC0))
+		return FAIL;
+
+	*out |= ((unsigned char)*ptr & 0x3Fu);
+
+	return SUCCEED;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: decodes duktape string into utf-8                                 *
+ *                                                                            *
+ * Parameters: duk_str - [IN] pointer to the first char of NULL terminated    *
+ *                       Duktape string                                       *
+ *             out_str - [OUT] on success, pointer to pointer to the first    *
+ *                       char of allocated NULL terminated UTF8 string        *
+ *                                                                            *
+ * Return value: SUCCEED                                                      *
+ *               FAIL                                                         *
+ *                                                                            *
+ ******************************************************************************/
+int	es_duktape_string_decode(const char *duk_str, char **out_str)
+{
+	const char	*in, *end;
+	char		*out;
+	size_t		len;
+
+	len = strlen(duk_str);
+	out = *out_str = zbx_malloc(*out_str, len + 1);
+	end = duk_str + len;
+
+	for (in = duk_str; in < end;)
+	{
+		if (0x7f >= (unsigned char)*in)
+		{
+			*out++ = *in++;
+			continue;
+		}
+
+		if (0xdf >= (unsigned char)*in)
+		{
+			if (2 > end - in)
+				goto fail;
+
+			*out++ = *in++;
+			*out++ = *in++;
+			continue;
+		}
+
+		if (0xef >= (unsigned char)*in)
+		{
+			zbx_uint32_t	c1, c2, u;
+
+			if (3 > end - in || FAIL == utf8_decode_3byte_sequence(in, &c1))
+				goto fail;
+
+			if (0xd800 > c1 || 0xdbff < c1)
+			{
+				/* normal 3-byte sequence */
+				*out++ = *in++;
+				*out++ = *in++;
+				*out++ = *in++;
+				continue;
+			}
+
+			/* decode unicode supplementary character represented as surrogate pair */
+			in += 3;
+			if (3 > end - in || FAIL == utf8_decode_3byte_sequence(in, &c2) || 0xdc00 > c2 || 0xdfff < c2)
+				goto fail;
+
+			u = 0x10000 + ((((zbx_uint32_t)c1 & 0x3ff) << 10) | (c2 & 0x3ff));
+			*out++ = (char)(0xf0 |  u >> 18);
+			*out++ = (char)(0x80 | (u >> 12 & 0x3f));
+			*out++ = (char)(0x80 | (u >> 6 & 0x3f));
+			*out++ = (char)(0x80 | (u & 0x3f));
+			in += 3;
+			continue;
+		}
+
+		/* duktape can use the four-byte UTF-8 style supplementary character sequence */
+		if (0xf0 >= (unsigned char)*in)
+		{
+			if (4 > end - in)
+				goto fail;
+
+			*out++ = *in++;
+			*out++ = *in++;
+			*out++ = *in++;
+			*out++ = *in++;
+			continue;
+		}
+
+		goto fail;
+	}
+	*out = '\0';
+
+	return SUCCEED;
+fail:
+	zbx_free(*out_str);
+
+	return FAIL;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: zbx_es_check_timeout                                             *
@@ -214,13 +333,11 @@ int	zbx_es_init_env(zbx_es_t *es, char **error)
 
 	/* put environment object to be accessible from duktape C calls */
 	duk_push_global_stash(es->env->ctx);
+
+	duk_push_string(es->env->ctx, "\xff""\xff""zbx_env");
 	duk_push_pointer(es->env->ctx, (void *)es->env);
-	if (1 != duk_put_prop_string(es->env->ctx, -2, "\xff""\xff""zbx_env"))
-	{
-		*error = zbx_strdup(*error, duk_safe_to_string(es->env->ctx, -1));
-		duk_pop(es->env->ctx);
-		return FAIL;
-	}
+	duk_def_prop(es->env->ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_CLEAR_WRITABLE | DUK_DEFPROP_HAVE_ENUMERABLE |
+			DUK_DEFPROP_HAVE_CONFIGURABLE);
 
 	/* initialize CurlHttpRequest prototype */
 	if (FAIL == zbx_es_init_httprequest(es, error))
@@ -439,6 +556,8 @@ int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size,
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() param:%s", __func__, param);
 
 	zbx_timespec(&es->env->start_time);
+	es->env->http_req_objects = 0;
+	es->env->logged_msgs = 0;
 
 	if (NULL != es->env->json)
 	{
@@ -500,7 +619,7 @@ int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size,
 		}
 		else
 		{
-			if (SUCCEED != (ret = zbx_cesu8_to_utf8(duk_safe_to_string(es->env->ctx, -1), output)))
+			if (SUCCEED != (ret = es_duktape_string_decode(duk_safe_to_string(es->env->ctx, -1), output)))
 				*error = zbx_strdup(*error, "could not convert return value to utf8");
 			else
 				zabbix_log(LOG_LEVEL_DEBUG, "%s() output:'%s'", __func__, *output);
@@ -563,3 +682,18 @@ void	zbx_es_debug_disable(zbx_es_t *es)
 	zbx_json_free(es->env->json);
 	zbx_free(es->env->json);
 }
+
+zbx_es_env_t	*zbx_es_get_env(duk_context *ctx)
+{
+	zbx_es_env_t	*env;
+
+	duk_push_global_stash(ctx);
+
+	if (1 != duk_get_prop_string(ctx, -1, "\xff""\xff""zbx_env"))
+		return NULL;
+
+	env = (zbx_es_env_t *)duk_to_pointer(ctx, -1);
+	duk_pop(ctx);
+
+	return env;
+}
