@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,6 +23,16 @@
 #include "common.h"
 #include "duktape.h"
 
+/* this macro can be used in time intensive C functions to check for script timeout execution */
+#define ZBX_ES_CHECK_TIMEOUT(ctx, env) \
+	do { \
+		zbx_uint64_t	elapsed_ms; \
+		elapsed_ms = zbx_get_duration_ms(&env->start_time); \
+		if (elapsed_ms >= (zbx_uint64_t)env->timeout * 1000) \
+			return duk_error(ctx, DUK_RET_TYPE_ERROR, "script execution timeout occurred"); \
+	} \
+	while (0);
+
 struct zbx_es_env
 {
 	duk_context	*ctx;
@@ -36,6 +46,13 @@ struct zbx_es_env
 	struct zbx_json	*json;
 
 	jmp_buf		loc;
+
+	int		http_req_objects;
+	int		logged_msgs;
 };
 
+zbx_es_env_t	*zbx_es_get_env(duk_context *ctx);
+
+int	es_duktape_string_decode(const char *duk_str, char **out_str);
+
 #endif /* ZABBIX_EMBED_H */
