@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -291,7 +291,8 @@ exit:
  *             flag          - [IN] indicates if exit code must be checked    *
  *                                                                            *
  * Return value: SUCCEED if processed successfully, TIMEOUT_ERROR if          *
- *               timeout occurred or FAIL otherwise                           *
+ *               timeout occurred, SIG_ERROR if interrupted by signal or FAIL *
+ *               otherwise                                                    *
  *                                                                            *
  * Author: Alexander Vladishev                                                *
  *                                                                            *
@@ -314,6 +315,7 @@ int	zbx_execute(const char *command, char **output, char *error, size_t max_erro
 #else
 	pid_t			pid;
 	int			fd;
+	sigset_t	mask, orig_mask;
 #endif
 
 	*error = '\0';
@@ -445,6 +447,18 @@ close:
 	zbx_free(wcmd);
 
 #else	/* not _WINDOWS */
+	/* block signals to prevent interruption of statements when runtime control command is issued */
+	if (0 > sigemptyset(&mask))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot initialize signal set: %s", zbx_strerror(errno));
+
+	if (0 > sigaddset(&mask, SIGUSR1))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot add SIGUSR1 signal to signal mask: %s", zbx_strerror(errno));
+
+	if (0 > sigaddset(&mask, SIGUSR2))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot add SIGUSR2 signal to signal mask: %s", zbx_strerror(errno));
+
+	if (0 > sigprocmask(SIG_BLOCK, &mask, &orig_mask))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot set sigprocmask to block the signal: %s", zbx_strerror(errno));
 
 	zbx_alarm_on(timeout);
 
@@ -464,7 +478,16 @@ close:
 		if (-1 == rc || -1 == zbx_waitpid(pid, &status))
 		{
 			if (EINTR == errno)
-				ret = TIMEOUT_ERROR;
+			{
+				if (SUCCEED == zbx_alarm_timed_out())
+					ret = TIMEOUT_ERROR;
+				else
+				{
+					ret = SIG_ERROR;
+					zbx_strlcpy(error, "Signal received while executing a shell script.",
+							max_error_len);
+				}
+			}
 			else
 				zbx_snprintf(error, max_error_len, "zbx_waitpid() failed: %s", zbx_strerror(errno));
 
@@ -492,6 +515,7 @@ close:
 				{
 					zbx_snprintf(error, max_error_len, "Process killed by signal: %d.",
 							WTERMSIG(status));
+					ret = SIG_ERROR;
 				}
 				else
 					zbx_strlcpy(error, "Process terminated unexpectedly.", max_error_len);
@@ -507,6 +531,9 @@ close:
 
 	zbx_alarm_off();
 
+	if (0 > sigprocmask(SIG_SETMASK, &orig_mask, NULL))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot restore sigprocmask: %s", zbx_strerror(errno));
+
 #endif	/* _WINDOWS */
 
 	if (TIMEOUT_ERROR == ret)
