@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -59,6 +59,8 @@ static void	get_source_ip_option(const char *fping, const char **option, unsigne
 
 	zbx_snprintf(tmp, sizeof(tmp), "%s -h 2>&1", fping);
 
+	zabbix_log(LOG_LEVEL_DEBUG, "executing %s", tmp);
+
 	if (NULL == (f = popen(tmp, "r")))
 		return;
 
@@ -87,12 +89,121 @@ static void	get_source_ip_option(const char *fping, const char **option, unsigne
 
 /******************************************************************************
  *                                                                            *
- * Function: get_interval_option                                              *
+ * Purpose: execute external program and return stdout and stderr values      *
+ *                                                                            *
+ * Parameters: fping         - [IN] location of fping program                 *
+ *             out           - [OUT] stdout and stderr values                 *
+ *             error         - [OUT] error string if function fails           *
+ *             max_error_len - [IN] length of error buffer                    *
+ *                                                                            *
+ * Return value: SUCCEED if processed successfully or FAIL otherwise          *
+ *                                                                            *
+ ******************************************************************************/
+static int	get_fping_out(const char *fping, const char *address, char **out, char *error, size_t max_error_len)
+{
+	FILE		*f;
+	size_t		buf_size = 0, offset = 0, len;
+	ssize_t		n;
+	char		tmp[MAX_STRING_LEN], *buffer = NULL;
+	int		ret = FAIL, fd;
+	sigset_t	mask, orig_mask;
+	char		filename[MAX_STRING_LEN];
+	mode_t		mode;
+
+	if (FAIL == zbx_validate_hostname(address) && FAIL == is_supported_ip(address))
+	{
+		zbx_strlcpy(error, "Invalid host name or IP address", max_error_len);
+		return FAIL;
+	}
+
+	zbx_snprintf(filename, sizeof(filename), "%s/%s_XXXXXX", CONFIG_TMPDIR, progname);
+
+	mode = umask(077);
+	fd = mkstemp(filename);
+	umask(mode);
+
+	if (-1 == fd)
+	{
+		zbx_snprintf(error, max_error_len, "Cannot create temporary file \"%s\": %s", filename,
+				zbx_strerror(errno));
+
+		return FAIL;
+	}
+
+	sigemptyset(&mask);
+	sigaddset(&mask, SIGINT);
+	sigaddset(&mask, SIGQUIT);
+
+	len = strlen(address);
+	if (-1 == (n = write(fd, address, len)))
+	{
+		zbx_snprintf(error, max_error_len, "Cannot write address into temporary file: %s", zbx_strerror(errno));
+		(void)close(fd);
+		goto out;
+	}
+
+	if (n != (ssize_t)len)
+	{
+		zbx_strlcpy(error, "Cannot write full address into temporary file", max_error_len);
+		(void)close(fd);
+		goto out;
+	}
+
+	if (-1 == close(fd))
+	{
+		zbx_snprintf(error, max_error_len, "Cannot close temporary file: %s", zbx_strerror(errno));
+		goto out;
+	}
+
+	zbx_snprintf(tmp, sizeof(tmp), "%s 2>&1 < %s", fping, filename);
+
+	if (0 > sigprocmask(SIG_BLOCK, &mask, &orig_mask))
+		zbx_error("cannot set sigprocmask to block the user signal");
+
+	zabbix_log(LOG_LEVEL_DEBUG, "executing %s", tmp);
+
+	if (NULL == (f = popen(tmp, "r")))
+	{
+		zbx_strlcpy(error, zbx_strerror(errno), max_error_len);
+		goto out;
+	}
+
+	while (NULL != zbx_fgets(tmp, sizeof(tmp), f))
+	{
+		len = strlen(tmp);
+
+		if (MAX_EXECUTE_OUTPUT_LEN < offset + len)
+			break;
+
+		zbx_strncpy_alloc(&buffer, &buf_size, &offset, tmp, len);
+	}
+
+	pclose(f);
+
+	if (NULL == buffer)
+	{
+		zbx_strlcpy(error, "Cannot obtain the program output", max_error_len);
+		goto out;
+	}
+
+	*out = buffer;
+	ret = SUCCEED;
+out:
+	unlink(filename);
+
+	if (0 > sigprocmask(SIG_SETMASK, &orig_mask, NULL))
+		zbx_error("cannot restore sigprocmask");
+
+	return ret;
+}
+
+/******************************************************************************
  *                                                                            *
  * Purpose: detect minimal possible fping packet interval                     *
  *                                                                            *
- * Parameters: fping         - [IN] the the location of fping program         *
- *             dst           - [IN] the the ip address for test               *
+ * Parameters: fping         - [IN] the location of fping program             *
+ *             hosts         - [IN] list of hosts to test                     *
+ *             hosts_count   - [IN] number of target hosts                    *
  *             value         - [OUT] interval between sending ping packets    *
  *                                   (in millisec)                            *
  *             error         - [OUT] error string if function fails           *
@@ -115,103 +226,102 @@ static void	get_source_ip_option(const char *fping, const char **option, unsigne
  *           "safe limits".                                                   *
  *                                                                            *
  ******************************************************************************/
-static int	get_interval_option(const char *fping, const char *dst, int *value, char *error, size_t max_error_len)
+static int	get_interval_option(const char *fping, ZBX_FPING_HOST *hosts, int hosts_count, int *value, char *error,
+		size_t max_error_len)
 {
 	char		*out = NULL;
 	unsigned int	intervals[] = {0, 1, 10};
-	size_t		i;
-	int		ret = FAIL;
+	size_t		out_len;
+	int		ret = FAIL, i;
 
-	for (i = 0; i < ARRSIZE(intervals); i++)
+	for (i = 0; i < hosts_count; i++)
 	{
-		int		ret_exec;
-		char		tmp[MAX_STRING_LEN], err[255];
-		const char	*p;
+		size_t		j;
+		const char	*dst = hosts[i].addr;
 
-		zabbix_log(LOG_LEVEL_DEBUG, "testing fping interval %u ms", intervals[i]);
-
-		zbx_snprintf(tmp, sizeof(tmp), "%s -c1 -t50 -i%u %s", fping, intervals[i], dst);
-
-		zbx_free(out);
-
-		/* call fping, ignore its exit code but mind execution failures */
-		if (TIMEOUT_ERROR == (ret_exec = zbx_execute(tmp, &out, err, sizeof(err), 1,
-				ZBX_EXIT_CODE_CHECKS_DISABLED)))
+		for (j = 0; j < ARRSIZE(intervals); j++)
 		{
-			zbx_snprintf(error, max_error_len, "Timeout while executing \"%s\"", tmp);
-			goto out;
-		}
+			char		tmp[MAX_STRING_LEN], err[255];
+			const char	*p;
 
-		if (FAIL == ret_exec)
-		{
-			zbx_snprintf(error, max_error_len, "Cannot execute \"%s\": %s", tmp, err);
-			goto out;
-		}
+			zabbix_log(LOG_LEVEL_DEBUG, "testing fping interval %u ms", intervals[j]);
 
-		/* First, check the output for suggested interval option, e. g.:          */
-		/*                                                                        */
-		/* /usr/sbin/fping: these options are too risky for mere mortals.         */
-		/* /usr/sbin/fping: You need i >= 1, p >= 20, r < 20, and t >= 50         */
+			zbx_snprintf(tmp, sizeof(tmp), "%s -c1 -t50 -i%u", fping, intervals[j]);
 
-#define FPING_YOU_NEED_PREFIX	"You need i >= "
+			zbx_free(out);
 
-		if (NULL != (p = strstr(out, FPING_YOU_NEED_PREFIX)))
-		{
-			p += ZBX_CONST_STRLEN(FPING_YOU_NEED_PREFIX);
-
-			*value = atoi(p);
-			ret = SUCCEED;
-
-			goto out;
-		}
-
-#undef FPING_YOU_NEED_PREFIX
-
-		/* in fping 3.16 they changed "You need i >=" to "You need -i >=" */
-
-#define FPING_YOU_NEED_PREFIX	"You need -i >= "
-
-		if (NULL != (p = strstr(out, FPING_YOU_NEED_PREFIX)))
-		{
-			p += ZBX_CONST_STRLEN(FPING_YOU_NEED_PREFIX);
-
-			*value = atoi(p);
-			ret = SUCCEED;
-
-			goto out;
-		}
-
-#undef FPING_YOU_NEED_PREFIX
-
-		/* if we get dst in the beginning of the output, the used interval is allowed, */
-		/* unless we hit the help message which is always bigger than 1 Kb             */
-		if (ZBX_KIBIBYTE > strlen(out))
-		{
-			/* skip white spaces */
-			for (p = out; '\0' != *p && isspace(*p); p++)
-				;
-
-			if (strlen(p) >= strlen(dst) && 0 == strncmp(p, dst, strlen(dst)))
+			/* call fping, ignore its exit code but mind execution failures */
+			if (SUCCEED != get_fping_out(tmp, dst, &out, err, sizeof(err)))
 			{
-				*value = intervals[i];
+				zbx_snprintf(error, max_error_len, "Cannot execute \"%s\": %s", tmp, err);
+				goto out;
+			}
+
+			/* First, check the output for suggested interval option, e. g.:          */
+			/*                                                                        */
+			/* /usr/sbin/fping: these options are too risky for mere mortals.         */
+			/* /usr/sbin/fping: You need i >= 1, p >= 20, r < 20, and t >= 50         */
+
+	#define FPING_YOU_NEED_PREFIX	"You need i >= "
+
+			if (NULL != (p = strstr(out, FPING_YOU_NEED_PREFIX)))
+			{
+				p += ZBX_CONST_STRLEN(FPING_YOU_NEED_PREFIX);
+
+				*value = atoi(p);
 				ret = SUCCEED;
 
 				goto out;
 			}
 
-			/* check if we hit the error message */
-			if (NULL != (p = strstr(out, " as root")))
+	#undef FPING_YOU_NEED_PREFIX
+
+			/* in fping 3.16 they changed "You need i >=" to "You need -i >=" */
+
+	#define FPING_YOU_NEED_PREFIX	"You need -i >= "
+
+			if (NULL != (p = strstr(out, FPING_YOU_NEED_PREFIX)))
 			{
-				zbx_rtrim(out, "\n");
-				zbx_strlcpy(error, out, max_error_len);
+				p += ZBX_CONST_STRLEN(FPING_YOU_NEED_PREFIX);
+
+				*value = atoi(p);
+				ret = SUCCEED;
+
 				goto out;
 			}
+
+	#undef FPING_YOU_NEED_PREFIX
+
+			/* if we get dst in the beginning of the output, the used interval is allowed, */
+			/* unless we hit the help message which is always bigger than 1 Kb             */
+			if (ZBX_KIBIBYTE > strlen(out))
+			{
+				/* skip white spaces */
+				for (p = out; '\0' != *p && isspace(*p); p++)
+					;
+
+				if (strlen(p) >= strlen(dst) && 0 == strncmp(p, dst, strlen(dst)))
+				{
+					*value = (int)intervals[j];
+					ret = SUCCEED;
+
+					goto out;
+				}
+
+				/* check if we hit the error message */
+				if (NULL != strstr(out, " as root"))
+				{
+					zbx_rtrim(out, "\n");
+					zbx_strlcpy(error, out, max_error_len);
+					goto out;
+				}
+			}
 		}
 	}
 
 	/* if we are here we have probably hit the usage or error message, let's collect it if it's error message */
 
-	if (ZBX_KIBIBYTE > strlen(out) && 0 != strlen(out))
+	if (NULL != out && ZBX_KIBIBYTE > (out_len = strlen(out)) && 0 != out_len)
 	{
 		zbx_rtrim(out, "\n");
 		zbx_strlcpy(error, out, max_error_len);
@@ -231,8 +341,8 @@ out:
  *                                                                            *
  * Purpose: check fping supports IPv6                                         *
  *                                                                            *
- * Parameters: fping - [IN] the the location of fping program                 *
- *             dst   - [IN] the the ip address for test                       *
+ * Parameters: fping - [IN] the location of fping program                     *
+ *             dst   - [IN] the ip address for test                           *
  *                                                                            *
  * Return value: SUCCEED - IPv6 is supported                                  *
  *               FAIL    - IPv6 is not supported                              *
@@ -243,10 +353,10 @@ static int	get_ipv6_support(const char * fping, const char *dst)
 	int	ret;
 	char	tmp[MAX_STRING_LEN], error[255], *out = NULL;
 
-	zbx_snprintf(tmp, sizeof(tmp), "%s -6 -c1 -t50 %s", fping, dst);
+	zbx_snprintf(tmp, sizeof(tmp), "%s -6 -c1 -t50", fping);
 
-	if ((SUCCEED == (ret = zbx_execute(tmp, &out, error, sizeof(error), 1, ZBX_EXIT_CODE_CHECKS_DISABLED)) &&
-				ZBX_KIBIBYTE > strlen(out) && NULL != strstr(out, dst)) || TIMEOUT_ERROR == ret)
+	if (SUCCEED == (ret = get_fping_out(tmp, dst, &out, error, sizeof(error)) &&
+				ZBX_KIBIBYTE > strlen(out) && NULL != strstr(out, dst)))
 	{
 		ret = SUCCEED;
 	}
@@ -360,7 +470,7 @@ static int	process_ping(ZBX_FPING_HOST *hosts, int hosts_count, int count, int i
 	{
 		if (FPING_UNINITIALIZED_VALUE == packet_interval)
 		{
-			if (SUCCEED != get_interval_option(CONFIG_FPING_LOCATION, hosts[0].addr, &packet_interval,
+			if (SUCCEED != get_interval_option(CONFIG_FPING_LOCATION, hosts, hosts_count, &packet_interval,
 					error, max_error_len))
 			{
 				goto out;
@@ -377,8 +487,8 @@ static int	process_ping(ZBX_FPING_HOST *hosts, int hosts_count, int count, int i
 	{
 		if (FPING_UNINITIALIZED_VALUE == packet_interval6)
 		{
-			if (SUCCEED != get_interval_option(CONFIG_FPING6_LOCATION, hosts[0].addr, &packet_interval6,
-					error, max_error_len))
+			if (SUCCEED != get_interval_option(CONFIG_FPING6_LOCATION, hosts, hosts_count,
+					&packet_interval6, error, max_error_len))
 			{
 				goto out;
 			}
@@ -394,7 +504,7 @@ static int	process_ping(ZBX_FPING_HOST *hosts, int hosts_count, int count, int i
 	{
 		if (FPING_UNINITIALIZED_VALUE == packet_interval)
 		{
-			if (SUCCEED != get_interval_option(CONFIG_FPING_LOCATION, hosts[0].addr, &packet_interval,
+			if (SUCCEED != get_interval_option(CONFIG_FPING_LOCATION, hosts, hosts_count, &packet_interval,
 					error, max_error_len))
 			{
 				goto out;
@@ -530,7 +640,7 @@ static int	process_ping(ZBX_FPING_HOST *hosts, int hosts_count, int count, int i
 
 	fclose(f);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "%s", tmp);
+	zabbix_log(LOG_LEVEL_DEBUG, "executing %s", tmp);
 
 	sigemptyset(&mask);
 	sigaddset(&mask, SIGINT);
