@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -153,9 +153,9 @@ zbx_jsonpath_token_type_t;
 typedef struct
 {
 	unsigned char	type;
-	char		*data;
+	char		*text;
+	zbx_jsonpath_t	*path;
 }
 zbx_jsonpath_token_t;
 
-
 #endif
