@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ static void	str_base64_encode_rfc2047(const char *src, char **p_base64)
 		/* So, one "encoded-word" can hold up to 63 characters of Base64-encoded string. */
 		/* Encoding 45 bytes produces a 61 byte long Base64-encoded string which meets the limit. */
 		/* Encoding 46 bytes produces a 65 byte long Base64-encoded string which exceeds the limit. */
-		for (p1 = p0, c_len = 0; '\0' != *p1; p1 += c_len)
+		for (p1 = p0; '\0' != *p1; p1 += c_len)
 		{
 			/* an invalid UTF-8 character or length of a string more than 45 bytes */
 			if (0 == (c_len = zbx_utf8_char_len(p1)) || 45 < p1 - p0 + c_len)
@@ -637,6 +637,12 @@ static int	send_email_curl(const char *smtp_server, unsigned short smtp_port, co
 	if ('\0' != *smtp_helo)
 		zbx_snprintf(url + url_offset, sizeof(url) - url_offset, "/%s", smtp_helo);
 
+#if LIBCURL_VERSION_NUM >= 0x071304
+	/* CURLOPT_PROTOCOLS is supported starting with version 7.19.4 (0x071304) */
+	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_PROTOCOLS, CURLPROTO_SMTPS | CURLPROTO_SMTP)))
+		goto error;
+#endif
+
 	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_URL, url)))
 		goto error;
 
@@ -691,6 +697,9 @@ static int	send_email_curl(const char *smtp_server, unsigned short smtp_port, co
 		goto error;
 	}
 
+	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, ZBX_CURLOPT_ACCEPT_ENCODING, "")))
+		goto error;
+
 	for (i = 0; i < to_mails->values_num; i++)
 		recipients = curl_slist_append(recipients, ((zbx_mailaddr_t *)to_mails->values[i])->addr);
 
