@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -170,6 +170,46 @@ int	zbx_locks_create(char **error)
 	return SUCCEED;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_mutex_addr_get                                               *
+ *                                                                            *
+ * Purpose: acquire address of the mutex                                      *
+ *                                                                            *
+ * Parameters: mutex_name - name of the mutex to return address for           *
+ *                                                                            *
+ * Return value: address of the mutex                                         *
+ *                                                                            *
+ ******************************************************************************/
+zbx_mutex_t	zbx_mutex_addr_get(zbx_mutex_name_t mutex_name)
+{
+#ifdef HAVE_PTHREAD_PROCESS_SHARED
+	return &shared_lock->mutexes[mutex_name];
+#else
+	return mutex_name;
+#endif
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_mutex_addr_get                                               *
+ *                                                                            *
+ * Purpose: acquire address of the rwlock                                     *
+ *                                                                            *
+ * Parameters: rwlock_name - name of the rwlock to return address for         *
+ *                                                                            *
+ * Return value: address of the rwlock                                        *
+ *                                                                            *
+ ******************************************************************************/
+zbx_rwlock_t	zbx_rwlock_addr_get(zbx_rwlock_name_t rwlock_name)
+{
+#ifdef HAVE_PTHREAD_PROCESS_SHARED
+	return &shared_lock->rwlocks[rwlock_name];
+#else
+	return rwlock_name + ZBX_MUTEX_COUNT;
+#endif
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: zbx_rwlock_create                                                *
