@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -56,18 +56,25 @@
 #	define ZBX_PROC_MASK	P_INMEM
 #endif
 
+#define ARGV_START_SIZE	64
 static char	*get_commandline(struct kinfo_proc *proc)
 {
 	int		mib[4], i;
 	size_t		sz;
 	static char	*args = NULL;
+#if (__FreeBSD_version >= 802510)
 	static int	args_alloc = 0;
+#else
+	int		argv_max, err = -1;
+	static int	args_alloc = ARGV_START_SIZE;
+#endif
 
 	mib[0] = CTL_KERN;
 	mib[1] = KERN_PROC;
 	mib[2] = KERN_PROC_ARGS;
 	mib[3] = proc->ZBX_PROC_PID;
 
+#if (__FreeBSD_version >= 802510)
 	if (-1 == sysctl(mib, 4, NULL, &sz, NULL, 0))
 		return NULL;
 
@@ -84,16 +91,50 @@ static char	*get_commandline(struct kinfo_proc *proc)
 
 	if (-1 == sysctl(mib, 4, args, &sz, NULL, 0))
 		return NULL;
+#else
+	/*
+	 * Before FreeBSD 8.3 sysctl() API for kern.proc.args didn't follow the regular convention
+	 * that a user can query the needed size for results by passing in a NULL old pointer
+	 * and a valid oldsize, given that we have to estimate the required output buffer size manually:
+	 *
+	 * https://github.com/freebsd/freebsd-src/commit/9f688f2ce3c01f30b0c98d17c6ce057660819c8c
+	*/
 
+	if (NULL == args)
+		args = zbx_malloc(args, args_alloc);
+
+	if (-1 == (argv_max = sysconf(_SC_ARG_MAX)))
+		return NULL;
+
+	while (0 != err && args_alloc < argv_max)
+	{
+		sz = (size_t)args_alloc;
+
+		if (-1 == (err = sysctl(mib, 4, args, &sz, NULL, 0)))
+		{
+			if (ENOMEM == errno)
+			{
+				args_alloc *= 2;
+				args = zbx_realloc(args, args_alloc);
+			}
+			else
+				return NULL;
+		}
+	}
+
+	if (-1 == err)
+		return NULL;
+#endif
 	for (i = 0; i < (int)(sz - 1); i++)
 		if (args[i] == '\0')
 			args[i] = ' ';
 
-	if (sz == 0)
+	if (0 == sz)
 		zbx_strlcpy(args, proc->ZBX_PROC_COMM, args_alloc);
 
 	return args;
 }
+#undef ARGV_START_SIZE
 
 int     PROC_MEM(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
