@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -181,7 +181,7 @@ int	VFS_FS_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 static int	vfs_fs_get(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
-	char			line[MAX_STRING_LEN], *p, *mpoint, *mtype, *error;
+	char			line[MAX_STRING_LEN], *p, *error;
 	FILE			*f;
 	zbx_uint64_t		total, not_used, used;
 	zbx_uint64_t		itotal, inot_used, iused;
@@ -190,6 +190,7 @@ static int	vfs_fs_get(AGENT_REQUEST *request, AGENT_RESULT *result)
 	struct zbx_json		j;
 	zbx_vector_ptr_t	mntpoints;
 	zbx_mpoint_t		*mntpoint;
+	zbx_fsname_t		fsname;
 	int			ret = SYSINFO_RET_FAIL;
 
 	ZBX_UNUSED(request);
@@ -207,35 +208,35 @@ static int	vfs_fs_get(AGENT_REQUEST *request, AGENT_RESULT *result)
 		if (NULL == (p = strchr(line, ' ')))
 			continue;
 
-		mpoint = ++p;
+		fsname.mpoint = ++p;
 
-		if (NULL == (p = strchr(mpoint, ' ')))
+		if (NULL == (p = strchr(fsname.mpoint, ' ')))
 			continue;
 
 		*p = '\0';
 
-		mtype = ++p;
+		fsname.type = ++p;
 
-		if (NULL == (p = strchr(mtype, ' ')))
+		if (NULL == (p = strchr(fsname.type, ' ')))
 			continue;
 
 		*p = '\0';
 
-		if (SYSINFO_RET_OK != get_fs_size_stat(mpoint, &total, &not_used, &used, &pfree, &pused, &error))
+		if (SYSINFO_RET_OK != get_fs_size_stat(fsname.mpoint, &total, &not_used, &used, &pfree, &pused, &error))
 		{
 			zbx_free(error);
 			continue;
 		}
-		if (SYSINFO_RET_OK != get_fs_inode_stat(mpoint, &itotal, &inot_used, &iused, &ipfree, &ipused, "pused",
-				&error))
+		if (SYSINFO_RET_OK != get_fs_inode_stat(fsname.mpoint, &itotal, &inot_used, &iused, &ipfree, &ipused,
+				"pused", &error))
 		{
 			zbx_free(error);
 			continue;
 		}
 
 		mntpoint = (zbx_mpoint_t *)zbx_malloc(NULL, sizeof(zbx_mpoint_t));
-		zbx_strlcpy(mntpoint->fsname, mpoint, MAX_STRING_LEN);
-		zbx_strlcpy(mntpoint->fstype, mtype, MAX_STRING_LEN);
+		zbx_strlcpy(mntpoint->fsname, fsname.mpoint, MAX_STRING_LEN);
+		zbx_strlcpy(mntpoint->fstype, fsname.type, MAX_STRING_LEN);
 		mntpoint->bytes.total = total;
 		mntpoint->bytes.used = used;
 		mntpoint->bytes.not_used = not_used;
@@ -265,13 +266,21 @@ static int	vfs_fs_get(AGENT_REQUEST *request, AGENT_RESULT *result)
 		if (NULL == (p = strchr(line, ' ')))
 			continue;
 
-		mpoint = ++p;
+		fsname.mpoint = ++p;
 
-		if (NULL == (p = strchr(mpoint, ' ')))
+		if (NULL == (p = strchr(fsname.mpoint, ' ')))
 			continue;
 
 		*p = '\0';
-		if (FAIL != (idx = zbx_vector_ptr_search(&mntpoints, mpoint, ZBX_DEFAULT_STR_COMPARE_FUNC)))
+
+		fsname.type = ++p;
+
+		if (NULL == (p = strchr(fsname.type, ' ')))
+			continue;
+
+		*p = '\0';
+
+		if (FAIL != (idx = zbx_vector_ptr_search(&mntpoints, &fsname, zbx_fsname_compare)))
 		{
 			mntpoint = (zbx_mpoint_t *)mntpoints.values[idx];
 			zbx_json_addobject(&j, NULL);
