@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -86,11 +86,15 @@ int     SYSTEM_SW_OS(AGENT_REQUEST *request, AGENT_RESULT *result)
 		{
 			while (NULL != fgets(tmp_line, sizeof(tmp_line), f))
 			{
+				char	line2[MAX_STRING_LEN];
+
 				if (0 != strncmp(tmp_line, SW_OS_OPTION_PRETTY_NAME,
 						ZBX_CONST_STRLEN(SW_OS_OPTION_PRETTY_NAME)))
 					continue;
 
-				if (1 == sscanf(tmp_line, SW_OS_OPTION_PRETTY_NAME "=\"%[^\"]", line))
+				if (1 == sscanf(tmp_line, SW_OS_OPTION_PRETTY_NAME "=\"%[^\"]", line) ||
+						1 == sscanf(tmp_line, SW_OS_OPTION_PRETTY_NAME "=%[^ \t\n] %s",
+								line, line2))
 				{
 					line_read = SUCCEED;
 					break;
