@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1219,13 +1219,12 @@ int	set_result_type(AGENT_RESULT *result, int value_type, char *c)
 {
 	zbx_uint64_t	value_uint64;
 	int		ret = FAIL;
+	double		dbl_tmp;
 
 	assert(result);
 
 	switch (value_type)
 	{
-		double	dbl_tmp;
-
 		case ITEM_VALUE_TYPE_UINT64:
 			zbx_trim_integer(c);
 			del_zeros(c);
@@ -1913,6 +1912,34 @@ out:
 	return ret;
 }
 #endif
+
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_mpoints_free                                                 *
+ *                                                                            *
+ * Purpose: frees previously allocated mount-point structure                  *
+ *                                                                            *
+ * Parameters: mpoint - [IN] pointer to structure from vector                 *
+ *                                                                            *
+ * Return value:                                                              *
+ *                                                                            *
+ ******************************************************************************/
+void	zbx_mpoints_free(zbx_mpoint_t *mpoint)
+{
+	zbx_free(mpoint);
+}
+
+int	zbx_fsname_compare(const void *fs1, const void *fs2)
+{
+	int			res;
+	const zbx_mpoint_t	*f1 = *((const zbx_mpoint_t * const *)fs1);
+	const zbx_fsname_t	*f2 = *((const zbx_fsname_t * const *)fs2);
+
+	if (0 != (res = strcmp(f1->fsname, f2->mpoint)))
+		return res;
+
+	return strcmp(f1->fstype, f2->type);
+}
 #else
 
 static ZBX_THREAD_LOCAL zbx_uint32_t	mutex_flag = ZBX_MUTEX_ALL_ALLOW;
@@ -2060,18 +2087,50 @@ int	zbx_execute_threaded_metric(zbx_metric_func_t metric_func, AGENT_REQUEST *re
 }
 #endif
 
-/******************************************************************************
- *                                                                            *
- * Function: zbx_mpoints_free                                                 *
- *                                                                            *
- * Purpose: frees previously allocated mount-point structure                  *
- *                                                                            *
- * Parameters: mpoint - [IN] pointer to structure from vector                 *
- *                                                                            *
- * Return value:                                                              *
- *                                                                            *
- ******************************************************************************/
-void	zbx_mpoints_free(zbx_mpoint_t *mpoint)
+#ifndef _WINDOWS
+int	hostname_handle_params(AGENT_REQUEST *request, AGENT_RESULT *result, char *hostname)
 {
-	zbx_free(mpoint);
+	char	*type, *transform;
+
+	type = get_rparam(request, 0);
+	transform = get_rparam(request, 1);
+
+	if (NULL != type && '\0' != *type && 0 != strcmp(type, "host"))
+	{
+		if (0 == strcmp(type, "shorthost"))
+		{
+			char	*dot;
+
+			if (NULL != (dot = strchr(hostname, '.')))
+				*dot = '\0';
+		}
+		else if (0 == strcmp(type, "netbios"))
+		{
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "NetBIOS is not supported on the current platform."));
+			return FAIL;
+		}
+		else
+		{
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
+			return FAIL;
+		}
+	}
+
+	if (NULL != transform && '\0' != *transform && 0 != strcmp(transform, "none"))
+	{
+		if (0 == strcmp(transform, "lower"))
+		{
+			zbx_strlower(hostname);
+		}
+		else
+		{
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
+			return FAIL;
+		}
+	}
+
+	SET_STR_RESULT(result, hostname);
+
+	return SUCCEED;
 }
+#endif
