@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1245,13 +1245,20 @@ int	main(int argc, char **argv)
 	if (SUCCEED != parse_commandline(argc, argv, &t))
 		exit(EXIT_FAILURE);
 
+#ifdef _WINDOWS
+	/* if agent is started as windows service then try to log errors */
+	/* into windows event log while zabbix_log is not ready */
+	if (ZBX_TASK_START == t.task && 0 == (t.flags & ZBX_TASK_FLAG_FOREGROUND))
+		zabbix_open_log(LOG_TYPE_SYSTEM, LOG_LEVEL_WARNING, NULL, NULL);
+#endif
+
 	import_symbols();
 
 #ifdef _WINDOWS
 	if (ZBX_TASK_SHOW_USAGE != t.task && ZBX_TASK_SHOW_VERSION != t.task && ZBX_TASK_SHOW_HELP != t.task &&
 			SUCCEED != zbx_socket_start(&error))
 	{
-		zbx_error(error);
+		zabbix_log(LOG_LEVEL_CRIT, error);
 		zbx_free(error);
 		exit(EXIT_FAILURE);
 	}
@@ -1359,6 +1366,10 @@ int	main(int argc, char **argv)
 			zbx_load_config(ZBX_CFG_FILE_REQUIRED, &t);
 			load_user_parameters(CONFIG_USER_PARAMETERS);
 			load_aliases(CONFIG_ALIASES);
+#ifdef _WINDOWS
+			if (0 == (t.flags & ZBX_TASK_FLAG_FOREGROUND))
+				zabbix_close_log();
+#endif
 			break;
 	}
 
