@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,9 +21,11 @@ package com.zabbix.gateway;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.FileInputStream;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import java.util.Properties;
 
 class ConfigurationManager
 {
@@ -34,6 +36,7 @@ class ConfigurationManager
 	static final String LISTEN_PORT = "listenPort";
 	static final String START_POLLERS = "startPollers";
 	static final String TIMEOUT = "timeout";
+	static final String PROPERTIES_FILE = "propertiesFile";
 
 	private static ConfigurationParameter[] parameters =
 	{
@@ -73,7 +76,41 @@ class ConfigurationManager
 				null),
 		new ConfigurationParameter(TIMEOUT, ConfigurationParameter.TYPE_INTEGER, 3,
 				new IntegerValidator(1, 30),
-				null)
+				null),
+		new ConfigurationParameter(PROPERTIES_FILE, ConfigurationParameter.TYPE_FILE, null,
+				null,
+				new PostInputValidator()
+				{
+					@Override
+					public void execute(Object value)
+					{
+						FileInputStream inStream = null;
+
+						try
+						{
+							Properties props;
+
+							inStream = new FileInputStream((File)value);
+							props = new Properties(System.getProperties());
+
+							props.load(inStream);
+
+							System.setProperties(props);
+						}
+						catch (IOException e)
+						{
+							throw new RuntimeException(e);
+						}
+						catch (SecurityException e)
+						{
+							throw new RuntimeException(e);
+						}
+						finally
+						{
+							try { if (null != inStream) inStream.close(); } catch (Exception e) { }
+						}
+					}
+				}),
 	};
 
 	static void parseConfiguration()
