@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,13 +48,17 @@ void	zbx_tm_get_remote_tasks(zbx_vector_ptr_t *tasks, zbx_uint64_t proxy_hostid)
 
 	result = DBselect(
 			"select t.taskid,t.type,t.clock,t.ttl,"
-				"r.status,r.parent_taskid,r.info"
-			" from task t,task_remote_command_result r"
-			" where t.taskid=r.taskid"
-				" and t.status=%d"
-				" and t.type=%d"
+				"r.status,r.parent_taskid,r.info,"
+				"tr.status,tr.parent_taskid,tr.info"
+			" from task t"
+			" left join task_remote_command_result r"
+				" on t.taskid=r.taskid"
+			" left join task_result tr"
+				" on t.taskid=tr.taskid"
+			" where t.status=%d"
+				" and t.type in (%d,%d)"
 			" order by t.taskid",
-			ZBX_TM_STATUS_NEW, ZBX_TM_TASK_REMOTE_COMMAND_RESULT);
+			ZBX_TM_STATUS_NEW, ZBX_TM_TASK_REMOTE_COMMAND_RESULT, ZBX_TM_TASK_DATA_RESULT);
 
 	while (NULL != (row = DBfetch(result)))
 	{
@@ -62,11 +66,33 @@ void	zbx_tm_get_remote_tasks(zbx_vector_ptr_t *tasks, zbx_uint64_t proxy_hostid)
 		zbx_tm_task_t	*task;
 
 		ZBX_STR2UINT64(taskid, row[0]);
-		ZBX_DBROW2UINT64(parent_taskid, row[5]);
-
 		task = zbx_tm_task_create(taskid, atoi(row[1]), ZBX_TM_STATUS_NEW, atoi(row[2]), atoi(row[3]), 0);
 
-		task->data = zbx_tm_remote_command_result_create(parent_taskid, atoi(row[4]), row[6]);
+		switch (task->type)
+		{
+			case ZBX_TM_TASK_REMOTE_COMMAND_RESULT:
+				if (SUCCEED == DBis_null(row[4]))
+				{
+					zbx_free(task);
+					continue;
+				}
+
+				ZBX_DBROW2UINT64(parent_taskid, row[5]);
+
+				task->data = zbx_tm_remote_command_result_create(parent_taskid, atoi(row[4]), row[6]);
+				break;
+			case ZBX_TM_TASK_DATA_RESULT:
+				if (SUCCEED == DBis_null(row[7]))
+				{
+					zbx_free(task);
+					continue;
+				}
+
+				ZBX_DBROW2UINT64(parent_taskid, row[8]);
+
+				task->data = zbx_tm_data_result_create(parent_taskid, atoi(row[7]), row[9]);
+				break;
+		}
 
 		zbx_vector_ptr_append(tasks, task);
 	}
@@ -74,4 +100,3 @@ void	zbx_tm_get_remote_tasks(zbx_vector_ptr_t *tasks, zbx_uint64_t proxy_hostid)
 	DBfree_result(result);
 }
 
-
