@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -324,29 +324,6 @@ static void	ipmi_poller_free_request(zbx_ipmi_poller_t *poller)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_poller_free                                                 *
- *                                                                            *
- * Purpose: frees IPMI poller                                                 *
- *                                                                            *
- ******************************************************************************/
-static void	ipmi_poller_free(zbx_ipmi_poller_t *poller)
-{
-	zbx_ipmi_request_t	*request;
-
-	zbx_ipc_client_close(poller->client);
-
-	while (NULL != (request = ipmi_poller_pop_request(poller)))
-		ipmi_request_free(request);
-
-	zbx_binary_heap_destroy(&poller->requests);
-
-	zbx_free(poller);
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: ipmi_manager_init                                                *
  *                                                                            *
  * Purpose: initializes IPMI manager                                          *
  *                                                                            *
@@ -390,26 +367,6 @@ static void	ipmi_manager_init(zbx_ipmi_manager_t *manager)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_manager_destroy                                             *
- *                                                                            *
- * Purpose: destroys IPMI manager                                             *
- *                                                                            *
- * Parameters: manager - [IN] the manager to destroy                          *
- *                                                                            *
- ******************************************************************************/
-static void	ipmi_manager_destroy(zbx_ipmi_manager_t *manager)
-{
-	zbx_hashset_destroy(&manager->hosts);
-	zbx_binary_heap_destroy(&manager->pollers_load);
-	zbx_hashset_destroy(&manager->pollers_client);
-	zbx_vector_ptr_clear_ext(&manager->pollers, (zbx_clean_func_t)ipmi_poller_free);
-	zbx_vector_ptr_destroy(&manager->pollers);
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: ipmi_manager_host_cleanup                                        *
  *                                                                            *
  * Purpose: performs cleanup of monitored hosts cache                         *
  *                                                                            *
@@ -958,7 +915,7 @@ static void	ipmi_manager_process_value_result(zbx_ipmi_manager_t *manager, zbx_i
 			break;
 		default:
 			/* don't change item's state when network related error occurs */
-			state = poller->request->item_state;
+			break;
 	}
 
 	zbx_free(value);
@@ -1099,9 +1056,6 @@ ZBX_THREAD_ENTRY(ipmi_manager_thread, args)
 
 	while (1)
 		zbx_sleep(SEC_PER_MIN);
-
-	zbx_ipc_service_close(&ipmi_service);
-	ipmi_manager_destroy(&ipmi_manager);
 #undef STAT_INTERVAL
 }
 
