@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -279,10 +279,6 @@ ZBX_THREAD_ENTRY(ipmi_poller_thread, args)
 
 	while (1)
 		zbx_sleep(SEC_PER_MIN);
-
-	zbx_ipc_async_socket_close(&ipmi_socket);
-
-	zbx_free_ipmi_handler();
 #undef STAT_INTERVAL
 }
 
