@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,19 +39,17 @@
  * Author: Eugene Grigorjev                                                   *
  *                                                                            *
  ******************************************************************************/
-int	get_value_db(DC_ITEM *item, AGENT_RESULT *result)
+int	get_value_db(const DC_ITEM *item, AGENT_RESULT *result)
 {
-	const char		*__function_name = "get_value_db";
-
 	AGENT_REQUEST		request;
-	const char		*dsn;
+	const char		*dsn, *connection = NULL;
 	zbx_odbc_data_source_t	*data_source;
 	zbx_odbc_query_result_t	*query_result;
 	char			*error = NULL;
 	int			(*query_result_to_text)(zbx_odbc_query_result_t *query_result, char **text, char **error),
 				ret = NOTSUPPORTED;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() key_orig:'%s' query:'%s'", __function_name, item->key_orig, item->params);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() key_orig:'%s' query:'%s'", __func__, item->key_orig, item->params);
 
 	init_request(&request);
 
@@ -69,13 +67,17 @@ int	get_value_db(DC_ITEM *item, AGENT_RESULT *result)
 	{
 		query_result_to_text = zbx_odbc_query_result_to_lld_json;
 	}
+	else if (0 == strcmp(request.key, "db.odbc.get"))
+	{
+		query_result_to_text = zbx_odbc_query_result_to_json;
+	}
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Unsupported item key for this item type."));
 		goto out;
 	}
 
-	if (2 != request.nparam)
+	if (2 > request.nparam || 3 < request.nparam)
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid number of parameters."));
 		goto out;
@@ -85,13 +87,17 @@ int	get_value_db(DC_ITEM *item, AGENT_RESULT *result)
 
 	dsn = request.params[1];
 
-	if (NULL == dsn || '\0' == *dsn)
+	if (2 < request.nparam)
+		connection = request.params[2];
+
+	if ((NULL == dsn || '\0' == *dsn) && (NULL == connection || '\0' == *connection))
 	{
-		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
+		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid database connection settings."));
 		goto out;
 	}
 
-	if (NULL != (data_source = zbx_odbc_connect(dsn, item->username, item->password, CONFIG_TIMEOUT, &error)))
+	if (NULL != (data_source = zbx_odbc_connect(dsn, connection, item->username, item->password, CONFIG_TIMEOUT,
+			&error)))
 	{
 		if (NULL != (query_result = zbx_odbc_select(data_source, item->params, &error)))
 		{
@@ -114,7 +120,7 @@ int	get_value_db(DC_ITEM *item, AGENT_RESULT *result)
 out:
 	free_request(&request);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
