@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,7 +31,8 @@
 
 #include "preprocessing.h"
 #include "preproc_manager.h"
-#include "linked_list.h"
+#include "zbxalgo.h"
+#include "../../libs/zbxalgo/vectorimpl.h"
 #include "preproc_history.h"
 
 extern unsigned char	process_type, program_type;
@@ -52,18 +53,23 @@ typedef enum
 }
 zbx_preprocessing_states_t;
 
+typedef struct preprocessing_request zbx_preprocessing_request_t;
+
+ZBX_PTR_VECTOR_DECL(preprocessing_request, zbx_preprocessing_request_t *)
+ZBX_PTR_VECTOR_IMPL(preprocessing_request, zbx_preprocessing_request_t *)
+
 /* preprocessing request */
-typedef struct preprocessing_request
+struct preprocessing_request
 {
-	zbx_preprocessing_states_t	state;		/* request state */
-	struct preprocessing_request	*pending;	/* the request waiting on this request to complete */
-	zbx_preproc_item_value_t	value;		/* unpacked item value */
-	zbx_preproc_op_t		*steps;		/* preprocessing steps */
-	int				steps_num;	/* number of preprocessing steps */
-	unsigned char			value_type;	/* value type from configuration */
-							/* at the beginning of preprocessing queue */
-}
-zbx_preprocessing_request_t;
+	zbx_preprocessing_states_t		state;		/* request state */
+	zbx_preprocessing_request_t		*pending;	/* the request waiting on this request to complete */
+	zbx_preproc_item_value_t		value;		/* unpacked item value */
+	zbx_preproc_op_t			*steps;		/* preprocessing steps */
+	int					steps_num;	/* number of preprocessing steps */
+	unsigned char				value_type;	/* value type from configuration */
+								/* at the beginning of preprocessing queue */
+	zbx_vector_preprocessing_request_t	flush_queue;	/* processed request waiting to be flushed */
+};
 
 /* preprocessing worker data */
 typedef struct
@@ -251,13 +257,16 @@ static zbx_uint32_t	preprocessor_create_task(zbx_preprocessing_manager_t *manage
  *                                                                            *
  * Parameters: manager    - [IN] preprocessing manager                        *
  *             request    - [IN] preprocessing request                        *
- *             queue_item - [IN] queued item                                  *
+ *             queue_item - [IN/OUT] in - queued item                         *
+ *                                   out - new position in queue              *
  *                                                                            *
  ******************************************************************************/
 static	void	preprocessor_set_request_state_done(zbx_preprocessing_manager_t *manager,
-		zbx_preprocessing_request_t *request, const zbx_list_item_t *queue_item)
+		zbx_preprocessing_request_t *request, zbx_list_item_t **queue_item)
 {
-	zbx_item_link_t	*index;
+	zbx_item_link_t			*index;
+	zbx_list_iterator_t		iterator, next_iterator;
+	zbx_preprocessing_request_t	*prev;
 
 	request->state = REQUEST_STATE_DONE;
 
@@ -266,10 +275,37 @@ static	void	preprocessor_set_request_state_done(zbx_preprocessing_manager_t *man
 		request->pending->state = REQUEST_STATE_QUEUED;
 
 	if (NULL != (index = (zbx_item_link_t *)zbx_hashset_search(&manager->linked_items, &request->value.itemid)) &&
-			queue_item == index->queue_item)
+			*queue_item == index->queue_item)
 	{
 		zbx_hashset_remove_direct(&manager->linked_items, index);
 	}
+
+	if (NULL == manager->queue.head)
+		return;
+
+	zbx_list_iterator_init(&manager->queue, &iterator);
+	if (iterator.next == *queue_item)
+		return;
+
+	while (SUCCEED == zbx_list_iterator_next(&iterator))
+	{
+		if (iterator.next == *queue_item)
+			break;
+	}
+
+	*queue_item = iterator.current;
+
+	prev = (zbx_preprocessing_request_t *)iterator.current->data;
+	zbx_vector_preprocessing_request_append(&prev->flush_queue, request);
+
+	next_iterator = iterator;
+	if (SUCCEED == zbx_list_iterator_next(&next_iterator))
+	{
+		if (SUCCEED == zbx_list_iterator_equal(&next_iterator, &manager->priority_tail))
+			manager->priority_tail = iterator;
+	}
+
+	(void)zbx_list_iterator_remove_next(&iterator);
 }
 
 /******************************************************************************
@@ -312,6 +348,7 @@ static void	*preprocessor_get_next_task(zbx_preprocessing_manager_t *manager, zb
 		if (ITEM_STATE_NOTSUPPORTED == request->value.state)
 		{
 			zbx_preproc_history_t	*vault;
+			zbx_list_item_t		*node = iterator.current;
 
 			if (NULL != (vault = (zbx_preproc_history_t *) zbx_hashset_search(&manager->history_cache,
 					&request->value.itemid)))
@@ -322,7 +359,7 @@ static void	*preprocessor_get_next_task(zbx_preprocessing_manager_t *manager, zb
 				zbx_hashset_remove_direct(&manager->history_cache, vault);
 			}
 
-			preprocessor_set_request_state_done(manager, request, iterator.current);
+			preprocessor_set_request_state_done(manager, request, &node);
 			continue;
 		}
 
@@ -474,6 +511,9 @@ static void	preproc_item_value_clear(zbx_preproc_item_value_t *value)
  ******************************************************************************/
 static void	preprocessor_free_request(zbx_preprocessing_request_t *request)
 {
+	zbx_vector_preprocessing_request_clear_ext(&request->flush_queue, preprocessor_free_request);
+	zbx_vector_preprocessing_request_destroy(&request->flush_queue);
+
 	preproc_item_value_clear(&request->value);
 	request_free_steps(request);
 	zbx_free(request);
@@ -512,7 +552,26 @@ static void	preprocessor_flush_value(const zbx_preproc_item_value_t *value)
 				value->ts, value->state, value->error);
 	}
 	else
-		zbx_lld_process_agent_result(value->itemid, value->result_ptr->result, value->ts, value->error);
+		zbx_lld_process_agent_result(value->itemid, value->hostid, value->result_ptr->result, value->ts,
+				value->error);
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: flush preprocessing request and all requests waiting on it        *
+ *                                                                            *
+ ******************************************************************************/
+static void	preprocessing_flush_request(zbx_preprocessing_manager_t *manager, zbx_preprocessing_request_t *request)
+{
+	int	i;
+
+	preprocessor_flush_value(&request->value);
+
+	manager->processed_num++;
+	manager->queued_num--;
+
+	for (i = 0; i < request->flush_queue.values_num; i++)
+		preprocessing_flush_request(manager, request->flush_queue.values[i]);
 }
 
 /******************************************************************************
@@ -538,16 +597,13 @@ static void	preprocessing_flush_queue(zbx_preprocessing_manager_t *manager)
 		if (REQUEST_STATE_DONE != request->state)
 			break;
 
-		preprocessor_flush_value(&request->value);
+		preprocessing_flush_request(manager, request);
 		preprocessor_free_request(request);
 
 		if (SUCCEED == zbx_list_iterator_equal(&iterator, &manager->priority_tail))
 			zbx_list_iterator_clear(&manager->priority_tail);
 
 		zbx_list_pop(&manager->queue, NULL);
-
-		manager->processed_num++;
-		manager->queued_num--;
 	}
 }
 
@@ -683,6 +739,7 @@ static void	preprocessor_enqueue(zbx_preprocessing_manager_t *manager, zbx_prepr
 
 	request = (zbx_preprocessing_request_t *)zbx_malloc(NULL, sizeof(zbx_preprocessing_request_t));
 	memset(request, 0, sizeof(zbx_preprocessing_request_t));
+	zbx_vector_preprocessing_request_create(&request->flush_queue);
 	memcpy(&request->value, value, sizeof(zbx_preproc_item_value_t));
 	request->state = state;
 
@@ -850,6 +907,35 @@ static void	preprocessor_add_test_request(zbx_preprocessing_manager_t *manager,
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: create_result_with_meta                                          *
+ *                                                                            *
+ * Purpose: create new result and copy meta information from previous result  *
+ *                                                                            *
+ * Parameters: result_old - [IN] result that can contain meta information     *
+ *                                                                            *
+ * Return value: pointer newly allocated result                               *
+ *                                                                            *
+ ******************************************************************************/
+static AGENT_RESULT	*create_result_with_meta(const AGENT_RESULT *result_old)
+{
+	AGENT_RESULT	*result;
+
+	result = zbx_malloc(NULL, sizeof(AGENT_RESULT));
+
+	init_result(result);
+
+	if (0 == ISSET_META(result_old))
+		return result;
+
+	result->type = AR_META;
+	result->lastlogsize = result_old->lastlogsize;
+	result->mtime = result_old->mtime;
+
+	return result;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: preprocessor_set_variant_result                                  *
@@ -879,11 +965,15 @@ static int	preprocessor_set_variant_result(zbx_preprocessing_request_t *request,
 
 	if (ZBX_VARIANT_NONE == value->type)
 	{
+		AGENT_RESULT	*result;
+
+		result = create_result_with_meta(request->value.result_ptr->result);
+
 		preproc_item_result_free(&request->value);
 		request->value.result_ptr = (zbx_result_ptr_t *)zbx_malloc(NULL, sizeof(zbx_result_ptr_t));
 		request->value.result_ptr->refcount = 1;
-		request->value.result_ptr->result = zbx_malloc(NULL, sizeof(AGENT_RESULT));
-		init_result(request->value.result_ptr->result);
+		request->value.result_ptr->result = result;
+
 		ret = FAIL;
 
 		goto out;
@@ -905,9 +995,9 @@ static int	preprocessor_set_variant_result(zbx_preprocessing_request_t *request,
 	if (FAIL != (ret = zbx_variant_convert(value, type)))
 	{
 		/* old result is shared between dependent and master items, it cannot be modified, create new result */
-		AGENT_RESULT	*result = zbx_malloc(NULL, sizeof(AGENT_RESULT));
+		AGENT_RESULT	*result;
 
-		init_result(result);
+		result = create_result_with_meta(request->value.result_ptr->result);
 
 		switch (request->value_type)
 		{
@@ -1023,10 +1113,10 @@ static void	preprocessor_add_result(zbx_preprocessing_manager_t *manager, zbx_ip
 		}
 	}
 
-	preprocessor_set_request_state_done(manager, request, worker->task);
+	preprocessor_set_request_state_done(manager, request, &node);
 
 	if (FAIL != preprocessor_set_variant_result(request, &value, error))
-		preprocessor_enqueue_dependent(manager, &request->value, worker->task);
+		preprocessor_enqueue_dependent(manager, &request->value, node);
 
 	worker->task = NULL;
 	zbx_variant_clear(&value);
@@ -1079,6 +1169,80 @@ static void	preprocessor_flush_test_result(zbx_preprocessing_manager_t *manager,
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
+static	void	preprocessor_get_items_totals(zbx_preprocessing_manager_t *manager, int *total, int *queued,
+		int *processing, int *done, int *pending)
+{
+#define ZBX_MAX_REQUEST_STATE_PRINT_LIMIT	25
+
+	zbx_preproc_item_stats_t	*item;
+	zbx_list_iterator_t		iterator;
+	zbx_preprocessing_request_t	*request;
+	zbx_hashset_t			items;
+
+	*total = 0;
+	*queued = 0;
+	*processing = 0;
+	*done = 0;
+	*pending = 0;
+
+	zbx_hashset_create(&items, 1024, ZBX_DEFAULT_UINT64_HASH_FUNC, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+
+	zbx_list_iterator_init(&manager->queue, &iterator);
+	while (SUCCEED == zbx_list_iterator_next(&iterator))
+	{
+		zbx_list_iterator_peek(&iterator, (void **)&request);
+
+		if (NULL == (item = zbx_hashset_search(&items, &request->value.itemid)))
+		{
+			zbx_preproc_item_stats_t	item_local = {.itemid = request->value.itemid};
+
+			item = zbx_hashset_insert(&items, &item_local, sizeof(item_local));
+		}
+
+		switch(request->state)
+		{
+			case REQUEST_STATE_QUEUED:
+				if (*queued < ZBX_MAX_REQUEST_STATE_PRINT_LIMIT)
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "oldest queued itemid: " ZBX_FS_UI64
+							" values:%d pos:%d", item->itemid, item->values_num, *total);
+				}
+				(*queued)++;
+				break;
+			case REQUEST_STATE_PROCESSING:
+				if (*processing < ZBX_MAX_REQUEST_STATE_PRINT_LIMIT)
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "oldest processing itemid: " ZBX_FS_UI64
+							" values:%d pos:%d", item->itemid, item->values_num, *total);
+				}
+				(*processing)++;
+				break;
+			case REQUEST_STATE_DONE:
+				if (*done < ZBX_MAX_REQUEST_STATE_PRINT_LIMIT)
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "oldest done itemid: " ZBX_FS_UI64
+							" values:%d pos:%d", item->itemid, item->values_num, *total);
+				}
+				(*done)++;
+				break;
+			case REQUEST_STATE_PENDING:
+				if (*pending < ZBX_MAX_REQUEST_STATE_PRINT_LIMIT)
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "oldest pending itemid: " ZBX_FS_UI64
+							" values:%d pos:%d", item->itemid, item->values_num, *total);
+				}
+				(*pending)++;
+				break;
+		}
+
+		item->values_num++;
+		(*total)++;
+	}
+
+	zbx_hashset_destroy(&items);
+#undef ZBX_MAX_REQUEST_STATE_PRINT_LIMIT
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: preprocessor_get_diag_stats                                      *
@@ -1093,10 +1257,13 @@ static void	preprocessor_get_diag_stats(zbx_preprocessing_manager_t *manager, zb
 {
 	unsigned char	*data;
 	zbx_uint32_t	data_len;
+	int		total, queued, processing, done, pending;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	data_len = zbx_preprocessor_pack_diag_stats(&data, manager->queued_num, manager->preproc_num);
+	preprocessor_get_items_totals(manager, &total, &queued, &processing, &done, &pending);
+
+	data_len = zbx_preprocessor_pack_diag_stats(&data, total, queued, processing, done, pending);
 	zbx_ipc_client_send(client, ZBX_IPC_PREPROCESSOR_DIAG_STATS_RESULT, data, data_len);
 	zbx_free(data);
 
@@ -1118,6 +1285,34 @@ static int	preproc_sort_item_by_values_desc(const void *d1, const void *d2)
 	return i2->values_num - i1->values_num;
 }
 
+static	void	preprocessor_get_items_view(zbx_preprocessing_manager_t *manager, zbx_hashset_t *items,
+		zbx_vector_ptr_t *view)
+{
+	zbx_preproc_item_stats_t	*item;
+	zbx_list_iterator_t		iterator;
+	zbx_preprocessing_request_t	*request;
+
+	zbx_list_iterator_init(&manager->queue, &iterator);
+	while (SUCCEED == zbx_list_iterator_next(&iterator))
+	{
+		zbx_list_iterator_peek(&iterator, (void **)&request);
+
+		if (NULL == (item = zbx_hashset_search(items, &request->value.itemid)))
+		{
+			zbx_preproc_item_stats_t	item_local = {.itemid = request->value.itemid};
+
+			item = zbx_hashset_insert(items, &item_local, sizeof(item_local));
+			zbx_vector_ptr_append(view, item);
+		}
+		/* There might be processed, but not yet flushed items at the start of queue with    */
+		/* freed preprocessing steps and steps_num being zero. Because of that keep updating */
+		/* items steps_num to have preprocessing steps of last queued item.                  */
+		item->steps_num = request->steps_num;
+		item->values_num++;
+	}
+}
+
+
 /******************************************************************************
  *                                                                            *
  * Function: preprocessor_get_top_items                                       *
@@ -1132,15 +1327,11 @@ static int	preproc_sort_item_by_values_desc(const void *d1, const void *d2)
 static void	preprocessor_get_top_items(zbx_preprocessing_manager_t *manager, zbx_ipc_client_t *client,
 		zbx_ipc_message_t *message)
 {
-	int				limit;
-	unsigned char			*data;
-	zbx_uint32_t			data_len;
-	zbx_hashset_t			items;
-	zbx_vector_ptr_t		view;
-	zbx_list_iterator_t		iterator;
-	zbx_preprocessing_request_t	*request;
-	zbx_preproc_item_stats_t	*item;
-	int				items_num;
+	int			limit;
+	unsigned char		*data;
+	zbx_uint32_t		data_len;
+	zbx_hashset_t		items;
+	zbx_vector_ptr_t	view;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
@@ -1149,29 +1340,12 @@ static void	preprocessor_get_top_items(zbx_preprocessing_manager_t *manager, zbx
 	zbx_hashset_create(&items, 1024, ZBX_DEFAULT_UINT64_HASH_FUNC, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
 	zbx_vector_ptr_create(&view);
 
-	zbx_list_iterator_init(&manager->queue, &iterator);
-	while (SUCCEED == zbx_list_iterator_next(&iterator))
-	{
-		zbx_list_iterator_peek(&iterator, (void **)&request);
-
-		if (NULL == (item = zbx_hashset_search(&items, &request->value.itemid)))
-		{
-			zbx_preproc_item_stats_t	item_local = {.itemid = request->value.itemid};
-
-			item = zbx_hashset_insert(&items, &item_local, sizeof(item_local));
-			zbx_vector_ptr_append(&view, item);
-		}
-		/* There might be processed, but not yet flushed items at the start of queue with    */
-		/* freed preprocessing steps and steps_num being zero. Because of that keep updating */
-		/* items steps_num to have preprocessing steps of last queued item.                  */
-		item->steps_num = request->steps_num;
-		item->values_num++;
-	}
+	preprocessor_get_items_view(manager, &items, &view);
 
 	zbx_vector_ptr_sort(&view, preproc_sort_item_by_values_desc);
-	items_num = MIN(limit, view.values_num);
 
-	data_len = zbx_preprocessor_pack_top_items_result(&data, (zbx_preproc_item_stats_t **)view.values, items_num);
+	data_len = zbx_preprocessor_pack_top_items_result(&data, (zbx_preproc_item_stats_t **)view.values,
+			MIN(limit, view.values_num));
 	zbx_ipc_client_send(client, ZBX_IPC_PREPROCESSOR_TOP_ITEMS_RESULT, data, data_len);
 	zbx_free(data);
 
@@ -1181,6 +1355,52 @@ static void	preprocessor_get_top_items(zbx_preprocessing_manager_t *manager, zbx
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
+static void	preprocessor_get_oldest_preproc_items(zbx_preprocessing_manager_t *manager, zbx_ipc_client_t *client,
+		zbx_ipc_message_t *message)
+{
+	int			limit, i;
+	unsigned char		*data;
+	zbx_uint32_t		data_len;
+	zbx_hashset_t		items;
+	zbx_vector_ptr_t	view, view_preproc;
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
+
+	zbx_preprocessor_unpack_top_request(&limit, message->data);
+
+	zbx_hashset_create(&items, 1024, ZBX_DEFAULT_UINT64_HASH_FUNC, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+	zbx_vector_ptr_create(&view);
+	zbx_vector_ptr_create(&view_preproc);
+	zbx_vector_ptr_reserve(&view_preproc, limit);
+
+	preprocessor_get_items_view(manager, &items, &view);
+
+	for (i = 0; i < view.values_num && 0 < limit; i++)
+	{
+		zbx_preproc_item_stats_t	*item;
+
+		item = (zbx_preproc_item_stats_t *)view.values[i];
+
+		/* only items with preprocessing can slow down queue */
+		if (0 == item->steps_num)
+			continue;
+
+		zbx_vector_ptr_append(&view_preproc, item);
+		limit--;
+	}
+
+	data_len = zbx_preprocessor_pack_top_items_result(&data, (zbx_preproc_item_stats_t **)view_preproc.values,
+			MIN(limit, view_preproc.values_num));
+	zbx_ipc_client_send(client, ZBX_IPC_PREPROCESSOR_TOP_ITEMS_RESULT, data, data_len);
+	zbx_free(data);
+
+	zbx_vector_ptr_destroy(&view_preproc);
+	zbx_vector_ptr_destroy(&view);
+	zbx_hashset_destroy(&items);
+
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: preprocessor_init_manager                                        *
@@ -1253,38 +1473,6 @@ static void preprocessor_register_worker(zbx_preprocessing_manager_t *manager, z
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: preprocessor_destroy_manager                                     *
- *                                                                            *
- * Purpose: destroy preprocessing manager                                     *
- *                                                                            *
- * Parameters: manager - [IN] the manager to destroy                          *
- *                                                                            *
- ******************************************************************************/
-static void	preprocessor_destroy_manager(zbx_preprocessing_manager_t *manager)
-{
-	zbx_preprocessing_request_t		*request;
-	zbx_preprocessing_direct_request_t	*direct_request;
-
-	zbx_free(manager->workers);
-
-	/* this is the place where values are lost */
-	while (SUCCEED == zbx_list_pop(&manager->direct_queue, (void **)&direct_request))
-		preprocessor_free_direct_request(direct_request);
-
-	zbx_list_destroy(&manager->direct_queue);
-
-	while (SUCCEED == zbx_list_pop(&manager->queue, (void **)&request))
-		preprocessor_free_request(request);
-
-	zbx_list_destroy(&manager->queue);
-
-	zbx_hashset_destroy(&manager->item_config);
-	zbx_hashset_destroy(&manager->linked_items);
-	zbx_hashset_destroy(&manager->history_cache);
-}
-
 ZBX_THREAD_ENTRY(preprocessing_manager_thread, args)
 {
 	zbx_ipc_service_t		service;
@@ -1378,6 +1566,9 @@ ZBX_THREAD_ENTRY(preprocessing_manager_thread, args)
 				case ZBX_IPC_PREPROCESSOR_TOP_ITEMS:
 					preprocessor_get_top_items(&manager, client, message);
 					break;
+				case ZBX_IPC_PREPROCESSOR_TOP_OLDEST_PREPROC_ITEMS:
+					preprocessor_get_oldest_preproc_items(&manager, client, message);
+					break;
 			}
 
 			zbx_ipc_message_free(message);
@@ -1397,8 +1588,5 @@ ZBX_THREAD_ENTRY(preprocessing_manager_thread, args)
 
 	while (1)
 		zbx_sleep(SEC_PER_MIN);
-
-	zbx_ipc_service_close(&service);
-	preprocessor_destroy_manager(&manager);
 #undef STAT_INTERVAL
 }
