@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 static int	execute_remote_script(zbx_script_t *script, DC_HOST *host, char **info, char *error,
 		size_t max_error_len)
 {
-	int		ret = FAIL, time_start;
+	int		time_start;
 	zbx_uint64_t	taskid;
 	DB_RESULT	result = NULL;
 	DB_ROW		row;
@@ -62,6 +62,8 @@ static int	execute_remote_script(zbx_script_t *script, DC_HOST *host, char **inf
 
 		if (NULL != (row = DBfetch(result)))
 		{
+			int	ret;
+
 			if (SUCCEED == (ret = atoi(row[0])))
 				*info = zbx_strdup(*info, row[1]);
 			else
