@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -96,7 +96,6 @@ typedef struct
 {
 	const char		*name;
 	zbx_entry_type_t	entry_type;
-	zbx_user_type_t		access_level;
 	int			*res;
 	zbx_section_entry_t	entries[ZBX_MAX_SECTION_ENTRIES];
 }
@@ -706,7 +705,7 @@ static void	zbx_status_counters_free(void)
 }
 
 const zbx_status_section_t	status_sections[] = {
-/*	{SECTION NAME,			NUMBER OF SECTION ENTRIES	SECTION ACCESS LEVEL	SECTION READYNESS, */
+/*	{SECTION NAME,			NUMBER OF SECTION ENTRIES	SECTION READYNESS,                         */
 /*		{                                                                                                  */
 /*			{ENTRY INFORMATION,		COUNTER TYPE,                                              */
 /*				{                                                                                  */
@@ -718,7 +717,7 @@ const zbx_status_section_t	status_sections[] = {
 /*		}                                                                                                  */
 /*	},                                                                                                         */
 /*	...                                                                                                        */
-	{"template stats",		ZBX_SECTION_ENTRY_THE_ONLY,	USER_TYPE_ZABBIX_USER,	&templates_res,
+	{"template stats",		ZBX_SECTION_ENTRY_THE_ONLY,	&templates_res,
 		{
 			{&templates,			ZBX_COUNTER_TYPE_UI64,
 				{
@@ -728,7 +727,7 @@ const zbx_status_section_t	status_sections[] = {
 			{NULL}
 		}
 	},
-	{"host stats",			ZBX_SECTION_ENTRY_PER_PROXY,	USER_TYPE_ZABBIX_USER,	NULL,
+	{"host stats",			ZBX_SECTION_ENTRY_PER_PROXY,	NULL,
 		{
 			{&hosts_monitored,		ZBX_COUNTER_TYPE_UI64,
 				{
@@ -745,7 +744,7 @@ const zbx_status_section_t	status_sections[] = {
 			{NULL}
 		}
 	},
-	{"item stats",			ZBX_SECTION_ENTRY_PER_PROXY,	USER_TYPE_ZABBIX_USER,	NULL,
+	{"item stats",			ZBX_SECTION_ENTRY_PER_PROXY,	NULL,
 		{
 			{&items_active_normal,		ZBX_COUNTER_TYPE_UI64,
 				{
@@ -770,7 +769,7 @@ const zbx_status_section_t	status_sections[] = {
 			{NULL}
 		}
 	},
-	{"trigger stats",		ZBX_SECTION_ENTRY_THE_ONLY,	USER_TYPE_ZABBIX_USER,	NULL,
+	{"trigger stats",		ZBX_SECTION_ENTRY_THE_ONLY,	NULL,
 		{
 			{&triggers_enabled_ok,		ZBX_COUNTER_TYPE_UI64,
 				{
@@ -795,7 +794,7 @@ const zbx_status_section_t	status_sections[] = {
 			{NULL}
 		}
 	},
-	{"user stats",			ZBX_SECTION_ENTRY_THE_ONLY,	USER_TYPE_ZABBIX_USER,	&users_res,
+	{"user stats",			ZBX_SECTION_ENTRY_THE_ONLY,	&users_res,
 		{
 			{&users_online,			ZBX_COUNTER_TYPE_UI64,
 				{
@@ -812,7 +811,7 @@ const zbx_status_section_t	status_sections[] = {
 			{NULL}
 		}
 	},
-	{"required performance",	ZBX_SECTION_ENTRY_PER_PROXY,	USER_TYPE_SUPER_ADMIN,	NULL,
+	{"required performance",	ZBX_SECTION_ENTRY_PER_PROXY,	NULL,
 		{
 			{&required_performance,		ZBX_COUNTER_TYPE_DBL,
 				{
@@ -864,7 +863,7 @@ static void	status_entry_export(struct zbx_json *json, const zbx_section_entry_t
 	zbx_free(tmp);
 }
 
-static void	status_stats_export(struct zbx_json *json, zbx_user_type_t access_level)
+static void	status_stats_export(struct zbx_json *json)
 {
 	const zbx_status_section_t	*section;
 	const zbx_section_entry_t	*entry;
@@ -884,9 +883,6 @@ static void	status_stats_export(struct zbx_json *json, zbx_user_type_t access_le
 	/* add status information to JSON */
 	for (section = status_sections; NULL != section->name; section++)
 	{
-		if (access_level < section->access_level)	/* skip sections user has no rights to access */
-			continue;
-
 		if (NULL != section->res && SUCCEED != *section->res)	/* skip section we have no information for */
 			continue;
 
@@ -983,7 +979,10 @@ static int	recv_getstatus(zbx_socket_t *sock, struct zbx_json_parse *jp)
 		case ZBX_GET_STATUS_FULL:
 			zbx_json_addstring(&json, ZBX_PROTO_TAG_RESPONSE, ZBX_PROTO_VALUE_SUCCESS, ZBX_JSON_TYPE_STRING);
 			zbx_json_addobject(&json, ZBX_PROTO_TAG_DATA);
-			status_stats_export(&json, user.type);
+
+			if (USER_TYPE_SUPER_ADMIN == user.type)
+				status_stats_export(&json);
+
 			zbx_json_close(&json);
 			break;
 		default:
@@ -1254,7 +1253,7 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 					key[ITEM_KEY_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1];
 		zbx_agent_value_t	av;
 		zbx_host_key_t		hk = {host, key};
-		DC_ITEM			item;
+		zbx_history_recv_item_t	item;
 		int			errcode;
 
 		if (ZBX_GIBIBYTE < bytes_received)
@@ -1309,9 +1308,8 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 		if (0 == strcmp(av.value, ZBX_NOTSUPPORTED))
 			av.state = ITEM_STATE_NOTSUPPORTED;
 
-		DCconfig_get_items_by_keys(&item, &hk, &errcode, 1);
+		zbx_dc_config_history_recv_get_items_by_keys(&item, &hk, &errcode, 1);
 		process_history_data(&item, &av, &errcode, 1, NULL);
-		DCconfig_clean_items(&item, &errcode, 1);
 
 		zbx_alarm_on(CONFIG_TIMEOUT);
 		if (SUCCEED != zbx_tcp_send_raw(sock, "OK"))
@@ -1367,13 +1365,6 @@ ZBX_THREAD_ENTRY(trapper_thread, args)
 
 	DBconnect(ZBX_DB_CONNECT_NORMAL);
 
-	/* configuration sync is performed by trappers on passive Zabbix proxy */
-	if (1 == process_num && 0 == CONFIG_CONFSYNCER_FORKS)
-	{
-		zbx_setproctitle("%s [syncing configuration]", get_process_type_string(process_type));
-		DCsync_configuration(ZBX_DBSYNC_INIT);
-	}
-
 	zbx_set_sigusr_handler(zbx_trapper_sigusr_handler);
 
 	while (ZBX_IS_RUNNING())
