@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -164,6 +164,12 @@ class CControllerPopupItemTestEdit extends CControllerPopupItemTest {
 								$texts_support_user_macros[] = $token['data']['string'];
 								$texts_support_lld_macros[] = $token['data']['string'];
 								break;
+
+							case CTriggerExprParserResult::TOKEN_TYPE_FUNCTION:
+								$texts_support_user_macros = array_merge($token['data']['functionParams'],
+									$texts_support_user_macros
+								);
+								break;
 						}
 					}
 				}
@@ -195,20 +201,31 @@ class CControllerPopupItemTestEdit extends CControllerPopupItemTest {
 				}
 			}
 			elseif (strstr($inputs[$field], '{') !== false) {
+				if ($field === 'key') {
+					$item_key_parser = new CItemKey();
+
+					$texts_having_macros = $item_key_parser->parse($key) == CParser::PARSE_SUCCESS
+						? CMacrosResolverGeneral::getItemKeyParameters($item_key_parser->getParamsRaw())
+						: [];
+				}
+				else {
+					$texts_having_macros = [$inputs[$field]];
+				}
+
 				// Field support macros like {HOST.*}, {ITEM.*} etc.
 				if ($macros) {
 					$supported_macros = array_merge_recursive($supported_macros, $macros);
-					$texts_support_macros[] = $inputs[$field];
+					$texts_support_macros = array_merge($texts_support_macros, $texts_having_macros);
 				}
 
 				// Check if LLD macros are supported in field.
 				if ($support_lldmacros && $this->macros_by_item_props[$field]['support_lld_macros']) {
-					$texts_support_lld_macros[] = $inputs[$field];
+					$texts_support_lld_macros = array_merge($texts_support_lld_macros, $texts_having_macros);
 				}
 
 				// Check if user macros are supported in field.
 				if ($this->macros_by_item_props[$field]['support_user_macros']) {
-					$texts_support_user_macros[] = $inputs[$field];
+					$texts_support_user_macros = array_merge($texts_support_user_macros, $texts_having_macros);
 				}
 			}
 		}
