@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class CControllerRegExUpdate extends CController {
 			'test_string'  => 'string | db regexps.test_string',
 			'regexid'      => 'fatal | required | db regexps.regexpid',
 			'expressions'  => 'required | array',
-			'form_refresh' => ''
+			'form_refresh' => 'int32'
 		];
 
 		$ret = $this->validateInput($fields);
