@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -48,8 +48,9 @@ if ($data['form_refresh'] == 0) {
 
 // Create form.
 $user_form = (new CForm())
+	->addVar('form_refresh', $data['form_refresh'] + 1)
 	->setName('user_form')
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
+	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('action', $data['action'])
 	->addVar('userid', $data['userid']);
 
@@ -345,7 +346,7 @@ if ($data['action'] === 'user.edit') {
 			if (array_key_exists('grouped', $group_rights) && $group_rights['grouped']) {
 				$group_name = ($groupid == 0)
 					? italic(_('All groups'))
-					: [$group_rights['name'], SPACE, italic('('._('including subgroups').')')];
+					: [$group_rights['name'], NBSP(), italic('('._('including subgroups').')')];
 			}
 			else {
 				$group_name = $group_rights['name'];
