@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -89,8 +89,10 @@ $override_evaltype = (new CDiv([
 				DB::getFieldLength('lld_override', 'formula')))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setId('overrides_formula')
-			->setAttribute('placeholder', 'A or (B and C) &hellip;')
-	]))->addClass(ZBX_STYLE_CELL)
+			->setAttribute('placeholder', 'A or (B and C) ...')
+	]))
+		->addClass(ZBX_STYLE_CELL)
+		->addClass(ZBX_STYLE_CELL_EXPRESSION)
 ]))
 	->addClass(ZBX_STYLE_ROW)
 	->setId('overrideRow');
