@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -271,11 +271,6 @@ function getSystemStatusData(array $filter) {
 				'output' => ['alias', 'name', 'surname'],
 				'userids' => array_keys($actions['userids']),
 				'preservekeys' => true
-			]),
-			'mediatypes' => API::MediaType()->get([
-				'output' => ['name', 'maxattempts'],
-				'mediatypeids' => array_keys($actions['mediatypeids']),
-				'preservekeys' => true
 			])
 		];
 
@@ -624,54 +619,68 @@ function make_status_of_zbx() {
 			(new CSpan($status['is_running'] ? _('Yes') : _('No')))
 				->addClass($status['is_running'] ? ZBX_STYLE_GREEN : ZBX_STYLE_RED),
 			$server_details
-		])
-		->addRow([_('Number of hosts (enabled/disabled)'),
-			$status['has_status'] ? $status['hosts_count'] : '',
-			$status['has_status']
-				? [
-					(new CSpan($status['hosts_count_monitored']))->addClass(ZBX_STYLE_GREEN), ' / ',
-					(new CSpan($status['hosts_count_not_monitored']))->addClass(ZBX_STYLE_RED)
-				]
-				: ''
-		])
-		->addRow([_('Number of templates'),
-			$status['has_status'] ? $status['hosts_count_template'] : '', ''
 		]);
 
-	$title = (new CSpan(_('Number of items (enabled/disabled/not supported)')))
-		->setTitle(_('Only items assigned to enabled hosts are counted'));
-	$table->addRow([$title, $status['has_status'] ? $status['items_count'] : '',
-		$status['has_status']
-			? [
-				(new CSpan($status['items_count_monitored']))->addClass(ZBX_STYLE_GREEN), ' / ',
-				(new CSpan($status['items_count_disabled']))->addClass(ZBX_STYLE_RED), ' / ',
-				(new CSpan($status['items_count_not_supported']))->addClass(ZBX_STYLE_GREY)
-			]
-			: ''
-	]);
-	$title = (new CSpan(_('Number of triggers (enabled/disabled [problem/ok])')))
-		->setTitle(_('Only triggers assigned to enabled hosts and depending on enabled items are counted'));
-	$table->addRow([$title, $status['has_status'] ? $status['triggers_count'] : '',
-		$status['has_status']
-			? [
-				$status['triggers_count_enabled'], ' / ',
-				$status['triggers_count_disabled'], ' [',
-				(new CSpan($status['triggers_count_on']))->addClass(ZBX_STYLE_RED), ' / ',
-				(new CSpan($status['triggers_count_off']))->addClass(ZBX_STYLE_GREEN), ']'
-			]
-			: ''
-	]);
-	$table->addRow([_('Number of users (online)'), $status['has_status'] ? $status['users_count'] : '',
-		$status['has_status'] ? (new CSpan($status['users_online']))->addClass(ZBX_STYLE_GREEN) : ''
-	]);
 	if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
-		$table->addRow([_('Required server performance, new values per second'),
-			($status['has_status'] && array_key_exists('vps_total', $status)) ? round($status['vps_total'], 2) : '', ''
-		]);
-	}
+		$table
+			->addRow([
+				_('Number of hosts (enabled/disabled)'),
+				$status['has_status'] ? $status['hosts_count'] : '',
+				$status['has_status']
+					? [
+						(new CSpan($status['hosts_count_monitored']))->addClass(ZBX_STYLE_GREEN),
+						' / ',
+						(new CSpan($status['hosts_count_not_monitored']))->addClass(ZBX_STYLE_RED)
+					]
+					: ''
+			])
+			->addRow([
+				_('Number of templates'),
+				$status['has_status'] ? $status['hosts_count_template'] : '', ''
+			])
+			->addRow([
+				(new CSpan(_('Number of items (enabled/disabled/not supported)')))
+					->setTitle(_('Only items assigned to enabled hosts are counted')),
+				$status['has_status'] ? $status['items_count'] : '',
+				$status['has_status']
+					? [
+						(new CSpan($status['items_count_monitored']))->addClass(ZBX_STYLE_GREEN),
+						' / ',
+						(new CSpan($status['items_count_disabled']))->addClass(ZBX_STYLE_RED),
+						' / ',
+						(new CSpan($status['items_count_not_supported']))->addClass(ZBX_STYLE_GREY)
+					]
+					: ''
+			])
+			->addRow([
+				(new CSpan(_('Number of triggers (enabled/disabled [problem/ok])')))
+					->setTitle(_('Only triggers assigned to enabled hosts and depending on enabled items are counted')),
+				$status['has_status'] ? $status['triggers_count'] : '',
+				$status['has_status']
+					? [
+						$status['triggers_count_enabled'],
+						' / ',
+						$status['triggers_count_disabled'],
+						' [',
+						(new CSpan($status['triggers_count_on']))->addClass(ZBX_STYLE_RED),
+						' / ',
+						(new CSpan($status['triggers_count_off']))->addClass(ZBX_STYLE_GREEN),
+						']'
+					]
+					: ''
+			])
+			->addRow([
+				_('Number of users (online)'),
+				$status['has_status'] ? $status['users_count'] : '',
+				$status['has_status'] ? (new CSpan($status['users_online']))->addClass(ZBX_STYLE_GREEN) : ''
+			])
+			->addRow([
+				_('Required server performance, new values per second'),
+				($status['has_status'] && array_key_exists('vps_total', $status)) ? round($status['vps_total'], 2) : '',
+				''
+			]);
 
-	// Check requirements.
-	if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
+		// Check requirements.
 		$setup = new CFrontendSetup();
 		$reqs = $setup->checkRequirements();
 		$reqs[] = $setup->checkSslFiles();
@@ -691,17 +700,57 @@ function make_status_of_zbx() {
 				(new CRow((new CCol($db->getWarning()))->setAttribute('colspan', 3)))->addClass(ZBX_STYLE_RED)
 			);
 		}
+
+		// Warn if database history tables have not been upgraded.
+		global $DB;
+
+		if (!$DB['DOUBLE_IEEE754']) {
+			$table->addRow([
+				_('Database history tables upgraded'),
+				(new CSpan(_('No')))->addClass(ZBX_STYLE_RED),
+				''
+			]);
+		}
 	}
 
-	// Warn if database history tables have not been upgraded.
-	global $DB;
+	if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN && $DB['TYPE'] == ZBX_DB_POSTGRESQL) {
+		$config = select_config();
 
-	if (!$DB['DOUBLE_IEEE754']) {
-		$table->addRow([
-			_('Database history tables upgraded'),
-			(new CSpan(_('No')))->addClass(ZBX_STYLE_RED),
-			''
-		]);
+		if ($config['db_extension'] === ZBX_DB_EXTENSION_TIMESCALEDB && $config['compression_availability'] == 1) {
+			if ($config['hk_history_mode'] == 1 && $config['hk_history_global'] == 0) {
+				if (PostgresqlDbBackend::isCompressed([
+					'history', 'history_log', 'history_str', 'history_text', 'history_uint'
+				])) {
+					$table->addRow((new CRow([
+						_('Housekeeping'),
+						_('Override item history period'),
+						(new CCol([
+							_('This setting should be enabled, because history tables contain compressed chunks.'),
+							' ',
+							new CLink([_('Configuration'), HELLIP()],
+								(new CUrl('zabbix.php'))->setArgument('action', 'housekeeping.edit')
+							)
+						]))->addClass(ZBX_STYLE_RED)
+					])));
+				}
+			}
+
+			if ($config['hk_trends_mode'] == 1 && $config['hk_trends_global'] == 0) {
+				if (PostgresqlDbBackend::isCompressed(['trends', 'trends_uint'])) {
+					$table->addRow((new CRow([
+						_('Housekeeping'),
+						_('Override item trend period'),
+						(new CCol([
+							_('This setting should be enabled, because trend tables contain compressed chunks.'),
+							' ',
+							new CLink([_('Configuration'), HELLIP()],
+								(new CUrl('zabbix.php'))->setArgument('action', 'housekeeping.edit')
+							)
+						]))->addClass(ZBX_STYLE_RED)
+					])));
+				}
+			}
+		}
 	}
 
 	return $table;
@@ -883,9 +932,7 @@ function makeProblemsPopup(array $problems, array $triggers, array $actions, arr
 			($show_opdata == OPERATIONAL_DATA_SHOW_SEPARATELY) ? $opdata : null,
 			zbx_date2age($problem['clock']),
 			$problem_update_link,
-			makeEventActionsIcons($problem['eventid'], $actions['all_actions'], $actions['mediatypes'],
-				$actions['users'], $config
-			),
+			makeEventActionsIcons($problem['eventid'], $actions['all_actions'], $actions['users'], $config),
 			$tags[$problem['eventid']]
 		]));
 	}
