@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -139,7 +139,7 @@ class CDRule extends CApiService {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$dbRes = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$dbRes = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($drule = DBfetch($dbRes)) {
 			if ($options['countOutput']) {
 				if ($options['groupCount']) {
@@ -886,7 +886,7 @@ class CDRule extends CApiService {
 		if ($actionIds) {
 			DB::update('actions', [
 				'values' => ['status' => ACTION_STATUS_DISABLED],
-				'where' => ['actionid' => $actionIds],
+				'where' => ['actionid' => $actionIds]
 			]);
 
 			DB::delete('conditions', [
@@ -904,16 +904,22 @@ class CDRule extends CApiService {
 		// Adding Discovery Checks
 		if (!is_null($options['selectDChecks'])) {
 			if ($options['selectDChecks'] != API_OUTPUT_COUNT) {
+				$dchecks = [];
 				$relationMap = $this->createRelationMap($result, 'druleid', 'dcheckid', 'dchecks');
-				$dchecks = API::DCheck()->get([
-					'output' => $options['selectDChecks'],
-					'dcheckids' => $relationMap->getRelatedIds(),
-					'nopermissions' => true,
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($dchecks, 'dcheckid');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$dchecks = API::DCheck()->get([
+						'output' => $options['selectDChecks'],
+						'dcheckids' => $related_ids,
+						'nopermissions' => true,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($dchecks, 'dcheckid');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $dchecks, 'dchecks', $options['limitSelects']);
 			}
 			else {
@@ -935,15 +941,21 @@ class CDRule extends CApiService {
 		// Adding Discovery Hosts
 		if (!is_null($options['selectDHosts'])) {
 			if ($options['selectDHosts'] != API_OUTPUT_COUNT) {
+				$dhosts = [];
 				$relationMap = $this->createRelationMap($result, 'druleid', 'dhostid', 'dhosts');
-				$dhosts = API::DHost()->get([
-					'output' => $options['selectDHosts'],
-					'dhostids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($dhosts, 'dhostid');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$dhosts = API::DHost()->get([
+						'output' => $options['selectDHosts'],
+						'dhostids' => $related_ids,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($dhosts, 'dhostid');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $dhosts, 'dhosts', $options['limitSelects']);
 			}
 			else {
