@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -548,11 +548,8 @@ class CHost extends CHostGeneral {
 					')';
 				}
 
-				$sqlParts['left_join']['hosts_templates'] = [
-					'from' => 'hosts_templates ht2',
-					'on' => 'h.hostid=ht2.hostid'
-				];
-				$sqlParts['left_table'] = $this->tableName();
+				$sqlParts['left_join'][] = ['alias' => 'ht2', 'table' => 'hosts_templates', 'using' => 'hostid'];
+				$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
 
 				$operator = ($options['evaltype'] == TAG_EVAL_TYPE_AND_OR) ? ' AND ' : ' OR ';
 				$sqlParts['where'][] = '('.implode($operator, $where).')';
@@ -575,7 +572,7 @@ class CHost extends CHostGeneral {
 
 		// Return count or grouped counts via direct SQL count.
 		if ($options['countOutput'] && !$this->requiresPostSqlFiltering($options)) {
-			$res = DBselect($this->createSelectQueryFromParts($sqlParts), $options['limit']);
+			$res = DBselect(self::createSelectQueryFromParts($sqlParts), $options['limit']);
 			while ($host = DBfetch($res)) {
 				if ($options['groupCount']) {
 					$result[] = $host;
@@ -588,15 +585,25 @@ class CHost extends CHostGeneral {
 			return $result;
 		}
 
-		$result = zbx_toHash($this->customFetch($this->createSelectQueryFromParts($sqlParts), $options), 'hostid');
+		$result = zbx_toHash($this->customFetch(self::createSelectQueryFromParts($sqlParts), $options), 'hostid');
 
 		// Return count for post SQL filtered result sets.
 		if ($options['countOutput']) {
 			return (string) count($result);
 		}
 
+		// Hosts share table with host prototypes. Therefore remove host unrelated fields.
+		if ($this->outputIsRequested('discover', $options['output'])) {
+			foreach ($result as &$row) {
+				unset($row['discover']);
+			}
+
+			unset($row);
+		}
+
 		if ($result) {
 			$result = $this->addRelatedObjects($options, $result);
+			$result = $this->unsetExtraFields($result, ['name_upper'], []);
 		}
 
 		// removing keys (hash -> array)
@@ -636,6 +643,12 @@ class CHost extends CHostGeneral {
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
 		$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 
+		$upcased_index = array_search($tableAlias.'.name_upper', $sqlParts['select']);
+
+		if ($upcased_index !== false) {
+			unset($sqlParts['select'][$upcased_index]);
+		}
+
 		if (!$options['countOutput'] && $this->outputIsRequested('inventory_mode', $options['output'])) {
 			$sqlParts['select']['inventory_mode'] =
 				dbConditionCoalesce('hinv.inventory_mode', HOST_INVENTORY_DISABLED, 'inventory_mode');
@@ -643,11 +656,8 @@ class CHost extends CHostGeneral {
 
 		if ((!$options['countOutput'] && $this->outputIsRequested('inventory_mode', $options['output']))
 				|| ($options['filter'] && array_key_exists('inventory_mode', $options['filter']))) {
-			$sqlParts['left_join'][] = [
-				'from' => 'host_inventory hinv',
-				'on' => $this->tableAlias().'.'.$this->pk().'=hinv.hostid'
-			];
-			$sqlParts['left_table'] = $this->tableName();
+			$sqlParts['left_join'][] = ['alias' => 'hinv', 'table' => 'host_inventory', 'using' => 'hostid'];
+			$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
 		}
 
 		return $sqlParts;
@@ -698,81 +708,110 @@ class CHost extends CHostGeneral {
 
 		$this->validateCreate($hosts);
 
-		$hostids = [];
-		$ins_tags = [];
-		foreach ($hosts as $host) {
+		foreach ($hosts as &$host) {
 			// If visible name is not given or empty it should be set to host name.
-			if (!array_key_exists('name', $host) || !trim($host['name'])) {
+			if (!array_key_exists('name', $host) || trim($host['name']) === '') {
 				$host['name'] = $host['host'];
 			}
+		}
+		unset($host);
 
-			$hostid = DB::insert('hosts', [$host]);
-			$hostid = reset($hostid);
-			$host['hostid'] = $hostid;
-			$hostids[] = $hostid;
+		$hosts_groups = [];
+		$hosts_tags = [];
+		$hosts_interfaces = [];
+		$hosts_macros = [];
+		$hosts_inventory = [];
+		$templates_hostids = [];
 
-			// Save groups. Groups must be added before calling massAdd() for permission validation to work.
-			$groupsToAdd = [];
-			foreach ($host['groups'] as $group) {
-				$groupsToAdd[] = [
-					'hostid' => $hostid,
+		$hostids = DB::insert('hosts', $hosts);
+
+		foreach ($hosts as $index => &$host) {
+			$host['hostid'] = $hostids[$index];
+
+			foreach (zbx_toArray($host['groups']) as $group) {
+				$hosts_groups[] = [
+					'hostid' => $host['hostid'],
 					'groupid' => $group['groupid']
 				];
 			}
-			DB::insert('hosts_groups', $groupsToAdd);
 
 			if (array_key_exists('tags', $host)) {
-				foreach ($host['tags'] as $tag) {
-					$ins_tags[] = ['hostid' => $hostid] + $tag;
+				foreach (zbx_toArray($host['tags']) as $tag) {
+					$hosts_tags[] = ['hostid' => $host['hostid']] + $tag;
 				}
 			}
 
-			$options = [
-				'hosts' => $host
-			];
-
-			if (isset($host['templates']) && !is_null($host['templates'])) {
-				$options['templates'] = $host['templates'];
+			if (array_key_exists('interfaces', $host)) {
+				foreach (zbx_toArray($host['interfaces']) as $interface) {
+					$hosts_interfaces[] = ['hostid' => $host['hostid']] + $interface;
+				}
 			}
 
-			if (isset($host['macros']) && !is_null($host['macros'])) {
-				$options['macros'] = $host['macros'];
+			if (array_key_exists('macros', $host)) {
+				foreach (zbx_toArray($host['macros']) as $macro) {
+					$hosts_macros[] = ['hostid' => $host['hostid']] + $macro;
+				}
 			}
 
-			if (isset($host['interfaces']) && !is_null($host['interfaces'])) {
-				$options['interfaces'] = $host['interfaces'];
-			}
-
-			$result = API::Host()->massAdd($options);
-			if (!$result) {
-				self::exception();
+			if (array_key_exists('templates', $host)) {
+				foreach (zbx_toArray($host['templates']) as $template) {
+					$templates_hostids[$template['templateid']][] = $host['hostid'];
+				}
 			}
 
+			$host_inventory = [];
 			if (array_key_exists('inventory', $host) && $host['inventory']) {
-				$hostInventory = $host['inventory'];
-				$hostInventory['inventory_mode'] = HOST_INVENTORY_MANUAL;
-			}
-			else {
-				$hostInventory = [];
+				$host_inventory = $host['inventory'];
+				$host_inventory['inventory_mode'] = HOST_INVENTORY_MANUAL;
 			}
 
 			if (array_key_exists('inventory_mode', $host) && $host['inventory_mode'] != HOST_INVENTORY_DISABLED) {
-				$hostInventory['inventory_mode'] = $host['inventory_mode'];
+				$host_inventory['inventory_mode'] = $host['inventory_mode'];
 			}
 
-			if (array_key_exists('inventory_mode', $hostInventory)
-					&& ($hostInventory['inventory_mode'] == HOST_INVENTORY_MANUAL
-						|| $hostInventory['inventory_mode'] == HOST_INVENTORY_AUTOMATIC)) {
-				$hostInventory['hostid'] = $hostid;
-				DB::insert('host_inventory', [$hostInventory], false);
+			if (array_key_exists('inventory_mode', $host_inventory)) {
+				$hosts_inventory[] = ['hostid' => $host['hostid']] + $host_inventory;
 			}
 		}
+		unset($host);
 
-		if ($ins_tags) {
-			DB::insert('host_tag', $ins_tags);
+		DB::insertBatch('hosts_groups', $hosts_groups);
+
+		if ($hosts_tags) {
+			DB::insert('host_tag', $hosts_tags);
 		}
 
-		return ['hostids' => $hostids];
+		if ($hosts_interfaces) {
+			API::HostInterface()->create($hosts_interfaces);
+		}
+
+		if ($hosts_macros) {
+			API::UserMacro()->create($hosts_macros);
+		}
+
+		while ($templates_hostids) {
+			$templateid = key($templates_hostids);
+			$link_hostids = reset($templates_hostids);
+			$link_templateids = [$templateid];
+			unset($templates_hostids[$templateid]);
+
+			foreach ($templates_hostids as $templateid => $hostids) {
+				if ($link_hostids === $hostids) {
+					$link_templateids[] = $templateid;
+					unset($templates_hostids[$templateid]);
+				}
+			}
+
+			$this->link($link_templateids, $link_hostids);
+		}
+
+		if ($hosts_inventory) {
+			DB::insert('host_inventory', $hosts_inventory, false);
+		}
+
+		$this->addAuditBulk(AUDIT_ACTION_ADD, AUDIT_RESOURCE_HOST, $hosts);
+
+		return ['hostids' => array_column($hosts, 'hostid')];
 	}
 
 	/**
@@ -818,6 +857,11 @@ class CHost extends CHostGeneral {
 	 */
 	public function update($hosts) {
 		$hosts = zbx_toArray($hosts);
+
+		if (!$hosts) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		}
+
 		$hostids = zbx_objectValues($hosts, 'hostid');
 
 		$db_hosts = $this->get([
@@ -854,10 +898,14 @@ class CHost extends CHostGeneral {
 		$macros = [];
 		foreach ($hosts as &$host) {
 			if (isset($host['macros'])) {
-				$macros[$host['hostid']] = $host['macros'];
+				$macros[$host['hostid']] = zbx_toArray($host['macros']);
 
 				unset($host['macros']);
 			}
+
+			if (array_key_exists('tags', $host)) {
+				$host['tags'] = zbx_toArray($host['tags']);
+			}
 		}
 		unset($host);
 
@@ -966,7 +1014,10 @@ class CHost extends CHostGeneral {
 		sort($hostids);
 
 		$db_hosts = $this->get([
-			'output' => ['hostid', 'host'],
+			'output' => ['hostid', 'proxy_hostid', 'host', 'status', 'ipmi_authtype', 'ipmi_privilege', 'ipmi_username',
+				'ipmi_password', 'name', 'description', 'tls_connect', 'tls_accept', 'tls_issuer', 'tls_subject',
+				'tls_psk_identity', 'tls_psk', 'inventory_mode'
+			],
 			'hostids' => $hostids,
 			'editable' => true,
 			'preservekeys' => true
@@ -1112,12 +1163,8 @@ class CHost extends CHostGeneral {
 			$updateInventory['inventory_mode'] = $data['inventory_mode'];
 		}
 
-		if (isset($data['status'])) {
-			$updateStatus = $data['status'];
-		}
-
 		unset($data['hosts'], $data['groups'], $data['interfaces'], $data['templates_clear'], $data['templates'],
-			$data['macros'], $data['inventory'], $data['inventory_mode'], $data['status']);
+			$data['macros'], $data['inventory'], $data['inventory_mode']);
 
 		if (!zbx_empty($data)) {
 			DB::update('hosts', [
@@ -1126,10 +1173,6 @@ class CHost extends CHostGeneral {
 			]);
 		}
 
-		if (isset($updateStatus)) {
-			updateHostStatus($hostids, $updateStatus);
-		}
-
 		/*
 		 * Update template linkage
 		 */
@@ -1321,6 +1364,18 @@ class CHost extends CHostGeneral {
 			}
 		}
 
+		$new_hosts = [];
+		foreach ($db_hosts as $hostid => $db_host) {
+			$new_host = $data + $db_host;
+			if ($new_host['status'] != $db_host['status']) {
+				info(_s('Updated status of host "%1$s".', $new_host['host']));
+			}
+
+			$new_hosts[] = $new_host;
+		}
+
+		$this->addAuditBulk(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_HOST, $new_hosts, $db_hosts);
+
 		return ['hostids' => $inputHostIds];
 	}
 
@@ -1332,18 +1387,24 @@ class CHost extends CHostGeneral {
 	 * Additional supported $data parameters are:
 	 * - interfaces  - an array of interfaces to delete from the hosts
 	 *
+	 * @throws APIException if the input is invalid.
+	 *
 	 * @param array $data
 	 *
 	 * @return array
 	 */
 	public function massRemove(array $data) {
-		$hostids = zbx_toArray($data['hostids']);
+		if (!array_key_exists('hostids', $data) || $data['hostids'] === null) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
+		}
 
-		$this->checkPermissions($hostids, _('No permissions to referred object or it does not exist!'));
+		$data['hostids'] = zbx_toArray($data['hostids']);
+
+		$this->checkPermissions($data['hostids'], _('No permissions to referred object or it does not exist!'));
 
 		if (isset($data['interfaces'])) {
 			$options = [
-				'hostids' => $hostids,
+				'hostids' => $data['hostids'],
 				'interfaces' => zbx_toArray($data['interfaces'])
 			];
 			API::HostInterface()->massRemove($options);
@@ -1433,7 +1494,7 @@ class CHost extends CHostGeneral {
 			'preservekeys' => true
 		]);
 		if ($del_rules) {
-			API::DiscoveryRule()->delete(array_keys($del_rules), true);
+			CDiscoveryRuleManager::delete(array_keys($del_rules));
 		}
 
 		// delete the items
@@ -1520,7 +1581,7 @@ class CHost extends CHostGeneral {
 		}
 
 		DB::delete('opcommand_hst', [
-			'hostid' => $hostIds,
+			'hostid' => $hostIds
 		]);
 
 		// delete empty operations
@@ -1535,14 +1596,11 @@ class CHost extends CHostGeneral {
 		}
 
 		DB::delete('operations', [
-			'operationid' => $delOperationids,
+			'operationid' => $delOperationids
 		]);
 
-		$hosts = API::Host()->get([
-			'output' => [
-				'hostid',
-				'name'
-			],
+		$db_hosts = API::Host()->get([
+			'output' => ['hostid', 'name'],
 			'hostids' => $hostIds,
 			'nopermissions' => true
 		]);
@@ -1557,14 +1615,15 @@ class CHost extends CHostGeneral {
 		DB::delete('hosts', ['hostid' => $hostIds]);
 
 		// TODO: remove info from API
-		foreach ($hosts as $host) {
-			info(_s('Deleted: Host "%1$s".', $host['name']));
-			add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_HOST, $host['hostid'], $host['name'], 'hosts', NULL, NULL);
+		foreach ($db_hosts as $db_host) {
+			info(_s('Deleted: Host "%1$s".', $db_host['name']));
 		}
 
 		// remove Monitoring > Latest data toggle profile values related to given hosts
 		DB::delete('profiles', ['idx' => 'web.latest.toggle_other', 'idx2' => $hostIds]);
 
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_HOST, $db_hosts);
+
 		return ['hostids' => $hostIds];
 	}
 
@@ -1907,6 +1966,10 @@ class CHost extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateCreate(array $hosts) {
+		if (!$hosts) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		}
+
 		$host_name_parser = new CHostNameParser();
 
 		$host_db_fields = ['host' => null];
@@ -1945,7 +2008,19 @@ class CHost extends CHostGeneral {
 				);
 			}
 
-			$groupids = array_merge($groupids, zbx_objectValues($host['groups'], 'groupid'));
+			$host['groups'] = zbx_toArray($host['groups']);
+
+			foreach ($host['groups'] as $group) {
+				if (!is_array($group) || (is_array($group) && !array_key_exists('groupid', $group))) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_s('Incorrect value for field "%1$s": %2$s.', 'groups',
+							_s('the parameter "%1$s" is missing', 'groupid')
+						)
+					);
+				}
+
+				$groupids[$group['groupid']] = true;
+			}
 
 			// Validate tags.
 			if (array_key_exists('tags', $host)) {
@@ -1970,14 +2045,14 @@ class CHost extends CHostGeneral {
 		}
 
 		// Validate permissions to host groups.
-		if ($groupids) {
-			$db_groups = API::HostGroup()->get([
+		$db_groups = $groupids
+			? API::HostGroup()->get([
 				'output' => ['groupid'],
-				'groupids' => $groupids,
+				'groupids' => array_keys($groupids),
 				'editable' => true,
 				'preservekeys' => true
-			]);
-		}
+			])
+			: [];
 
 		foreach ($hosts as $host) {
 			foreach ($host['groups'] as $group) {
@@ -2099,7 +2174,7 @@ class CHost extends CHostGeneral {
 	protected function validateUpdate(array $hosts, array $db_hosts) {
 		$host_db_fields = ['hostid' => null];
 
-		foreach ($hosts as $host) {
+		foreach ($hosts as &$host) {
 			// Validate mandatory fields.
 			if (!check_db_fields($host_db_fields, $host)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
@@ -2120,14 +2195,29 @@ class CHost extends CHostGeneral {
 			}
 
 			// Validate "groups" field.
-			if (array_key_exists('groups', $host) && (!is_array($host['groups']) || !$host['groups'])) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Host "%1$s" cannot be without host group.', $db_hosts[$host['hostid']]['host'])
-				);
+			if (array_key_exists('groups', $host)) {
+				if (!is_array($host['groups']) || !$host['groups']) {
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						_s('Host "%1$s" cannot be without host group.', $db_hosts[$host['hostid']]['host'])
+					);
+				}
+
+				$host['groups'] = zbx_toArray($host['groups']);
+
+				foreach ($host['groups'] as $group) {
+					if (!is_array($group) || (is_array($group) && !array_key_exists('groupid', $group))) {
+						self::exception(ZBX_API_ERROR_PARAMETERS,
+							_s('Incorrect value for field "%1$s": %2$s.', 'groups',
+								_s('the parameter "%1$s" is missing', 'groupid')
+							)
+						);
+					}
+				}
 			}
 
 			// Permissions to host groups is validated in massUpdate().
 		}
+		unset($host);
 
 		$inventory_fields = zbx_objectValues(getHostInventories(), 'db_field');
 
@@ -2337,7 +2427,8 @@ class CHost extends CHostGeneral {
 				'hostids' => zbx_objectValues($hosts, 'hostid'),
 				'skipDependent' => true,
 				'status' => TRIGGER_STATUS_ENABLED,
-				'preservekeys' => true
+				'preservekeys' => true,
+				'nopermissions' => true
 			]);
 
 			$problems = API::Problem()->get([
@@ -2346,7 +2437,8 @@ class CHost extends CHostGeneral {
 				'source' => EVENT_SOURCE_TRIGGERS,
 				'object' => EVENT_OBJECT_TRIGGER,
 				'suppressed' => $options['withProblemsSuppressed'],
-				'severities' => $options['severities']
+				'severities' => $options['severities'],
+				'nopermissions' => true
 			]);
 
 			if (!$problems) {
