@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ abstract class CHostGeneral extends CHostBase {
 	 *
 	 * @throws APIException if the user doesn't have write permissions for the given hosts.
 	 */
-	private function checkHostPermissions(array $hostids) {
+	protected function checkHostPermissions(array $hostids) {
 		if ($hostids) {
 			$hostids = array_unique($hostids);
 
@@ -149,7 +149,11 @@ abstract class CHostGeneral extends CHostBase {
 			$this->unlink(zbx_toArray($data['templateids_clear']), $allHostIds, true);
 		}
 
-		if (isset($data['macros'])) {
+		if (array_key_exists('macros', $data)) {
+			if (!$data['macros']) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+			}
+
 			$hostMacros = API::UserMacro()->get([
 				'output' => ['hostmacroid'],
 				'hostids' => $allHostIds,
@@ -158,7 +162,9 @@ abstract class CHostGeneral extends CHostBase {
 				]
 			]);
 			$hostMacroIds = zbx_objectValues($hostMacros, 'hostmacroid');
-			API::UserMacro()->delete($hostMacroIds);
+			if ($hostMacroIds) {
+				API::UserMacro()->delete($hostMacroIds);
+			}
 		}
 
 		if (isset($data['groupids'])) {
@@ -169,71 +175,60 @@ abstract class CHostGeneral extends CHostBase {
 	}
 
 	protected function link(array $templateIds, array $targetIds) {
-		$hostsLinkageInserts = parent::link($templateIds, $targetIds);
+		$hosts_linkage_inserts = parent::link($templateIds, $targetIds);
+		$templates_hostids = [];
+		$link_requests = [];
 
-		foreach ($hostsLinkageInserts as $hostTplIds){
-			Manager::Application()->link($hostTplIds['templateid'], $hostTplIds['hostid']);
+		foreach ($hosts_linkage_inserts as $host_tpl_ids) {
+			$templates_hostids[$host_tpl_ids['templateid']][] = $host_tpl_ids['hostid'];
+		}
+
+		foreach ($templates_hostids as $templateid => $hostids) {
+			Manager::Application()->link($templateid, $hostids);
 
 			// Fist link web items, so that later regular items can use web item as their master item.
-			Manager::HttpTest()->link($hostTplIds['templateid'], $hostTplIds['hostid']);
+			Manager::HttpTest()->link($templateid, $hostids);
+		}
 
-			API::Item()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
+		while ($templates_hostids) {
+			$templateid = key($templates_hostids);
+			$link_request = [
+				'hostids' => reset($templates_hostids),
+				'templateids' => [$templateid]
+			];
+			unset($templates_hostids[$templateid]);
 
-			API::DiscoveryRule()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
+			foreach ($templates_hostids as $templateid => $hostids) {
+				if ($link_request['hostids'] === $hostids) {
+					$link_request['templateids'][] = $templateid;
+					unset($templates_hostids[$templateid]);
+				}
+			}
 
-			API::ItemPrototype()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
+			$link_requests[] = $link_request;
+		}
 
-			API::HostPrototype()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
+		foreach ($link_requests as $link_request) {
+			API::Item()->syncTemplates($link_request);
+			API::DiscoveryRule()->syncTemplates($link_request);
+			API::ItemPrototype()->syncTemplates($link_request);
+			API::HostPrototype()->syncTemplates($link_request);
 		}
 
 		// we do linkage in two separate loops because for triggers you need all items already created on host
-		foreach ($hostsLinkageInserts as $hostTplIds){
-			API::Trigger()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
-
-			API::TriggerPrototype()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
-
-			API::GraphPrototype()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
-
-			API::Graph()->syncTemplates([
-				'hostids' => $hostTplIds['hostid'],
-				'templateids' => $hostTplIds['templateid']
-			]);
+		foreach ($link_requests as $link_request){
+			API::Trigger()->syncTemplates($link_request);
+			API::TriggerPrototype()->syncTemplates($link_request);
+			API::GraphPrototype()->syncTemplates($link_request);
+			API::Graph()->syncTemplates($link_request);
 		}
 
-		foreach ($hostsLinkageInserts as $hostTplIds){
-			API::Trigger()->syncTemplateDependencies([
-				'templateids' => $hostTplIds['templateid'],
-				'hostids' => $hostTplIds['hostid']
-			]);
-
-			API::TriggerPrototype()->syncTemplateDependencies([
-				'templateids' => $hostTplIds['templateid'],
-				'hostids' => $hostTplIds['hostid']
-			]);
+		foreach ($link_requests as $link_request){
+			API::Trigger()->syncTemplateDependencies($link_request);
+			API::TriggerPrototype()->syncTemplateDependencies($link_request);
 		}
 
-		return $hostsLinkageInserts;
+		return $hosts_linkage_inserts;
 	}
 
 	/**
@@ -681,15 +676,22 @@ abstract class CHostGeneral extends CHostBase {
 		// adding templates
 		if ($options['selectParentTemplates'] !== null) {
 			if ($options['selectParentTemplates'] != API_OUTPUT_COUNT) {
+				$templates = [];
 				$relationMap = $this->createRelationMap($result, 'hostid', 'templateid', 'hosts_templates');
-				$templates = API::Template()->get([
-					'output' => $options['selectParentTemplates'],
-					'templateids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($templates, 'host');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$templates = API::Template()->get([
+						'output' => $options['selectParentTemplates'],
+						'templateids' => $related_ids,
+						'nopermissions' => $options['nopermissions'],
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($templates, 'host');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $templates, 'parentTemplates', $options['limitSelects']);
 			}
 			else {
@@ -778,6 +780,8 @@ abstract class CHostGeneral extends CHostBase {
 		// adding triggers
 		if ($options['selectTriggers'] !== null) {
 			if ($options['selectTriggers'] != API_OUTPUT_COUNT) {
+				$triggers = [];
+				$relationMap = new CRelationMap();
 				// discovered items
 				$res = DBselect(
 					'SELECT i.hostid,f.triggerid'.
@@ -785,19 +789,23 @@ abstract class CHostGeneral extends CHostBase {
 						' WHERE '.dbConditionInt('i.hostid', $hostids).
 						' AND i.itemid=f.itemid'
 				);
-				$relationMap = new CRelationMap();
 				while ($relation = DBfetch($res)) {
 					$relationMap->addRelation($relation['hostid'], $relation['triggerid']);
 				}
 
-				$triggers = API::Trigger()->get([
-					'output' => $options['selectTriggers'],
-					'triggerids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($triggers, 'description');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$triggers = API::Trigger()->get([
+						'output' => $options['selectTriggers'],
+						'triggerids' => $related_ids,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($triggers, 'description');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $triggers, 'triggers', $options['limitSelects']);
 			}
 			else {
@@ -819,6 +827,8 @@ abstract class CHostGeneral extends CHostBase {
 		// adding graphs
 		if ($options['selectGraphs'] !== null) {
 			if ($options['selectGraphs'] != API_OUTPUT_COUNT) {
+				$graphs = [];
+				$relationMap = new CRelationMap();
 				// discovered items
 				$res = DBselect(
 					'SELECT i.hostid,gi.graphid'.
@@ -826,19 +836,23 @@ abstract class CHostGeneral extends CHostBase {
 						' WHERE '.dbConditionInt('i.hostid', $hostids).
 						' AND i.itemid=gi.itemid'
 				);
-				$relationMap = new CRelationMap();
 				while ($relation = DBfetch($res)) {
 					$relationMap->addRelation($relation['hostid'], $relation['graphid']);
 				}
 
-				$graphs = API::Graph()->get([
-					'output' => $options['selectGraphs'],
-					'graphids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($graphs, 'name');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$graphs = API::Graph()->get([
+						'output' => $options['selectGraphs'],
+						'graphids' => $related_ids,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($graphs, 'name');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $graphs, 'graphs', $options['limitSelects']);
 			}
 			else {
@@ -954,18 +968,18 @@ abstract class CHostGeneral extends CHostBase {
 				'output' => $this->outputExtend($options['selectTags'], ['hostid']),
 				'filter' => ['hostid' => $hostids]
 			];
-			$tags = DBselect(DB::makeSql('host_tag', $tags_options));
 
 			foreach ($result as &$host) {
 				$host['tags'] = [];
 			}
 			unset($host);
 
+			$tags = DBselect(DB::makeSql('host_tag', $tags_options));
+
 			while ($tag = DBfetch($tags)) {
-				$result[$tag['hostid']]['tags'][] = [
-					'tag' => $tag['tag'],
-					'value' => $tag['value']
-				];
+				$hostid = $tag['hostid'];
+				unset($tag['hosttagid'], $tag['hostid']);
+				$result[$hostid]['tags'][] = $tag;
 			}
 		}
 
@@ -985,10 +999,12 @@ abstract class CHostGeneral extends CHostBase {
 	 */
 	protected function updateTags(array $hosts, $id_field) {
 		$hostids = [];
-		foreach ($hosts as $host) {
-			if (array_key_exists('tags', $host)) {
-				$hostids[] = $host[$id_field];
+		foreach ($hosts as $index => $host) {
+			if (!array_key_exists('tags', $host)) {
+				unset($host[$index]);
+				continue;
 			}
+			$hostids[] = $host[$id_field];
 		}
 
 		if (!$hostids) {
@@ -1053,7 +1069,7 @@ abstract class CHostGeneral extends CHostBase {
 	protected function validateTags(array $host) {
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'evaltype'	=> ['type' => API_INT32, 'in' => implode(',', [TAG_EVAL_TYPE_AND_OR, TAG_EVAL_TYPE_OR])],
-			'tags'		=> ['type' => API_OBJECTS, 'uniq' => [['tag', 'value']], 'fields' => [
+			'tags'		=> ['type' => API_OBJECTS, 'flags' => API_NORMALIZE, 'uniq' => [['tag', 'value']], 'fields' => [
 				'tag'		=> ['type' => API_STRING_UTF8, 'flags' => API_REQUIRED | API_NOT_EMPTY, 'length' => DB::getFieldLength('host_tag', 'tag')],
 				'value'		=> ['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('host_tag', 'value'), 'default' => DB::getDefault('host_tag', 'value')]
 			]]
