@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -84,6 +84,7 @@ class CHostGroup extends CApiService {
 			'selectTemplates'						=> null,
 			'selectGroupDiscovery'					=> null,
 			'selectDiscoveryRule'					=> null,
+			'selectHostPrototype'					=> null,
 			'countOutput'							=> false,
 			'groupCount'							=> false,
 			'preservekeys'							=> false,
@@ -397,23 +398,40 @@ class CHostGroup extends CApiService {
 		$parent_names = [];
 
 		foreach ($groups as $group) {
-			if (($pos = strrpos($group['name'], '/')) === false) {
-				continue;
-			}
+			$name = $group['name'];
 
-			$parent_names[substr($group['name'], 0, $pos)][] = $group['groupid'];
+			while (($pos = strrpos($name, '/')) !== false) {
+				$name = substr($name, 0, $pos);
+				$parent_names[$name][] = $group['groupid'];
+			}
 		}
 
 		if ($parent_names) {
-			$db_parent_groups = DB::select('hstgrp', [
+			$options = [
 				'output' => ['groupid', 'name'],
 				'filter' => ['name' => array_keys($parent_names)]
-			]);
+			];
+			$result = DBselect(DB::makeSql('hstgrp', $options));
+
+			$db_parent_groups = [];
+
+			while ($row = DBfetch($result)) {
+				$db_parent_groups[$row['name']] = $row['groupid'];
+			}
 
 			$parent_groupids = [];
 
-			foreach ($db_parent_groups as $db_parent_group) {
-				$parent_groupids[$db_parent_group['groupid']] = $parent_names[$db_parent_group['name']];
+			foreach ($groups as $group) {
+				$name = $group['name'];
+
+				while (($pos = strrpos($name, '/')) !== false) {
+					$name = substr($name, 0, $pos);
+
+					if (array_key_exists($name, $db_parent_groups)) {
+						$parent_groupids[$db_parent_groups[$name]][] = $group['groupid'];
+						break;
+					}
+				}
 			}
 
 			if ($parent_groupids) {
@@ -450,23 +468,40 @@ class CHostGroup extends CApiService {
 		$parent_names = [];
 
 		foreach ($groups as $group) {
-			if (($pos = strrpos($group['name'], '/')) === false) {
-				continue;
-			}
+			$name = $group['name'];
 
-			$parent_names[substr($group['name'], 0, $pos)][] = $group['groupid'];
+			while (($pos = strrpos($name, '/')) !== false) {
+				$name = substr($name, 0, $pos);
+				$parent_names[$name][] = $group['groupid'];
+			}
 		}
 
 		if ($parent_names) {
-			$db_parent_groups = DB::select('hstgrp', [
+			$options = [
 				'output' => ['groupid', 'name'],
 				'filter' => ['name' => array_keys($parent_names)]
-			]);
+			];
+			$result = DBselect(DB::makeSql('hstgrp', $options));
+
+			$db_parent_groups = [];
+
+			while ($row = DBfetch($result)) {
+				$db_parent_groups[$row['name']] = $row['groupid'];
+			}
 
 			$parent_groupids = [];
 
-			foreach ($db_parent_groups as $db_parent_group) {
-				$parent_groupids[$db_parent_group['groupid']] = $parent_names[$db_parent_group['name']];
+			foreach ($groups as $group) {
+				$name = $group['name'];
+
+				while (($pos = strrpos($name, '/')) !== false) {
+					$name = substr($name, 0, $pos);
+
+					if (array_key_exists($name, $db_parent_groups)) {
+						$parent_groupids[$db_parent_groups[$name]][] = $group['groupid'];
+						break;
+					}
+				}
 			}
 
 			if ($parent_groupids) {
@@ -1359,26 +1394,32 @@ class CHostGroup extends CApiService {
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
-		$groupIds = array_keys($result);
-		sort($groupIds);
+		$groupids = array_keys($result);
+		sort($groupids);
 
 		// adding hosts
 		if ($options['selectHosts'] !== null) {
 			if ($options['selectHosts'] !== API_OUTPUT_COUNT) {
+				$hosts = [];
 				$relationMap = $this->createRelationMap($result, 'groupid', 'hostid', 'hosts_groups');
-				$hosts = API::Host()->get([
-					'output' => $options['selectHosts'],
-					'hostids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($hosts, 'host');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$hosts = API::Host()->get([
+						'output' => $options['selectHosts'],
+						'hostids' => $related_ids,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($hosts, 'host');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $hosts, 'hosts', $options['limitSelects']);
 			}
 			else {
 				$hosts = API::Host()->get([
-					'groupids' => $groupIds,
+					'groupids' => $groupids,
 					'countOutput' => true,
 					'groupCount' => true
 				]);
@@ -1394,20 +1435,26 @@ class CHostGroup extends CApiService {
 		// adding templates
 		if ($options['selectTemplates'] !== null) {
 			if ($options['selectTemplates'] !== API_OUTPUT_COUNT) {
+				$hosts = [];
 				$relationMap = $this->createRelationMap($result, 'groupid', 'hostid', 'hosts_groups');
-				$hosts = API::Template()->get([
-					'output' => $options['selectTemplates'],
-					'templateids' => $relationMap->getRelatedIds(),
-					'preservekeys' => true
-				]);
-				if (!is_null($options['limitSelects'])) {
-					order_result($hosts, 'host');
+				$related_ids = $relationMap->getRelatedIds();
+
+				if ($related_ids) {
+					$hosts = API::Template()->get([
+						'output' => $options['selectTemplates'],
+						'templateids' => $related_ids,
+						'preservekeys' => true
+					]);
+					if (!is_null($options['limitSelects'])) {
+						order_result($hosts, 'host');
+					}
 				}
+
 				$result = $relationMap->mapMany($result, $hosts, 'templates', $options['limitSelects']);
 			}
 			else {
 				$hosts = API::Template()->get([
-					'groupids' => $groupIds,
+					'groupids' => $groupids,
 					'countOutput' => true,
 					'groupCount' => true
 				]);
@@ -1426,7 +1473,7 @@ class CHostGroup extends CApiService {
 			$discoveryRules = DBFetchArray(DBselect(
 				'SELECT gd.groupid,hd.parent_itemid'.
 					' FROM group_discovery gd,group_prototype gp,host_discovery hd'.
-					' WHERE '.dbConditionInt('gd.groupid', $groupIds).
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
 					' AND gd.parent_group_prototypeid=gp.group_prototypeid'.
 					' AND gp.hostid=hd.hostid'
 			));
@@ -1440,11 +1487,38 @@ class CHostGroup extends CApiService {
 			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
 		}
 
+		// adding host prototype
+		if ($options['selectHostPrototype'] !== null) {
+			$db_links = DBFetchArray(DBselect(
+				'SELECT gd.groupid,gp.hostid'.
+					' FROM group_discovery gd,group_prototype gp'.
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
+					' AND gd.parent_group_prototypeid=gp.group_prototypeid'
+			));
+
+			$host_prototypes = API::HostPrototype()->get([
+				'output' => $options['selectHostPrototype'],
+				'hostids' => array_column($db_links, 'hostid'),
+				'preservekeys' => true
+			]);
+
+			foreach ($result as &$row) {
+				$row['hostPrototype'] = [];
+			}
+			unset($row);
+
+			foreach ($db_links as $db_link) {
+				if (array_key_exists($db_link['hostid'], $host_prototypes)) {
+					$result[$db_link['groupid']]['hostPrototype'] = $host_prototypes[$db_link['hostid']];
+				}
+			}
+		}
+
 		// adding group discovery
 		if ($options['selectGroupDiscovery'] !== null) {
 			$groupDiscoveries = API::getApiService()->select('group_discovery', [
 				'output' => $this->outputExtend($options['selectGroupDiscovery'], ['groupid']),
-				'filter' => ['groupid' => $groupIds],
+				'filter' => ['groupid' => $groupids],
 				'preservekeys' => true
 			]);
 			$relationMap = $this->createRelationMap($groupDiscoveries, 'groupid', 'groupid');
