@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -154,7 +154,7 @@ class CHostInterface extends CApiService {
 			$sqlParts['limit'] = $options['limit'];
 		}
 
-		if ($this->outputIsRequested('details', $options['output'])) {
+		if (!$options['countOutput'] && $this->outputIsRequested('details', $options['output'])) {
 			$sqlParts['left_join'][] = ['alias' => 'his', 'table' => 'interface_snmp', 'using' => 'interfaceid'];
 			$sqlParts['left_table'] = ['alias' => $this->tableAlias, 'table' => $this->tableName];
 		}
@@ -614,6 +614,10 @@ class CHostInterface extends CApiService {
 	}
 
 	protected function validateMassRemove(array $data) {
+		if (!$data['hostids'] || !$data['interfaces']) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		}
+
 		// Check permissions.
 		$this->checkHostPermissions($data['hostids']);
 
@@ -634,12 +638,8 @@ class CHostInterface extends CApiService {
 				'port' => $interface['port']
 			];
 
-			if (array_key_exists('bulk', $interface)) {
-				$filter['bulk'] = $interface['bulk'];
-			}
-
 			// check main interfaces
-			$interfacesToRemove = API::getApiService()->select($this->tableName(), [
+			$interfacesToRemove = DB::select($this->tableName(), [
 				'output' => ['interfaceid'],
 				'filter' => $filter
 			]);
@@ -660,6 +660,10 @@ class CHostInterface extends CApiService {
 	 * @return array
 	 */
 	public function massRemove(array $data) {
+		if (!array_key_exists('hostids', $data) || !array_key_exists('interfaces', $data)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
+		}
+
 		$data['interfaces'] = zbx_toArray($data['interfaces']);
 		$data['hostids'] = zbx_toArray($data['hostids']);
 
@@ -987,16 +991,19 @@ class CHostInterface extends CApiService {
 			]);
 			$host = reset($host);
 
-			foreach ($db_interfaces as $db_interface) {
-				if (bccomp($db_interface['hostid'], $host['hostid']) == 0) {
-					$type = $db_interface['type'];
-					break;
+			if ($host) {
+				foreach ($db_interfaces as $db_interface) {
+					if (bccomp($db_interface['hostid'], $host['hostid']) == 0) {
+						$type = $db_interface['type'];
+						break;
+					}
 				}
-			}
 
-			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('No default interface for "%1$s" type on "%2$s".', hostInterfaceTypeNumToName($type), $host['name'])
-			);
+				self::exception(ZBX_API_ERROR_PARAMETERS, _s(
+					'No default interface for "%1$s" type on "%2$s".', hostInterfaceTypeNumToName($type), $host['name']
+				));
+			}
+			// Otherwise it's not a host. Could be a Proxy.
 		}
 
 		$interface_count = [];
@@ -1067,9 +1074,12 @@ class CHostInterface extends CApiService {
 					]);
 					$host = reset($host);
 
-					self::exception(ZBX_API_ERROR_PARAMETERS,_s('No default interface for "%1$s" type on "%2$s".',
-						hostInterfaceTypeNumToName($type), $host['name']
-					));
+					if ($host) {
+						self::exception(ZBX_API_ERROR_PARAMETERS,_s('No default interface for "%1$s" type on "%2$s".',
+							hostInterfaceTypeNumToName($type), $host['name']
+						));
+					}
+					// Otherwise it's not a host. Could be a Proxy.
 				}
 
 				if ($counters['main'] > 1) {
@@ -1202,7 +1212,7 @@ class CHostInterface extends CApiService {
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
 		$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 
-		if ($this->outputIsRequested('details', $options['output'])) {
+		if (!$options['countOutput'] && $this->outputIsRequested('details', $options['output'])) {
 			// Select interface type to check show details array or not.
 			$sqlParts = $this->addQuerySelect('hi.type', $sqlParts);
 
