@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -58,6 +58,7 @@ abstract class CItemGeneral extends CApiService {
 			'history'				=> [],
 			'trends'				=> [],
 			'status'				=> [],
+			'discover'				=> [],
 			'value_type'			=> ['template' => 1],
 			'trapper_hosts'			=> [],
 			'units'					=> ['template' => 1],
@@ -81,6 +82,7 @@ abstract class CItemGeneral extends CApiService {
 			'inventory_link'		=> [],
 			'lifetime'				=> [],
 			'preprocessing'			=> ['template' => 1],
+			'overrides'				=> ['template' => 1],
 			'jmx_endpoint'			=> [],
 			'url'					=> ['template' => 1],
 			'timeout'				=> ['template' => 1],
@@ -118,6 +120,20 @@ abstract class CItemGeneral extends CApiService {
 	 * @param bool  $update
 	 */
 	protected function checkInput(array &$items, $update = false) {
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+			'type' => ['type' => API_INT32, 'flags' => API_REQUIRED, 'in' => implode(',', static::SUPPORTED_ITEM_TYPES)]
+		]];
+		if ($update) {
+			unset($api_input_rules['fields']['type']['flags']);
+		}
+
+		foreach ($items as $num => $item) {
+			$data = array_intersect_key($item, $api_input_rules['fields']);
+			if (!CApiInputValidator::validate($api_input_rules, $data, '/'.($num + 1), $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+			}
+		}
+
 		if ($update) {
 			$itemDbFields = ['itemid' => null];
 
@@ -318,11 +334,24 @@ abstract class CItemGeneral extends CApiService {
 				}
 			}
 
+			if ($fullItem['type'] == ITEM_TYPE_CALCULATED) {
+				$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+					'params' => ['type' => API_CALC_FORMULA, 'flags' => $this instanceof CItemPrototype ? API_ALLOW_LLD_MACRO : 0]
+				]];
+
+				$data = array_intersect_key($item, $api_input_rules['fields']);
+
+				if (!CApiInputValidator::validate($api_input_rules, $data, '/'.($inum + 1), $error)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+				}
+			}
+
 			$host = $dbHosts[$fullItem['hostid']];
 
 			// Validate update interval.
-			if (!in_array($fullItem['type'], [ITEM_TYPE_TRAPPER, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT])) {
-				$this->validateDelay($update_interval_parser, $fullItem['delay']);
+			if (!in_array($fullItem['type'], [ITEM_TYPE_TRAPPER, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT])
+					&& !validateDelay($update_interval_parser, 'delay', $fullItem['delay'], $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 			}
 
 			// For non-numeric types, whichever value was entered in trends field, is overwritten to zero.
@@ -732,6 +761,63 @@ abstract class CItemGeneral extends CApiService {
 		$this->inherit($new_items);
 	}
 
+	/**
+	 * Check that no items with repeating keys would be inherited to a single host or template.
+	 *
+	 * @param array $tpl_items
+	 * @param array $chd_hosts
+	 *
+	 * @throws APIException
+	 */
+	private function checkDoubleInheritedNames(array $tpl_items, array $chd_hosts): void {
+		$templateids = array_unique(array_column($tpl_items, 'hostid'));
+
+		$tpl_links = [];
+
+		foreach ($chd_hosts as $chd_host) {
+			foreach ($chd_host['parentTemplates'] as $template) {
+				if (!in_array($template['templateid'], $templateids)) {
+					continue;
+				}
+
+				$tpl_links[$template['templateid']][] = $chd_host['hostid'];
+			}
+		}
+
+		$item_indexes = [];
+
+		foreach ($tpl_items as $i => $tpl_item) {
+			if (!array_key_exists($tpl_item['hostid'], $tpl_links)) {
+				continue;
+			}
+
+			$item_indexes[$tpl_item['key_']][] = $i;
+		}
+
+		foreach ($item_indexes as $key => $indexes) {
+			if (count($indexes) == 1) {
+				continue;
+			}
+
+			$hostids = [];
+
+			foreach ($indexes as $i) {
+				$templateid = $tpl_items[$i]['hostid'];
+				$same_hosts = array_intersect($tpl_links[$templateid], $hostids);
+
+				if ($same_hosts) {
+					$hostid = reset($same_hosts);
+
+					self::exception(ZBX_API_ERROR_PARAMETERS,
+						sprintf($this->getErrorMsg(self::ERROR_EXISTS_TEMPLATE), $key, $chd_hosts[$hostid]['host'])
+					);
+				}
+
+				$hostids = array_merge($hostids, $tpl_links[$templateid]);
+			}
+		}
+	}
+
 	/**
 	 * Prepares and returns an array of child items, inherited from items $tpl_items on the given hosts.
 	 *
@@ -775,6 +861,8 @@ abstract class CItemGeneral extends CApiService {
 			return [];
 		}
 
+		$this->checkDoubleInheritedNames($tpl_items, $chd_hosts);
+
 		$chd_items_tpl = [];
 		$chd_items_key = [];
 
@@ -1242,11 +1330,17 @@ abstract class CItemGeneral extends CApiService {
 							);
 						}
 
-						if (!is_numeric($params)
-								&& (new CUserMacroParser())->parse($params) != CParser::PARSE_SUCCESS
-								&& (!($this instanceof CItemPrototype)
-									|| ((new CLLDMacroFunctionParser())->parse($params) != CParser::PARSE_SUCCESS
-										&& (new CLLDMacroParser())->parse($params) != CParser::PARSE_SUCCESS))) {
+						if (is_numeric($params)) {
+							break;
+						}
+
+						$types = ['usermacros' => true];
+
+						if ($this instanceof CItemPrototype) {
+							$types['lldmacros'] = true;
+						}
+
+						if (!(new CMacrosResolverGeneral)->getMacroPositions($params, $types)) {
 							self::exception(ZBX_API_ERROR_PARAMETERS, _s('Incorrect value for field "%1$s": %2$s.',
 								'params', _('a numeric value is expected')
 							));
@@ -1654,37 +1748,97 @@ abstract class CItemGeneral extends CApiService {
 	/**
 	 * Update item pre-processing data in DB. Delete old records and create new ones.
 	 *
-	 * @param array $items                     An array of items.
-	 * @param array $items[]['preprocessing']  An array of item pre-processing data.
+	 * @param array  $items
+	 * @param string $items[]['itemid']
+	 * @param array  $items[]['preprocessing']
+	 * @param int    $items[]['preprocessing'][]['type']
+	 * @param string $items[]['preprocessing'][]['params']
+	 * @param int    $items[]['preprocessing'][]['error_handler']
+	 * @param string $items[]['preprocessing'][]['error_handler_params']
 	 */
 	protected function updateItemPreprocessing(array $items) {
-		$item_preproc = [];
-		$item_preprocids = [];
+		$item_preprocs = [];
 
 		foreach ($items as $item) {
 			if (array_key_exists('preprocessing', $item)) {
-				$item_preprocids[] = $item['itemid'];
+				$item_preprocs[$item['itemid']] = [];
 				$step = 1;
 
-				foreach ($item['preprocessing'] as $preprocessing) {
-					$item_preproc[] = [
-						'itemid' => $item['itemid'],
-						'step' => $step++,
-						'type' => $preprocessing['type'],
-						'params' => $preprocessing['params'],
-						'error_handler' => $preprocessing['error_handler'],
-						'error_handler_params' => $preprocessing['error_handler_params']
+				foreach ($item['preprocessing'] as $item_preproc) {
+					$item_preprocs[$item['itemid']][$step++] = [
+						'type' => $item_preproc['type'],
+						'params' => $item_preproc['params'],
+						'error_handler' => $item_preproc['error_handler'],
+						'error_handler_params' => $item_preproc['error_handler_params']
 					];
 				}
 			}
 		}
 
-		if ($item_preprocids) {
-			DB::delete('item_preproc', ['itemid' => $item_preprocids]);
+		if (!$item_preprocs) {
+			return;
 		}
 
-		if ($item_preproc) {
-			DB::insertBatch('item_preproc', $item_preproc);
+		$ins_item_preprocs = [];
+		$upd_item_preprocs = [];
+		$del_item_preprocids = [];
+
+		$options = [
+			'output' => ['item_preprocid', 'itemid', 'step', 'type', 'params', 'error_handler', 'error_handler_params'],
+			'filter' => ['itemid' => array_keys($item_preprocs)]
+		];
+		$db_item_preprocs = DBselect(DB::makeSql('item_preproc', $options));
+
+		while ($db_item_preproc = DBfetch($db_item_preprocs)) {
+			if (array_key_exists($db_item_preproc['step'], $item_preprocs[$db_item_preproc['itemid']])) {
+				$item_preproc = $item_preprocs[$db_item_preproc['itemid']][$db_item_preproc['step']];
+				$upd_item_preproc = [];
+
+				if ($item_preproc['type'] != $db_item_preproc['type']) {
+					$upd_item_preproc['type'] = $item_preproc['type'];
+				}
+				if ($item_preproc['params'] !== $db_item_preproc['params']) {
+					$upd_item_preproc['params'] = $item_preproc['params'];
+				}
+				if ($item_preproc['error_handler'] != $db_item_preproc['error_handler']) {
+					$upd_item_preproc['error_handler'] = $item_preproc['error_handler'];
+				}
+				if ($item_preproc['error_handler_params'] !== $db_item_preproc['error_handler_params']) {
+					$upd_item_preproc['error_handler_params'] = $item_preproc['error_handler_params'];
+				}
+
+				if ($upd_item_preproc) {
+					$upd_item_preprocs[] = [
+						'values' => $upd_item_preproc,
+						'where' => ['item_preprocid' => $db_item_preproc['item_preprocid']]
+					];
+				}
+				unset($item_preprocs[$db_item_preproc['itemid']][$db_item_preproc['step']]);
+			}
+			else {
+				$del_item_preprocids[] = $db_item_preproc['item_preprocid'];
+			}
+		}
+
+		foreach ($item_preprocs as $itemid => $preprocs) {
+			foreach ($preprocs as $step => $preproc) {
+				$ins_item_preprocs[] = [
+					'itemid' => $itemid,
+					'step' => $step
+				] + $preproc;
+			}
+		}
+
+		if ($del_item_preprocids) {
+			DB::delete('item_preproc', ['item_preprocid' => $del_item_preprocids]);
+		}
+
+		if ($upd_item_preprocs) {
+			DB::update('item_preproc', $upd_item_preprocs);
+		}
+
+		if ($ins_item_preprocs) {
+			DB::insertBatch('item_preproc', $ins_item_preprocs);
 		}
 	}
 
@@ -1752,7 +1906,7 @@ abstract class CItemGeneral extends CApiService {
 		if ($options['selectPreprocessing'] !== null && $options['selectPreprocessing'] != API_OUTPUT_COUNT) {
 			$db_item_preproc = API::getApiService()->select('item_preproc', [
 				'output' => $this->outputExtend($options['selectPreprocessing'], ['itemid', 'step']),
-				'filter' => ['itemid' => array_keys($result)],
+				'filter' => ['itemid' => array_keys($result)]
 			]);
 
 			CArrayHelper::sort($db_item_preproc, ['step']);
@@ -2065,14 +2219,14 @@ abstract class CItemGeneral extends CApiService {
 			],
 			'url' => [
 				'type' => API_STRING_UTF8, 'flags' => API_REQUIRED | API_NOT_EMPTY,
-				'length' => DB::getFieldLength('items', 'url'),
+				'length' => DB::getFieldLength('items', 'url')
 			],
 			'status_codes' => [
 				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'status_codes')
 			],
 			'follow_redirects' => [
 				'type' => API_INT32,
-				'in' => implode(',', [HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF, HTTPTEST_STEP_FOLLOW_REDIRECTS_ON]),
+				'in' => implode(',', [HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF, HTTPTEST_STEP_FOLLOW_REDIRECTS_ON])
 			],
 			'post_type' => [
 				'type' => API_INT32,
@@ -2106,13 +2260,13 @@ abstract class CItemGeneral extends CApiService {
 				'in' => implode(',', [HTTPCHECK_ALLOW_TRAPS_OFF, HTTPCHECK_ALLOW_TRAPS_ON])
 			],
 			'ssl_cert_file' => [
-				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_cert_file'),
+				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_cert_file')
 			],
 			'ssl_key_file' => [
-				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_key_file'),
+				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_key_file')
 			],
 			'ssl_key_password' => [
-				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_key_password'),
+				'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('items', 'ssl_key_password')
 			],
 			'verify_peer' => [
 				'type' => API_INT32,
@@ -2157,7 +2311,7 @@ abstract class CItemGeneral extends CApiService {
 
 		if (array_key_exists('templateid', $data) && $data['templateid']) {
 			$rules['interfaceid'] = [
-				'type' => API_ID, 'flags' => API_REQUIRED | API_NOT_EMPTY
+				'type' => API_ID, 'flags' => API_REQUIRED
 			];
 		}
 
@@ -2288,57 +2442,4 @@ abstract class CItemGeneral extends CApiService {
 			}
 		}
 	}
-
-	/**
-	 * Validates update interval.
-	 *
-	 * @param CUpdateIntervalParser $parser  Parser used for delay validation.
-	 * @param string                $value   Update interval to parse and validate.
-	 *
-	 * @throws APIException if update interval is incorrect.
-	 */
-	protected function validateDelay(CUpdateIntervalParser $parser, $value) {
-		if ($parser->parse($value) != CParser::PARSE_SUCCESS) {
-			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Incorrect value for field "%1$s": %2$s.', 'delay', _('invalid delay'))
-			);
-		}
-
-		$delay = $parser->getDelay();
-
-		if ($delay[0] !== '{') {
-			$delay_sec = timeUnitToSeconds($delay);
-			$intervals = $parser->getIntervals();
-			$flexible_intervals = $parser->getIntervals(ITEM_DELAY_FLEXIBLE);
-			$has_scheduling_intervals = (bool) $parser->getIntervals(ITEM_DELAY_SCHEDULING);
-			$has_macros = false;
-
-			foreach ($intervals as $interval) {
-				if (strpos($interval['interval'], '{') !== false) {
-					$has_macros = true;
-					break;
-				}
-			}
-
-			// If delay is 0, there must be at least one either flexible or scheduling interval.
-			if ($delay_sec == 0 && !$intervals) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_('Item will not be refreshed. Specified update interval requires having at least one either flexible or scheduling interval.')
-				);
-			}
-			elseif ($delay_sec < 0 || $delay_sec > SEC_PER_DAY) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_('Item will not be refreshed. Update interval should be between 1s and 1d. Also Scheduled/Flexible intervals can be used.')
-				);
-			}
-
-			// If there are scheduling intervals or intervals with macros, skip the next check calculation.
-			if (!$has_macros && !$has_scheduling_intervals && $flexible_intervals
-					&& calculateItemNextCheck(0, $delay_sec, $flexible_intervals, time()) == ZBX_JAN_2038) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_('Item will not be refreshed. Please enter a correct update interval.')
-				);
-			}
-		}
-	}
 }
