@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1939,6 +1939,11 @@ class CMap extends CMapElement {
 
 			// Urls.
 			if (array_key_exists('urls', $map)) {
+				foreach ($map['urls'] as &$url) {
+					unset($url['sysmapurlid'], $url['sysmapid']);
+				}
+				unset($url);
+
 				$url_diff = zbx_array_diff($map['urls'], $db_map['urls'], 'name');
 
 				foreach ($url_diff['both'] as $updateUrl) {
