@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ class CMediatype extends CApiService {
 	protected $tableAlias = 'mt';
 	protected $sortColumns = ['mediatypeid'];
 
+	public const LIMITED_OUTPUT_FIELDS = ['mediatypeid', 'type', 'name', 'status', 'description', 'maxattempts'];
+
 	/**
 	 * Get Media types data
 	 *
@@ -80,14 +82,20 @@ class CMediatype extends CApiService {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// permission check
-		if (self::$userData['type'] == USER_TYPE_SUPER_ADMIN) {
-		}
-		elseif (!$options['editable'] && self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN) {
-		}
-		elseif ($options['editable'] || self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+		if ((self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN && $options['editable'])
+				|| self::$userData['type'] == USER_TYPE_ZABBIX_USER) {
 			return [];
 		}
 
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+			if ($options['output'] === API_OUTPUT_EXTEND) {
+				$options['output'] = self::LIMITED_OUTPUT_FIELDS;
+			}
+			elseif (is_array($options['output'])) {
+				$options['output'] = array_intersect($options['output'], self::LIMITED_OUTPUT_FIELDS);
+			}
+		}
+
 		// mediatypeids
 		if (!is_null($options['mediatypeids'])) {
 			zbx_value2array($options['mediatypeids']);
@@ -98,6 +106,16 @@ class CMediatype extends CApiService {
 		if (!is_null($options['mediaids'])) {
 			zbx_value2array($options['mediaids']);
 
+			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+				$_options = [
+					'output' => ['mediaid'],
+					'filter' => ['userid' => self::$userData['userid']]
+				];
+				$accessible_mediaids = DBfetchColumn(DBselect(DB::makeSql('media', $_options)), 'mediaid');
+
+				$options['mediaids'] = array_intersect($options['mediaids'], $accessible_mediaids);
+			}
+
 			$sqlParts['from']['media'] = 'media m';
 			$sqlParts['where'][] = dbConditionInt('m.mediaid', $options['mediaids']);
 			$sqlParts['where']['mmt'] = 'm.mediatypeid=mt.mediatypeid';
@@ -107,6 +125,10 @@ class CMediatype extends CApiService {
 		if (!is_null($options['userids'])) {
 			zbx_value2array($options['userids']);
 
+			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+				$options['userids'] = array_intersect($options['userids'], [self::$userData['userid']]);
+			}
+
 			$sqlParts['from']['media'] = 'media m';
 			$sqlParts['where'][] = dbConditionInt('m.userid', $options['userids']);
 			$sqlParts['where']['mmt'] = 'm.mediatypeid=mt.mediatypeid';
@@ -114,11 +136,31 @@ class CMediatype extends CApiService {
 
 		// filter
 		if (is_array($options['filter'])) {
+			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+				if ($options['searchByAny'] !== null && $options['searchByAny'] !== false) {
+					$options['filter'] =
+						array_intersect_key($options['filter'], array_flip(self::LIMITED_OUTPUT_FIELDS));
+				}
+				elseif (array_diff_key($options['filter'], array_flip(self::LIMITED_OUTPUT_FIELDS))) {
+					return [];
+				}
+			}
+
 			$this->dbFilter('media_type mt', $options, $sqlParts);
 		}
 
 		// search
 		if (is_array($options['search'])) {
+			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+				if ($options['searchByAny']) {
+					$options['search'] =
+						array_intersect_key($options['search'], array_flip(self::LIMITED_OUTPUT_FIELDS));
+				}
+				elseif (array_diff_key($options['search'], array_flip(self::LIMITED_OUTPUT_FIELDS))) {
+					return [];
+				}
+			}
+
 			zbx_db_search('media_type mt', $options, $sqlParts);
 		}
 
@@ -1203,7 +1245,8 @@ class CMediatype extends CApiService {
 		$result = parent::addRelatedObjects($options, $result);
 
 		// adding message templates
-		if ($options['selectMessageTemplates'] !== null && $options['selectMessageTemplates'] != API_OUTPUT_COUNT) {
+		if (self::$userData['type'] == USER_TYPE_SUPER_ADMIN && $options['selectMessageTemplates'] !== null
+				&& $options['selectMessageTemplates'] != API_OUTPUT_COUNT) {
 			$message_templates = [];
 			$relation_map = $this->createRelationMap($result, 'mediatypeid', 'mediatype_messageid',
 				'media_type_message'
@@ -1226,9 +1269,23 @@ class CMediatype extends CApiService {
 
 		// adding users
 		if ($options['selectUsers'] !== null && $options['selectUsers'] != API_OUTPUT_COUNT) {
+			$user_condition = self::$userData['type'] != USER_TYPE_SUPER_ADMIN
+				? ['userid' => self::$userData['userid']]
+				: [];
+			$_options = [
+				'output' => ['mediatypeid', 'userid'],
+				'filter' => ['mediatypeid' => array_keys($result)] + $user_condition
+			];
+			$medias = DBselect(DB::makeSql('media', $_options));
+
+			$relation_map = new CRelationMap();
+
+			while ($media = DBfetch($medias)) {
+				$relation_map->addRelation($media['mediatypeid'], $media['userid']);
+			}
+
 			$users = [];
-			$relationMap = $this->createRelationMap($result, 'mediatypeid', 'userid', 'media');
-			$related_ids = $relationMap->getRelatedIds();
+			$related_ids = $relation_map->getRelatedIds();
 
 			if ($related_ids) {
 				$users = API::User()->get([
@@ -1238,7 +1295,7 @@ class CMediatype extends CApiService {
 				]);
 			}
 
-			$result = $relationMap->mapMany($result, $users, 'users');
+			$result = $relation_map->mapMany($result, $users, 'users');
 		}
 
 		if ($this->outputIsRequested('parameters', $options['output'])) {
