@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -198,4 +198,15 @@ class MysqlDbBackend extends DbBackend {
 	public function init() {
 		DBexecute('SET NAMES utf8');
 	}
+
+	/**
+	 * @inheritdoc
+	 */
+	public function dbFieldExists($table_name, $field_name) {
+		return (bool) DBFetch(DBselect(
+			'SHOW COLUMNS'.
+			' FROM '.$table_name.
+			' LIKE '.zbx_dbstr($field_name)
+		));
+	}
 }
