@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -91,9 +91,9 @@ class PostgresqlDbBackend extends DbBackend {
 			' WHERE datname='.zbx_dbstr($DB['DATABASE'])
 		));
 
-		if ($row && $row['db_charset'] != ZBX_DB_DEFAULT_CHARSET) {
+		if ($row && $row['db_charset'] != ZBX_DB_POSTGRESQL_ALLOWED_CHARSET) {
 			$this->setWarning(_s('Incorrect default charset for Zabbix database: %1$s.',
-				_s('"%1$s" instead "%2$s"', $row['db_charset'], ZBX_DB_DEFAULT_CHARSET)
+				_s('"%1$s" instead "%2$s"', $row['db_charset'], ZBX_DB_POSTGRESQL_ALLOWED_CHARSET)
 			));
 			return false;
 		}
@@ -239,7 +239,7 @@ class PostgresqlDbBackend extends DbBackend {
 	 * @return bool
 	 */
 	public function init() {
-		$schema_set = DBexecute('SET search_path='.zbx_dbstr($this->schema), true);
+		$schema_set = DBexecute('SET search_path='.zbx_dbstr($this->schema));
 
 		if(!$schema_set) {
 			$this->setError(pg_last_error());
@@ -272,11 +272,48 @@ class PostgresqlDbBackend extends DbBackend {
 			return false;
 		}
 
-		$result = DBfetch(DBselect('SELECT coalesce(sum(number_compressed_chunks),0) chunks'.
-			' FROM timescaledb_information.compressed_hypertable_stats'.
-			' WHERE number_compressed_chunks != 0 AND '.dbConditionString('hypertable_name::text', $tables)
+		$timescale_v1 = DBfetch(DBselect(
+			'SELECT NULL FROM pg_catalog.pg_class c'.
+			' JOIN pg_catalog.pg_namespace n'.
+			' ON n.oid=c.relnamespace'.
+			' WHERE n.nspname='.zbx_dbstr('timescaledb_information').
+			' AND c.relname='.zbx_dbstr('compressed_hypertable_stats')
 		));
 
-		return (bool) $result['chunks'];
+		if ($timescale_v1) {
+			$result = DBfetch(DBselect('SELECT coalesce(sum(number_compressed_chunks),0) chunks'.
+				' FROM timescaledb_information.compressed_hypertable_stats'.
+				' WHERE number_compressed_chunks != 0 AND '.dbConditionString('hypertable_name::text', $tables)
+			));
+
+			return (bool) $result['chunks'];
+		}
+
+		$query = implode(' UNION ', array_map(function ($table) {
+			return 'SELECT number_compressed_chunks chunks'.
+				' FROM hypertable_compression_stats('.zbx_dbstr($table).')'.
+				' WHERE number_compressed_chunks != 0';
+		}, $tables));
+
+		$result = DBfetch(DBselect($query));
+
+		return $result ? (bool) $result['chunks'] : $result;
+	}
+
+	/**
+	 * @inheritdoc
+	 */
+	public function dbFieldExists($table_name, $field_name) {
+		global $DB;
+
+		$schema = $DB['SCHEMA'] ? $DB['SCHEMA'] : 'public';
+
+		return (bool) DBFetch(DBselect(
+			'SELECT 1'.
+			' FROM information_schema.columns'.
+			' WHERE table_name='.zbx_dbstr($table_name).
+				' AND column_name='.zbx_dbstr($field_name).
+				' AND table_schema='.zbx_dbstr($schema)
+		));
 	}
 }
