@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -451,9 +451,14 @@ class CImportDataAdapter {
 					unset($message_template);
 				}
 
-				$media_types[] = CArrayHelper::renameKeys($media_type,
-					$keys + (($media_type['type'] == MEDIA_TYPE_EXEC) ? ['parameters' => 'exec_params'] : [])
-				);
+				if ($media_type['type'] == MEDIA_TYPE_EXEC && array_key_exists('parameters', $media_type)) {
+					$media_type['exec_params'] = $media_type['parameters']
+						? implode("\n", $media_type['parameters'])."\n"
+						: '';
+					unset($media_type['parameters']);
+				}
+
+				$media_types[] = CArrayHelper::renameKeys($media_type, $keys);
 			}
 		}
 
