@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -446,14 +446,14 @@ class CMacrosResolverGeneral {
 	 *
 	 * @return array
 	 */
-	private function getItemKeyParameters($params_raw) {
+	public static function getItemKeyParameters($params_raw) {
 		$item_key_parameters = [];
 
 		foreach ($params_raw as $param_raw) {
 			switch ($param_raw['type']) {
 				case CItemKey::PARAM_ARRAY:
 					$item_key_parameters = array_merge($item_key_parameters,
-						$this->getItemKeyParameters($param_raw['parameters'])
+						self::getItemKeyParameters($param_raw['parameters'])
 					);
 					break;
 
@@ -483,7 +483,7 @@ class CMacrosResolverGeneral {
 
 		$item_key_parameters = [];
 		if ($item_key_parser->parse($key) == CParser::PARSE_SUCCESS) {
-			$item_key_parameters = $this->getItemKeyParameters($item_key_parser->getParamsRaw());
+			$item_key_parameters = self::getItemKeyParameters($item_key_parser->getParamsRaw());
 		}
 
 		return self::extractMacros($item_key_parameters, $types);
@@ -528,14 +528,14 @@ class CMacrosResolverGeneral {
 	 *
 	 * @return string
 	 */
-	private function resolveItemKeyParamsMacros($key_chain, array $params_raw, array $macros, array $types) {
+	private static function resolveItemKeyParamsMacros($key_chain, array $params_raw, array $macros, array $types) {
 		foreach (array_reverse($params_raw) as $param_raw) {
 			$param = $param_raw['raw'];
 			$forced = false;
 
 			switch ($param_raw['type']) {
 				case CItemKey::PARAM_ARRAY:
-					$param = $this->resolveItemKeyParamsMacros($param, $param_raw['parameters'], $macros, $types);
+					$param = self::resolveItemKeyParamsMacros($param, $param_raw['parameters'], $macros, $types);
 					break;
 
 				case CItemKey::PARAM_QUOTED:
@@ -544,13 +544,7 @@ class CMacrosResolverGeneral {
 					// break; is not missing here
 
 				case CItemKey::PARAM_UNQUOTED:
-					$matched_macros = $this->getMacroPositions($param, $types);
-
-					foreach (array_reverse($matched_macros, true) as $pos => $macro) {
-						$param = substr_replace($param, $macros[$macro], $pos, strlen($macro));
-					}
-
-					$param = quoteItemKeyParam($param, $forced);
+					$param = quoteItemKeyParam(strtr($param, $macros), $forced);
 					break;
 			}
 
@@ -569,11 +563,11 @@ class CMacrosResolverGeneral {
 	 *
 	 * @return string
 	 */
-	protected function resolveItemKeyMacros($key, array $macros, array $types) {
+	public static function resolveItemKeyMacros($key, array $macros, array $types) {
 		$item_key_parser = new CItemKey();
 
 		if ($item_key_parser->parse($key) == CParser::PARSE_SUCCESS) {
-			$key = $this->resolveItemKeyParamsMacros($key, $item_key_parser->getParamsRaw(), $macros, $types);
+			$key = self::resolveItemKeyParamsMacros($key, $item_key_parser->getParamsRaw(), $macros, $types);
 		}
 
 		return $key;
@@ -1137,7 +1131,7 @@ class CMacrosResolverGeneral {
 							}
 							elseif ($context !== null && count($global_macros[$macro]['regex'])) {
 								foreach ($global_macros[$macro]['regex'] as $regex => $val) {
-									if (preg_match('/'.trim($regex, '/').'/', $context) === 1) {
+									if (preg_match('/'.self::handleSlashEscaping($regex).'/', $context) === 1) {
 										$value['value'] = $val;
 										break;
 									}
@@ -1214,7 +1208,7 @@ class CMacrosResolverGeneral {
 				// Searching context coincidence, if regex array not empty.
 				elseif ($context !== null && count($host_macros[$hostid][$macro]['regex'])) {
 					foreach ($host_macros[$hostid][$macro]['regex'] as $regex => $val) {
-						if (preg_match('/'.trim($regex, '/').'/', $context) === 1) {
+						if (preg_match('/'.self::handleSlashEscaping($regex).'/', $context) === 1) {
 							return [
 								'value' => $val,
 								'value_default' => $value_default
@@ -1260,6 +1254,34 @@ class CMacrosResolverGeneral {
 		return ['value' => null, 'value_default' => $value_default];
 	}
 
+	/**
+	 * Escape slashes in the regular expression based on preceding backslashes.
+	 *
+	 * @param string $regex
+	 *
+	 * @return string
+	 */
+	private static function handleSlashEscaping(string $regex): string {
+		$formatted_regex = '';
+		$backslash_count = 0;
+
+		for ($p = 0; isset($regex[$p]); $p++) {
+			if ($regex[$p] === '\\') {
+				$backslash_count++;
+			}
+			else {
+				if ($regex[$p] === '/' && $backslash_count % 2 == 0) {
+					$formatted_regex .= '\\';
+				}
+				$backslash_count = 0;
+			}
+
+			$formatted_regex .= $regex[$p];
+		}
+
+		return $formatted_regex;
+	}
+
 	/**
 	 * Get macro value refer by type.
 	 *
