@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -707,15 +707,6 @@ function copyApplications($source_hostid, $destination_hostid) {
 	return (bool) API::Application()->create($applications_to_create);
 }
 
-function get_item_by_itemid($itemid) {
-	$db_items = DBfetch(DBselect('SELECT i.* FROM items i WHERE i.itemid='.zbx_dbstr($itemid)));
-	if ($db_items) {
-		return $db_items;
-	}
-	error(_s('No item with itemid="%1$s".', $itemid));
-	return false;
-}
-
 /**
  * Description:
  * Replace items for specified host
@@ -933,10 +924,10 @@ function makeItemTemplatePrefix($itemid, array $parent_templates, $flag) {
 				->setArgument('filter_hostids', [$template['hostid']]);
 		}
 
-		$name = (new CLink(CHtml::encode($template['name']), $url))->addClass(ZBX_STYLE_LINK_ALT);
+		$name = (new CLink($template['name'], $url))->addClass(ZBX_STYLE_LINK_ALT);
 	}
 	else {
-		$name = new CSpan(CHtml::encode($template['name']));
+		$name = new CSpan($template['name']);
 	}
 
 	return [$name->addClass(ZBX_STYLE_GREY), NAME_DELIMITER];
@@ -977,13 +968,13 @@ function makeItemTemplatesHtml($itemid, array $parent_templates, $flag) {
 					->setArgument('itemid', $parent_templates['links'][$itemid]['itemid']);
 			}
 
-			$name = new CLink(CHtml::encode($template['name']), $url);
+			$name = new CLink($template['name'], $url);
 		}
 		else {
-			$name = (new CSpan(CHtml::encode($template['name'])))->addClass(ZBX_STYLE_GREY);
+			$name = (new CSpan($template['name']))->addClass(ZBX_STYLE_GREY);
 		}
 
-		array_unshift($list, $name, '&nbsp;&rArr;&nbsp;');
+		array_unshift($list, $name, [NBSP(), RARR(), NBSP()]);
 
 		$itemid = $parent_templates['links'][$itemid]['itemid'];
 	}
@@ -1069,7 +1060,7 @@ function getDataOverviewCellData(array $db_items, array $data, int $show_suppres
  *
  * @return array
  */
-function getDataOverviewItems(?array $groupids = null, ?array $hostids = null, ?string $application = ''): array {
+function getDataOverviewItems(?array $groupids = null, ?array $hostids, ?string $application = ''): array {
 	if ($application !== '') {
 		$db_applications = API::Application()->get([
 			'output' => ['hostid'],
@@ -1087,15 +1078,21 @@ function getDataOverviewItems(?array $groupids = null, ?array $hostids = null, ?
 	}
 
 	if ($hostids === null) {
+		$config = select_config();
 		$db_hosts = API::Host()->get([
-			'output' => [],
+			'output' => ['name'],
 			'groupids' => $groupids,
 			'applicationids' => $applicationids,
 			'monitored_hosts' => true,
 			'with_monitored_items' => true,
-			'preservekeys' => true,
-			'limit' => ZBX_MAX_TABLE_COLUMNS + 1
+			'sortfield' => ['name'],
+			'limit' => $config['search_limit'],
+			'preservekeys' => true
 		]);
+
+		CArrayHelper::sort($db_hosts, ['name']);
+		$db_hosts = array_slice($db_hosts, 0, ZBX_MAX_TABLE_COLUMNS + 1, true);
+
 		$hostids = array_keys($db_hosts);
 	}
 
@@ -1128,7 +1125,7 @@ function getDataOverviewItems(?array $groupids = null, ?array $hostids = null, ?
 		['field' => 'itemid', 'order' => ZBX_SORT_UP]
 	]);
 
-	return [$db_items, $hostids];
+	return $db_items;
 }
 
 /**
@@ -1141,7 +1138,7 @@ function getDataOverviewItems(?array $groupids = null, ?array $hostids = null, ?
  * @return array
  */
 function getDataOverview(?array $groupids, ?array $hostids, array $filter): array {
-	[$db_items, $hostids] = getDataOverviewItems($groupids, $hostids, $filter['application']);
+	$db_items = getDataOverviewItems($groupids, $hostids, $filter['application']);
 
 	$data = [];
 	$item_counter = [];
@@ -1193,35 +1190,51 @@ function getDataOverview(?array $groupids, ?array $hostids, array $filter): arra
 		['field' => 'name', 'order' => ZBX_SORT_UP]
 	]);
 
-	$has_hidden_hosts = (count($db_hosts) > ZBX_MAX_TABLE_COLUMNS);
+	$has_hidden_data = count($data) > ZBX_MAX_TABLE_COLUMNS || count($db_hosts) > ZBX_MAX_TABLE_COLUMNS;
 	$db_hosts = array_slice($db_hosts, 0, ZBX_MAX_TABLE_COLUMNS, true);
+	$host_names = array_column($db_hosts, 'name', 'name');
 
-	$data = array_slice($data, 0, ZBX_MAX_TABLE_COLUMNS, true);
-	$items_left = ZBX_MAX_TABLE_COLUMNS;
 	$itemids = [];
-	array_walk($data, function (array &$item_columns) use (&$itemids, &$items_left) {
+	$items_left = ZBX_MAX_TABLE_COLUMNS;
+
+	foreach ($data as &$item_columns) {
 		if ($items_left != 0) {
 			$item_columns = array_slice($item_columns, 0, min(ZBX_MAX_TABLE_COLUMNS, $items_left));
 			$items_left -= count($item_columns);
 		}
 		else {
 			$item_columns = null;
-			return;
+			break;
 		}
 
-		array_walk($item_columns, function (array &$item_column) use (&$itemids) {
+		foreach ($item_columns as &$item_column) {
+			CArrayHelper::ksort($item_column);
 			$item_column = array_slice($item_column, 0, ZBX_MAX_TABLE_COLUMNS, true);
-			$itemids += array_column($item_column, 'itemid', 'itemid');
-		});
-	});
-	$data = array_filter($data);
 
-	$has_hidden_items = (count($db_items) != count($itemids));
+			foreach ($item_column as $host_name => $item) {
+				if (array_key_exists($host_name, $host_names)) {
+					$itemids[$item['itemid']] = true;
+				}
+				else {
+					unset($item_column[$host_name]);
+				}
+			}
+		}
+		unset($item_column);
+
+		$item_columns = array_filter($item_columns);
+	}
+	unset($item_columns);
+
+	$data = array_filter($data);
+	$data = array_slice($data, 0, ZBX_MAX_TABLE_COLUMNS, true);
+
+	$has_hidden_data = $has_hidden_data || count($db_items) != count($itemids);
 
 	$db_items = array_intersect_key($db_items, $itemids);
 	$data = getDataOverviewCellData($db_items, $data, $filter['show_suppressed']);
 
-	return [$data, $db_hosts, ($has_hidden_items || $has_hidden_hosts)];
+	return [$data, $db_hosts, $has_hidden_data];
 }
 
 /**
