@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -125,7 +125,7 @@ if ($page['type'] == PAGE_TYPE_HTML) {
 		$pageTitle .= ' ['._s('refreshed every %1$s sec.', CWebUser::getRefresh()).']';
 	}
 
-	$pageHeader = new CPageHeader($pageTitle);
+	$pageHeader = new CPageHeader($pageTitle, CWebUser::getLang());
 	$is_standard_page = (!defined('ZBX_PAGE_NO_MENU') || $page['web_layout_mode'] == ZBX_LAYOUT_KIOSKMODE);
 
 	$theme = ZBX_DEFAULT_THEME;
@@ -145,18 +145,20 @@ if ($page['type'] == PAGE_TYPE_HTML) {
 			}
 		}
 	}
-	$pageHeader->addCssFile('assets/styles/'.CHtml::encode($theme).'.css');
+	$pageHeader->addCssFile('assets/styles/'.$theme.'.css');
 
 	if ($page['file'] == 'sysmap.php') {
 		$pageHeader->addCssFile('imgstore.php?css=1&output=css');
 	}
 
+	$tz_offsets = array_column((new DateTime())->getTimezone()->getTransitions(0, ZBX_MAX_DATE), 'offset', 'ts');
+
 	$pageHeader
 		->addJsFile((new CUrl('js/browsers.js'))->getUrl())
-		->addJsBeforeScripts(
-			'var PHP_TZ_OFFSET = '.date('Z').','.
-				'PHP_ZBX_FULL_DATE_TIME = "'.ZBX_FULL_DATE_TIME.'";'
-		);
+		->addJsBeforeScripts('
+			const PHP_ZBX_FULL_DATE_TIME = "'.ZBX_FULL_DATE_TIME.'";
+			const PHP_TZ_OFFSETS = '.json_encode($tz_offsets).';
+		');
 
 	// Show GUI messages in pages with menus and in fullscreen mode.
 	if (!defined('ZBX_PAGE_NO_JSLOADER')) {
@@ -179,7 +181,7 @@ if ($page['type'] == PAGE_TYPE_HTML) {
 
 	$pageHeader->display();
 
-	echo '<body lang="'.CWebUser::getLang().'">';
+	echo '<body>';
 }
 
 define('PAGE_HEADER_LOADED', 1);
