@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ foreach ($data['applications'] as $application) {
 		$name[] = $application['name'];
 	}
 	elseif ($application['flags'] == ZBX_FLAG_DISCOVERY_CREATED && $application['discoveryRule']) {
-		$name = [(new CLink(CHtml::encode($application['discoveryRule']['name']),
+		$name = [(new CLink($application['discoveryRule']['name'],
 						'disc_prototypes.php?parent_discoveryid='.$application['discoveryRule']['itemid']))
 					->addClass(ZBX_STYLE_LINK_ALT)
 					->addClass(ZBX_STYLE_ORANGE)
