@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,12 +38,11 @@ else {
 
 // Create form.
 $graphForm = (new CForm())
+	->addVar('form_refresh', $data['form_refresh'] + 1)
 	->setName('graphForm')
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
-	->addVar('form', $this->data['form'])
-	->addVar('hostid', $this->data['hostid'])
-	->addVar('ymin_itemid', $this->data['ymin_itemid'])
-	->addVar('ymax_itemid', $this->data['ymax_itemid']);
+	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
+	->addVar('form', $data['form'])
+	->addVar('hostid', $data['hostid']);
 
 if ($data['parent_discoveryid'] !== null) {
 	$graphForm->addItem((new CVar('parent_discoveryid', $data['parent_discoveryid']))->removeId());
@@ -56,7 +55,7 @@ if ($data['graphid'] != 0) {
 // Create form list.
 $graphFormList = new CFormList('graphFormList');
 
-$is_templated = (bool) $this->data['templates'];
+$is_templated = (bool) $data['templates'];
 if ($is_templated) {
 	$graphFormList->addRow(_('Parent graphs'), $data['templates']);
 }
@@ -83,18 +82,18 @@ if ($discovered_graph) {
 $graphFormList
 	->addRow(
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
-		(new CTextBox('name', $this->data['name'], $readonly))
+		(new CTextBox('name', $data['name'], $readonly, DB::getFieldLength('graphs', 'name')))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setAttribute('autofocus', 'autofocus')
 	)
 	->addRow((new CLabel(_('Width'), 'width'))->setAsteriskMark(),
-		(new CNumericBox('width', $this->data['width'], 5, $readonly))
+		(new CNumericBox('width', $data['width'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
 	->addRow((new CLabel(_('Height'), 'height'))->setAsteriskMark(),
-		(new CNumericBox('height', $this->data['height'], 5, $readonly))
+		(new CNumericBox('height', $data['height'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
@@ -102,71 +101,71 @@ $graphFormList
 		(new CSelect('graphtype'))
 			->setId('graphtype')
 			->setFocusableElementId('label-graphtype')
-			->setValue($this->data['graphtype'])
+			->setValue($data['graphtype'])
 			->addOptions(CSelect::createOptionsFromArray(graphType()))
-			->setDisabled($readonly)
+			->setReadonly($readonly)
 	)
 	->addRow(_('Show legend'),
 		(new CCheckBox('show_legend'))
-			->setChecked($this->data['show_legend'] == 1)
+			->setChecked($data['show_legend'] == 1)
 			->setEnabled(!$readonly)
 	);
 
 // Append graph types to form list.
-if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] == GRAPH_TYPE_STACKED) {
+if ($data['graphtype'] == GRAPH_TYPE_NORMAL || $data['graphtype'] == GRAPH_TYPE_STACKED) {
 	$graphFormList->addRow(_('Show working time'),
 		(new CCheckBox('show_work_period'))
-			->setChecked($this->data['show_work_period'] == 1)
+			->setChecked($data['show_work_period'] == 1)
 			->setEnabled(!$readonly)
 	);
 	$graphFormList->addRow(_('Show triggers'),
 		(new CCheckbox('show_triggers'))
-			->setchecked($this->data['show_triggers'] == 1)
+			->setchecked($data['show_triggers'] == 1)
 			->setEnabled(!$readonly)
 	);
 
-	if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL) {
+	if ($data['graphtype'] == GRAPH_TYPE_NORMAL) {
 		// Percent left.
-		$percentLeftTextBox = (new CTextBox('percent_left', $this->data['percent_left'], $readonly, 7))
+		$percentLeftTextBox = (new CTextBox('percent_left', $data['percent_left'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentLeftCheckbox = (new CCheckBox('visible[percent_left]'))
 			->setChecked(true)
 			->onClick('javascript: showHideVisible("percent_left");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_left'])) {
+		if (array_key_exists('visible', $data) && array_key_exists('percent_left', $data['visible'])) {
 			$percentLeftCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_left'] == 0) {
+		elseif ($data['percent_left'] == 0) {
 			$percentLeftTextBox->addStyle('visibility: hidden;');
 			$percentLeftCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, SPACE, $percentLeftTextBox]);
+		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, ' ', $percentLeftTextBox]);
 
 		// Percent right.
-		$percentRightTextBox = (new CTextBox('percent_right', $this->data['percent_right'], $readonly, 7))
+		$percentRightTextBox = (new CTextBox('percent_right', $data['percent_right'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentRightCheckbox = (new CCheckBox('visible[percent_right]'))
 			->setChecked(true)
 			->onClick('javascript: showHideVisible("percent_right");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_right'])) {
+		if (array_key_exists('visible', $data) && array_key_exists('percent_right', $data['visible'])) {
 			$percentRightCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_right'] == 0) {
+		elseif ($data['percent_right'] == 0) {
 			$percentRightTextBox->addStyle('visibility: hidden;');
 			$percentRightCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, SPACE, $percentRightTextBox]);
+		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, ' ', $percentRightTextBox]);
 	}
 
 	$yaxisMinData = [];
 	$yaxisMinData[] = (new CSelect('ymin_type'))
 		->setId('ymin_type')
-		->setValue($this->data['ymin_type'])
+		->setValue($data['ymin_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
@@ -174,48 +173,56 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		]))
 		->setDisabled($readonly);
 
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('yaxismin', $this->data['yaxismin'], $readonly))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
+		$yaxisMinData[] = (new CTextBox('yaxismin', $data['yaxismin'], $readonly))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
+	elseif ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
 
-		$ymin_name = '';
-		if (!empty($this->data['ymin_itemid'])) {
-			$min_host = get_host_by_itemid($this->data['ymin_itemid']);
+		$ymin_axis_ms_data = [];
 
-			$minItems = CMacrosResolverHelper::resolveItemNames([get_item_by_itemid($this->data['ymin_itemid'])]);
-			$minItem = reset($minItems);
-
-			$ymin_name = $min_host['name'].NAME_DELIMITER.$minItem['name_expanded'];
+		if ($data['ymin_itemid'] != 0) {
+			if (array_key_exists($data['ymin_itemid'], $data['yaxis_items'])) {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => $data['yaxis_items'][$data['ymin_itemid']]['name_expanded'],
+					'prefix' => $data['yaxis_items'][$data['ymin_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
 		}
 
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('ymin_name', $ymin_name, true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
-		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-
-		// Select item button.
-		$yaxisMinData[] = (new CButton('yaxis_min', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick('return PopUp("popup.generic",jQuery.extend('.
-				json_encode([
+		$yaxisMinData[] = (new CMultiSelect([
+			'name' => 'ymin_itemid',
+			'object_name' => 'items',
+			'data' => $ymin_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymin_itemid',
-					'dstfld2' => 'ymin_name',
-					'with_webitems' => '1',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).
-					',getOnlyHostParam()), null, this);'
-			)
-			->setEnabled(!$readonly);
+					'webitems' => '1',
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
@@ -229,7 +236,6 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 						'srcfld2' => 'name',
 						'dstfrm' => $graphForm->getName(),
 						'dstfld1' => 'ymin_itemid',
-						'dstfld2' => 'ymin_name',
 						'parent_discoveryid' => $data['parent_discoveryid'],
 						'numeric' => '1'
 					]).', null, this);'
@@ -238,11 +244,11 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
 	}
 
 	$yaxismin_label = new CLabel(_('Y axis MIN value'));
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
 		$yaxismin_label
 			->setAsteriskMark()
 			->setAttribute('for', 'ymin_name');
@@ -253,7 +259,7 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 	$yaxisMaxData = [];
 	$yaxisMaxData[] = (new CSelect('ymax_type'))
 		->setId('ymax_type')
-		->setValue($this->data['ymax_type'])
+		->setValue($data['ymax_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
@@ -261,48 +267,56 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		]))
 		->setDisabled($readonly);
 
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('yaxismax', $this->data['yaxismax'], $readonly))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
+		$yaxisMaxData[] = (new CTextBox('yaxismax', $data['yaxismax'], $readonly))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
+	elseif ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
 
-		$ymax_name = '';
-		if (!empty($this->data['ymax_itemid'])) {
-			$max_host = get_host_by_itemid($this->data['ymax_itemid']);
+		$ymax_axis_ms_data = [];
 
-			$maxItems = CMacrosResolverHelper::resolveItemNames([get_item_by_itemid($this->data['ymax_itemid'])]);
-			$maxItem = reset($maxItems);
-
-			$ymax_name = $max_host['name'].NAME_DELIMITER.$maxItem['name_expanded'];
+		if ($data['ymax_itemid'] != 0) {
+			if (array_key_exists($data['ymax_itemid'], $data['yaxis_items'])) {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => $data['yaxis_items'][$data['ymax_itemid']]['name_expanded'],
+					'prefix' => $data['yaxis_items'][$data['ymax_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
 		}
 
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('ymax_name', $ymax_name, true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
-		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-
-		// Select item button.
-		$yaxisMaxData[] = (new CButton('yaxis_max', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick('return PopUp("popup.generic",jQuery.extend('.
-				json_encode([
+		$yaxisMaxData[] = (new CMultiSelect([
+			'name' => 'ymax_itemid',
+			'object_name' => 'items',
+			'data' => $ymax_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymax_itemid',
-					'dstfld2' => 'ymax_name',
-					'with_webitems' => '1',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).
-					',getOnlyHostParam()), null, this);'
-			)
-			->setEnabled(!$readonly);
+					'webitems' => '1',
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
@@ -316,7 +330,6 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 						'srcfld2' => 'name',
 						'dstfrm' => $graphForm->getName(),
 						'dstfld1' => 'ymax_itemid',
-						'dstfld2' => 'ymax_name',
 						'parent_discoveryid' => $data['parent_discoveryid'],
 						'numeric' => '1'
 					]).', null, this);'
@@ -325,11 +338,11 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
 	}
 
 	$yaxismax_label = new CLabel(_('Y axis MAX value'));
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
 		$yaxismax_label
 			->setAsteriskMark()
 			->setAttribute('for', 'ymax_name');
@@ -340,7 +353,7 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 else {
 	$graphFormList->addRow(_('3D view'),
 		(new CCheckBox('show_3d'))
-			->setChecked($this->data['show_3d'] == 1)
+			->setChecked($data['show_3d'] == 1)
 			->setEnabled(!$readonly)
 	);
 }
@@ -351,21 +364,21 @@ $items_table = (new CTable())
 	->setColumns([
 		(new CTableColumn())->addClass('table-col-handle'),
 		(new CTableColumn())->addClass('table-col-no'),
-		(new CTableColumn(_('Name')))->addClass(($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		(new CTableColumn(_('Name')))->addClass(($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? 'table-col-name-normal'
 			: 'table-col-name'
 		),
-		in_array($this->data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
+		in_array($data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
 			? (new CTableColumn(_('Type')))->addClass('table-col-type')
 			: null,
 		(new CTableColumn(_('Function')))->addClass('table-col-function'),
-		($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? (new CTableColumn(
 				(new CColHeader(_('Draw style')))->addClass(ZBX_STYLE_NOWRAP)
 			))
 				->addClass('table-col-draw-style')
 			: null,
-		in_array($this->data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
+		in_array($data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
 			? (new CTableColumn(
 				(new CColHeader(_('Y axis side')))->addClass(ZBX_STYLE_NOWRAP)
 			))
@@ -432,7 +445,11 @@ $items_table->addRow(
 	))->setId('itemButtonsRow')
 );
 
-foreach ($this->data['items'] as $n => $item) {
+foreach ($data['items'] as $n => $item) {
+	if (!$item['itemid']) {
+		continue;
+	}
+
 	$name = $item['host'].NAME_DELIMITER.$item['name_expanded'];
 
 	if (zbx_empty($item['drawtype'])) {
@@ -447,9 +464,17 @@ foreach ($this->data['items'] as $n => $item) {
 		$item['gitemid'] = '';
 	}
 
+	if (!array_key_exists('calc_fnc', $item)) {
+		$item['calc_fnc'] = CALC_FNC_AVG;
+	}
+
+	if (!array_key_exists('color', $item)) {
+		$item['color'] = '';
+	}
+
 	insert_js('loadItem('.$n.', '.json_encode($item['gitemid']).', '.$item['itemid'].', '.
-		json_encode($name).', '.$item['type'].', '.$item['calc_fnc'].', '.$item['drawtype'].', '.
-		$item['yaxisside'].', \''.$item['color'].'\', '.$item['flags'].');',
+		json_encode($name).', '.$item['type'].', '.json_encode($item['calc_fnc']).', '.$item['drawtype'].', '.
+		json_encode($item['yaxisside']).', '.json_encode($item['color']).', '.json_encode($item['flags']).');',
 		true
 	);
 }
@@ -492,7 +517,7 @@ if ($data['graphid'] != 0) {
 		url_params(['graphid', 'parent_discoveryid', 'hostid'])
 	);
 
-	if ($readonly) {
+	if ($readonly && $data['parent_discoveryid'] === null) {
 		$updateButton->setEnabled(false);
 	}
 
@@ -504,14 +529,14 @@ if ($data['graphid'] != 0) {
 		$updateButton, [
 			new CSubmit('clone', _('Clone')),
 			$deleteButton,
-			new CButtonCancel(url_param('parent_discoveryid').url_param('hostid', $this->data['hostid']))
+			new CButtonCancel(url_param('parent_discoveryid').url_param('hostid', $data['hostid']))
 		]
 	));
 }
 else {
 	$graphTab->setFooter(makeFormFooter(
 		new CSubmit('add', _('Add')),
-		[new CButtonCancel(url_param('parent_discoveryid').url_param('hostid', $this->data['hostid']))]
+		[new CButtonCancel(url_param('parent_discoveryid').url_param('hostid', $data['hostid']))]
 	));
 }
 
