@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -33,9 +33,10 @@ if (!empty($data['hostid'])) {
 
 // Create form.
 $form = (new CForm())
+	->addVar('form_refresh', $data['form_refresh'] + 1)
 	->setId('itemForm')
 	->setName('itemForm')
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
+	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form'])
 	->addVar('hostid', $data['hostid']);
 
@@ -163,7 +164,7 @@ $form_list
 					(new CTextBox('query_fields[name][#{index}]', '#{name}', $readonly))
 						->setAttribute('placeholder', _('name'))
 						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
-					'&rArr;',
+					RARR(),
 					(new CTextBox('query_fields[value][#{index}]', '#{value}', $readonly))
 						->setAttribute('placeholder', _('value'))
 						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
@@ -259,7 +260,7 @@ $form_list
 					(new CTextBox('headers[name][#{index}]', '#{name}', $readonly))
 						->setAttribute('placeholder', _('name'))
 						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
-					'&rArr;',
+					RARR(),
 					(new CTextBox('headers[value][#{index}]', '#{value}', $readonly, 2000))
 						->setAttribute('placeholder', _('value'))
 						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
@@ -466,7 +467,7 @@ if ($data['interfaces']) {
 }
 
 $form_list
-	// Append SNMP common fields fields.
+	// Append SNMP common fields.
 	->addRow(
 		(new CLabel(_('SNMP OID'), 'snmp_oid'))->setAsteriskMark(),
 		(new CTextBox('snmp_oid', $data['snmp_oid'], $readonly, 512))
@@ -749,7 +750,7 @@ foreach ($valuemaps as $valuemap) {
 }
 
 if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
-	$valuemap_select = [$valuemap_select, '&nbsp;',
+	$valuemap_select = [$valuemap_select, NBSP(),
 		(new CLink(_('show value mappings'), (new CUrl('zabbix.php'))
 			->setArgument('action', 'valuemap.list')
 			->getUrl()
@@ -788,7 +789,7 @@ if ($discovered_item) {
 
 	$application_list_box = new CListBox('applications_names[]', $data['applications'], 6);
 	foreach ($data['db_applications'] as $application) {
-		$application_list_box->addItem($application['applicationid'], CHtml::encode($application['name']));
+		$application_list_box->addItem($application['applicationid'], $application['name']);
 	}
 	$application_list_box->setEnabled(!$discovered_item);
 }
@@ -800,7 +801,7 @@ else {
 	$application_list_box = new CListBox('applications[]', $data['applications'], 6);
 	$application_list_box->addItem(0, '-'._('None').'-');
 	foreach ($data['db_applications'] as $application) {
-		$application_list_box->addItem($application['applicationid'], CHtml::encode($application['name']));
+		$application_list_box->addItem($application['applicationid'], $application['name']);
 	}
 }
 
@@ -857,11 +858,11 @@ $itemTab = (new CTabView())
 	->addTab('preprocTab', _('Preprocessing'),
 		(new CFormList('item_preproc_list'))
 			->addRow(_('Preprocessing steps'),
-				getItemPreprocessing($form, $data['preprocessing'], $readonly, $data['preprocessing_types'])
+				getItemPreprocessing($data['preprocessing'], $readonly, $data['preprocessing_types'])
 			)
 	);
 
-if (!hasRequest('form_refresh')) {
+if ($data['form_refresh'] == 0) {
 	$itemTab->setSelected(0);
 }
 
