@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@
 				->setAttribute('placeholder', _('name'))
 				->setAttribute('data-type', 'name')
 				->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
-			'&rArr;',
+			RARR(),
 			(new CTextBox(null, '#{value}'))
 				->setAttribute('placeholder', _('value'))
 				->setAttribute('data-type', 'value')
@@ -520,7 +520,7 @@
 					e.new_node.querySelector('.' + httpconf.ZBX_STYLE_DRAG_ICON).remove();
 				}
 
-				if (type === 'headers') {
+				if (type === 'variables' || type === 'headers') {
 					e.new_node.querySelector('[data-type="value"]').setAttribute('maxlength', 2000);
 				}
 			});
@@ -831,7 +831,7 @@
 				});
 			}
 
-			if (type === 'headers') {
+			if (type === 'variables' || type === 'headers' || type === 'post_fields') {
 				$node.on('dynamic_rows.beforeadd', function(e, dynamic_rows) {
 					e.new_node.querySelector('[data-type="value"]').setAttribute('maxlength', 2000);
 				});
