@@ -1,7 +1,6 @@
-// JavaScript Document
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -16,8 +15,7 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-**
-*/
+**/
 
 
 var CLNDR = null,
@@ -287,7 +285,6 @@ calendar.prototype = {
 				}
 
 				return false;
-				break;
 
 			case 32: // Prevent page scrolling when pressing Space.
 				return false;
