@@ -1,21 +1,21 @@
 /*
- ** Zabbix
- ** Copyright (C) 2001-2021 Zabbix SIA
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 2 of the License, or
- ** (at your option) any later version.
- **
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- ** GNU General Public License for more details.
- **
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- **/
+** Zabbix
+** Copyright (C) 2001-2024 Zabbix SIA
+**
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+**/
 
 
 /**
@@ -26,7 +26,7 @@
  *  - show_problems - show problems in hintbox when mouse is moved over the problem zone;
  *  - min_period - min period in seconds that must be s-boxed to change the data in dashboard timeselector.
  */
-jQuery(function ($) {
+(function ($) {
 	"use strict";
 
 	// Makes SBox selection cancelable pressing Esc.
@@ -474,10 +474,10 @@ jQuery(function ($) {
 						);
 					});
 
-					html = $('<div></div>')
+					html = $('<div>')
 							.addClass('svg-graph-hintbox')
 							.append(
-								$('<table></table>')
+								$('<table>')
 									.addClass('list-table compact-view')
 									.append(tbody)
 							)
@@ -522,7 +522,7 @@ jQuery(function ($) {
 
 				// Make html for hintbox.
 				if (show_hint) {
-					html = $('<ul></ul>');
+					html = $('<ul>');
 				}
 				var rows_added = 0;
 				points.forEach(function(point) {
@@ -537,10 +537,10 @@ jQuery(function ($) {
 						}
 
 						if (show_hint && data.hintMaxRows > rows_added) {
-							$('<li></li>')
+							$('<li>')
 								.text(point.g.getAttribute('data-metric') + ': ' + point.v)
 								.append(
-									$('<span></span>')
+									$('<span>')
 										.css('background-color', point.g.getAttribute('data-color'))
 										.addClass('svg-graph-hintbox-item-color')
 								)
@@ -556,20 +556,20 @@ jQuery(function ($) {
 
 				if (show_hint) {
 					// Calculate time at mouse position.
-					var time = parseInt(data.timeFrom + ((offsetX - data.dimX) * data.spp));
+					const time = new CDate((data.timeFrom + (offsetX - data.dimX) * data.spp) * 1000);
 
-					html = $('<div></div>')
-							.addClass('svg-graph-hintbox')
-							.append(
-								$('<div></div>')
-									.addClass('header')
-									.html(time2str(time))
-							)
-							.append(html)
-							.append(points_total > data.hintMaxRows
-								? makeHintBoxFooter(data.hintMaxRows, points_total)
-								: null
-							);
+					html = $('<div>')
+						.addClass('svg-graph-hintbox')
+						.append(
+							$('<div>')
+								.addClass('header')
+								.html(time.format(PHP_ZBX_FULL_DATE_TIME))
+						)
+						.append(html)
+						.append(points_total > data.hintMaxRows
+							? makeHintBoxFooter(data.hintMaxRows, points_total)
+							: null
+						);
 				}
 			}
 			else {
@@ -603,13 +603,13 @@ jQuery(function ($) {
 
 	// Function creates hintbox footer.
 	function makeHintBoxFooter(num_displayed, num_total) {
-		return $('<div></div>')
+		return $('<div>')
 			.addClass('table-paging')
 			.append(
-				$('<div></div>')
+				$('<div>')
 					.addClass('paging-btn-container')
 					.append(
-						$('<div></div>')
+						$('<div>')
 							.text(sprintf(t('S_DISPLAYING_FOUND'), num_displayed, num_total))
 							.addClass('table-stats')
 					)
@@ -682,4 +682,4 @@ jQuery(function ($) {
 
 		return methods.init.apply(this, arguments);
 	};
-});
+})(jQuery);
