@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -59,12 +59,12 @@ $fields = [
 	'expr_target_single' =>						[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({and_expression}) || isset({or_expression}) || isset({replace_expression}))', _('Target')],
 	'recovery_expr_temp' =>						[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({add_recovery_expression}) || isset({and_recovery_expression}) || isset({or_recovery_expression}) || isset({replace_recovery_expression}))', _('Recovery expression')],
 	'recovery_expr_target_single' =>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({and_recovery_expression}) || isset({or_recovery_expression}) || isset({replace_recovery_expression}))', _('Target')],
-	'dependencies' =>							[T_ZBX_INT, O_OPT, null,	DB_ID,			null],
-	'new_dependency' =>							[T_ZBX_INT, O_OPT, null,	DB_ID.'{}>0',	'isset({add_dependency})'],
-	'g_triggerid' =>							[T_ZBX_INT, O_OPT, null,	DB_ID,			null],
-	'copy_targetids' =>							[T_ZBX_INT, O_OPT, null,	DB_ID,			null],
-	'visible' =>								[T_ZBX_STR, O_OPT, null,	null,			null],
-	'tags' =>									[T_ZBX_STR, O_OPT, null,	null,			null],
+	'dependencies' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,			null],
+	'new_dependency' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID.'{}>0',	'isset({add_dependency})'],
+	'g_triggerid' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,			null],
+	'copy_targetids' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,			null],
+	'visible' =>								[T_ZBX_STR, O_OPT, P_ONLY_ARRAY,	null,			null],
+	'tags' =>									[T_ZBX_STR, O_OPT, P_ONLY_TD_ARRAY,	null,			null],
 	'mass_update_tags'	=>						[T_ZBX_INT, O_OPT, null,
 													IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE]),
 													null
@@ -79,7 +79,7 @@ $fields = [
 	// Filter related fields.
 	'filter_set' =>								[T_ZBX_STR, O_OPT, P_SYS,	null,			null],
 	'filter_rst' =>								[T_ZBX_STR, O_OPT, P_SYS,	null,			null],
-	'filter_priority' =>						[T_ZBX_INT, O_OPT, null,
+	'filter_priority' =>						[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,
 													IN([
 														TRIGGER_SEVERITY_NOT_CLASSIFIED,
 														TRIGGER_SEVERITY_INFORMATION, TRIGGER_SEVERITY_WARNING,
@@ -87,8 +87,8 @@ $fields = [
 														TRIGGER_SEVERITY_DISASTER
 													]), null
 												],
-	'filter_groupids' =>						[T_ZBX_INT, O_OPT, null, DB_ID, null],
-	'filter_hostids' =>							[T_ZBX_INT, O_OPT, null, DB_ID, null],
+	'filter_groupids' =>						[T_ZBX_INT, O_OPT, P_ONLY_ARRAY, DB_ID, null],
+	'filter_hostids' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY, DB_ID, null],
 	'filter_inherited' =>						[T_ZBX_INT, O_OPT, null, IN([-1, 0, 1]), null],
 	'filter_discovered' =>						[T_ZBX_INT, O_OPT, null, IN([-1, 0, 1]), null],
 	'filter_dependent' =>						[T_ZBX_INT, O_OPT, null, IN([-1, 0, 1]), null],
@@ -105,7 +105,7 @@ $fields = [
 	'filter_evaltype' =>						[T_ZBX_INT, O_OPT, null,
 													IN([TAG_EVAL_TYPE_AND_OR, TAG_EVAL_TYPE_OR]), null
 												],
-	'filter_tags' =>							[T_ZBX_STR, O_OPT, null,	null,			null],
+	'filter_tags' =>							[T_ZBX_STR, O_OPT, P_ONLY_TD_ARRAY,	null,			null],
 	// Action related fields.
 	'action' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 													IN('"trigger.masscopyto","trigger.massdelete","trigger.massdisable",'.
@@ -138,7 +138,7 @@ $fields = [
 	'delete' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'cancel' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
-	'form_refresh' =>							[T_ZBX_INT, O_OPT, null,	null,		null],
+	'form_refresh' =>							[T_ZBX_INT, O_OPT, P_SYS,	null,		null],
 	'checkbox_hash' =>							[T_ZBX_STR, O_OPT, null,	null,		null],
 	// Sort and sortorder.
 	'sort' =>									[T_ZBX_STR, O_OPT, P_SYS, IN('"description","priority","status"'),		null],
@@ -509,7 +509,9 @@ elseif (hasRequest('action') && getRequest('action') === 'trigger.massupdate'
 			}
 		}
 
-		$result = (bool) API::Trigger()->update($triggers_to_update);
+		if ($triggers_to_update) {
+			$result = (bool) API::Trigger()->update($triggers_to_update);
+		}
 	}
 
 	if ($result) {
@@ -631,7 +633,7 @@ elseif (isset($_REQUEST['form'])) {
 	$data = [
 		'config' => $config,
 		'form' => getRequest('form'),
-		'form_refresh' => getRequest('form_refresh'),
+		'form_refresh' => getRequest('form_refresh', 0),
 		'parent_discoveryid' => null,
 		'dependencies' => getRequest('dependencies', []),
 		'db_dependencies' => [],
@@ -879,6 +881,10 @@ else {
 			}
 
 			foreach (array_column($item['triggers'], 'triggerid') as $triggerid) {
+				if (!array_key_exists($triggerid, $triggers)) {
+					continue;
+				}
+
 				if (!array_key_exists('ts_delete', $triggers[$triggerid]['triggerDiscovery'])) {
 					$triggers[$triggerid]['triggerDiscovery']['ts_delete'] = $ts_delete;
 				}
